@@ -305,7 +305,7 @@ AppWindow::finish_editing( bool opt_save )
 
     Lifeograph::s_signal_logout.emit();	// only for DialogEvent
 
-    Lifeograph::m_internaloperation++;
+    Lifeograph::s_internaloperation++;
     panel_main->handle_logout();
     panel_diary->handle_logout();
     m_entry_view->get_buffer()->handle_logout();
@@ -316,7 +316,7 @@ AppWindow::finish_editing( bool opt_save )
     Diary::d->clear();
     m_connection_timeout.disconnect();
     m_connection_backup.disconnect();
-    Lifeograph::m_internaloperation--;
+    Lifeograph::s_internaloperation--;
 
     return true;
 }
@@ -419,65 +419,74 @@ AppWindow::login()
             Lifeograph::builder->get_widget_derived( "treeview_all_tags", panel_extra );
 
             // ICONS
+            std::string icon_dir( ICONDIR );
+            if( ! Lifeograph::settings.icon_theme.empty() )
+            {
+                icon_dir += "/";
+                icon_dir += Lifeograph::settings.icon_theme;
+            }
+
             Lifeograph::icons->diary_16 =
-                    Gdk::Pixbuf::create_from_file( ICONDIR "/diary-16.png" );
+                    Gdk::Pixbuf::create_from_file( icon_dir + "/diary-16.png" );
             Lifeograph::icons->diary_32 =
-                    Gdk::Pixbuf::create_from_file( ICONDIR "/diary-32.png" );
+                    Gdk::Pixbuf::create_from_file( icon_dir + "/diary-32.png" );
             Lifeograph::icons->entry_16 =
-                    Gdk::Pixbuf::create_from_file( ICONDIR "/entry-16.png" );
+                    Gdk::Pixbuf::create_from_file( icon_dir + "/entry-16.png" );
             Lifeograph::icons->entry_32 =
-                    Gdk::Pixbuf::create_from_file( ICONDIR "/entry-32.png" );
-            Lifeograph::icons->entry_favorite_16 =
-                    Gdk::Pixbuf::create_from_file( ICONDIR "/favorite-16.png" );
+                    Gdk::Pixbuf::create_from_file( icon_dir + "/entry-32.png" );
+            Lifeograph::icons->favorite_16 =
+                    Gdk::Pixbuf::create_from_file( icon_dir + "/favorite-16.png" );
 
             Lifeograph::icons->tag_16 =
-                    Gdk::Pixbuf::create_from_file( ICONDIR "/tag-16.png" );
+                    Gdk::Pixbuf::create_from_file( icon_dir + "/tag-16.png" );
             Lifeograph::icons->tag_32 =
-                    Gdk::Pixbuf::create_from_file( ICONDIR "/tag-32.png" );
+                    Gdk::Pixbuf::create_from_file( icon_dir + "/tag-32.png" );
             Lifeograph::icons->tag_theme_16 =
-                    Gdk::Pixbuf::create_from_file( ICONDIR "/tag_theme-16.png" );
+                    Gdk::Pixbuf::create_from_file( icon_dir + "/tag_theme-16.png" );
             Lifeograph::icons->tag_theme_32 =
-                    Gdk::Pixbuf::create_from_file( ICONDIR "/tag_theme-32.png" );
+                    Gdk::Pixbuf::create_from_file( icon_dir + "/tag_theme-32.png" );
             Lifeograph::icons->untagged_16 =
-                    Gdk::Pixbuf::create_from_file( ICONDIR "/untagged-16.png" );
+                    Gdk::Pixbuf::create_from_file( icon_dir + "/untagged-16.png" );
             Lifeograph::icons->untagged_32 =
-                    Gdk::Pixbuf::create_from_file( ICONDIR "/untagged-32.png" );
+                    Gdk::Pixbuf::create_from_file( icon_dir + "/untagged-32.png" );
             Lifeograph::icons->tag_category_16 =
-                    Gdk::Pixbuf::create_from_file( ICONDIR "/tag_category-16.png" );
+                    Gdk::Pixbuf::create_from_file( icon_dir + "/tag_category-16.png" );
             Lifeograph::icons->tag_category_32 =
-                    Gdk::Pixbuf::create_from_file( ICONDIR "/tag_category-32.png" );
+                    Gdk::Pixbuf::create_from_file( icon_dir + "/tag_category-32.png" );
 
             Lifeograph::icons->chapter_16 =
-                    Gdk::Pixbuf::create_from_file( ICONDIR "/chapter-16.png" );
+                    Gdk::Pixbuf::create_from_file( icon_dir + "/chapter-16.png" );
             Lifeograph::icons->chapter_32 =
-                    Gdk::Pixbuf::create_from_file( ICONDIR "/chapter-32.png" );
+                    Gdk::Pixbuf::create_from_file( icon_dir + "/chapter-32.png" );
 
             Lifeograph::icons->month_16 =
-                    Gdk::Pixbuf::create_from_file( ICONDIR "/month-16.png" );
+                    Gdk::Pixbuf::create_from_file( icon_dir + "/month-16.png" );
             Lifeograph::icons->month_32 =
-                    Gdk::Pixbuf::create_from_file( ICONDIR "/month-32.png" );
+                    Gdk::Pixbuf::create_from_file( icon_dir + "/month-32.png" );
 
             Lifeograph::icons->filter_16 =
-                    Gdk::Pixbuf::create_from_file( ICONDIR "/filter-16.png" );
+                    Gdk::Pixbuf::create_from_file( icon_dir + "/filter-16.png" );
             Lifeograph::icons->filter_32 =
-                    Gdk::Pixbuf::create_from_file( ICONDIR "/filter-32.png" );
+                    Gdk::Pixbuf::create_from_file( icon_dir + "/filter-32.png" );
+            Lifeograph::icons->filter_revert_16 =
+                    Gdk::Pixbuf::create_from_file( icon_dir + "/filter_revert-16.png" );
 
             Lifeograph::icons->todo_open_16 =
-                    Gdk::Pixbuf::create_from_file( ICONDIR "/todo_open-16.png" );
+                    Gdk::Pixbuf::create_from_file( icon_dir + "/todo_open-16.png" );
             Lifeograph::icons->todo_open_32 =
-                    Gdk::Pixbuf::create_from_file( ICONDIR "/todo_open-32.png" );
+                    Gdk::Pixbuf::create_from_file( icon_dir + "/todo_open-32.png" );
             Lifeograph::icons->todo_progressed_16 =
-                    Gdk::Pixbuf::create_from_file( ICONDIR "/todo_progressed-16.png" );
+                    Gdk::Pixbuf::create_from_file( icon_dir + "/todo_progressed-16.png" );
             Lifeograph::icons->todo_progressed_32 =
-                    Gdk::Pixbuf::create_from_file( ICONDIR "/todo_progressed-32.png" );
+                    Gdk::Pixbuf::create_from_file( icon_dir + "/todo_progressed-32.png" );
             Lifeograph::icons->todo_done_16 =
-                    Gdk::Pixbuf::create_from_file( ICONDIR "/todo_done-16.png" );
+                    Gdk::Pixbuf::create_from_file( icon_dir + "/todo_done-16.png" );
             Lifeograph::icons->todo_done_32 =
-                    Gdk::Pixbuf::create_from_file( ICONDIR "/todo_done-32.png" );
+                    Gdk::Pixbuf::create_from_file( icon_dir + "/todo_done-32.png" );
             Lifeograph::icons->todo_canceled_16 =
-                    Gdk::Pixbuf::create_from_file( ICONDIR "/todo_canceled-16.png" );
+                    Gdk::Pixbuf::create_from_file( icon_dir + "/todo_canceled-16.png" );
             Lifeograph::icons->todo_canceled_32 =
-                    Gdk::Pixbuf::create_from_file( ICONDIR "/todo_canceled-32.png" );
+                    Gdk::Pixbuf::create_from_file( icon_dir + "/todo_canceled-32.png" );
 
             // PANELS & VIEWS
             panel_main = new PanelMain;
@@ -549,7 +558,7 @@ AppWindow::login()
     // the following must come before handle_login()s
     m_auto_logout_status = ( Lifeograph::settings.autologout && Diary::d->is_encrypted() ) ? 0 : 1;
 
-    Lifeograph::m_internaloperation++;
+    Lifeograph::s_internaloperation++;
 
     panel_main->handle_login(); // must come before m_diary_view->handle_login() for header bar order
     m_view_login->handle_login();
@@ -561,7 +570,7 @@ AppWindow::login()
     panel_diary->handle_login();
     panel_extra->handle_login();
 
-    Lifeograph::m_internaloperation--;
+    Lifeograph::s_internaloperation--;
 
     Lifeograph::loginstatus = Lifeograph::LOGGED_IN;
 
