@@ -20,8 +20,8 @@
 ***********************************************************************************/
 
 
-#ifndef LIFEOGRAPH_HEADER
-#define LIFEOGRAPH_HEADER
+#ifndef LIFEOGRAPH_APP_WINDOW_HEADER
+#define LIFEOGRAPH_APP_WINDOW_HEADER
 
 #define LIFEOGRAPH_DEVELOPMENT_VERSION
 
@@ -47,16 +47,10 @@ class AppWindow : public Gtk::ApplicationWindow
     public:
                                     AppWindow();
                                     ~AppWindow();
-        static AppWindow            *p;
-
-        void                        draw_welcomescreen();
-        void                        draw_loginscreen();
+        static AppWindow*           p;
 
         void                        update_title();
 
-        void                        freeze_auto_logout();
-        void                        unfreeze_auto_logout();
-
         bool                        confirm_dismiss_element( const DiaryElement*,
                                                              Gtk::Widget* = NULL );
         Gtk::TreeRow                get_element_row( const DiaryElement* );
@@ -72,31 +66,48 @@ class AppWindow : public Gtk::ApplicationWindow
         void                        handle_undo();
         void                        handle_redo();
 
-        // PANELS AND VIEWS
-        PanelMain                   *panel_main;
-        PanelDiary                  *panel_diary;
-        PanelExtra                  *panel_extra;
+        // AUTO LOGOUT FUNCTIONALITY
+        bool                        handle_idle();
+        void                        freeze_auto_logout();
+        void                        unfreeze_auto_logout();
+        void                        update_auto_logout_count_down();
+        void                        disable_auto_logout_for_the_session();
+        void                        reenable_auto_logout_for_the_session();
+        bool                        is_auto_logout_in_use()
+        { return( m_auto_logout_status == 0 ); }
 
-        ViewLogin                   *m_view_login;
-        DiaryView                   *m_diary_view;
-        EntryView                   *m_entry_view;
-        TagView                     *m_tag_view;
-        CategoryTagsView            *m_ctg_tags_view;
-        ChapterView                 *m_chapter_view;
-        FilterView                  *m_filter_view;
+        bool                        on_event( GdkEvent* );
+
+        // PANELS AND VIEWS
+        PanelMain*                  panel_main;
+        PanelDiary*                 panel_diary;
+        PanelExtra*                 panel_extra;
+
+        ViewLogin*                  m_view_login;
+        DiaryView*                  m_diary_view;
+        EntryView*                  m_entry_view;
+        TagView*                    m_tag_view;
+        CategoryTagsView*           m_ctg_tags_view;
+        ChapterView*                m_chapter_view;
+        FilterView*                 m_filter_view;
+
+        Gtk::HeaderBar              m_headerbar;
 
     protected:
-        bool                        on_event( GdkEvent* );
         bool                        on_delete_event( GdkEventAny* );
 
         // WIDGETS
-        Gtk::AboutDialog            *m_about_dialog;
+        Gtk::AboutDialog*           m_about_dialog;
 
-        Gtk::Paned                  *m_paned_entry;
-        Gtk::Paned                  *m_paned_main;
+        Gtk::Paned*                 m_paned_entry;
+        Gtk::Paned*                 m_paned_main;
 
         sigc::connection            m_connection_backup;
 
+        int                         m_seconds_remaining;
+        sigc::connection            m_connection_timeout;
+        int                         m_auto_logout_status; // reflects the result of all factors
+
         // ACTIONS
         Glib::RefPtr< Gtk::Action > m_action_undo;
         Glib::RefPtr< Gtk::Action > m_action_redo;
