@@ -142,9 +142,10 @@ DialogOpenDiary::DialogOpenDiary()
     // TRANSLATORS: this is the title of file chooser dialog for selecting a new diary
 :   Gtk::FileChooserDialog( _( "Select a Diary" ), Gtk::FILE_CHOOSER_ACTION_OPEN )
 {
-    add_button( Gtk::Stock::CANCEL, RESPONSE_CANCEL );
-    add_button( _( "Read" ), RESPONSE_READ );
+    // Gtk gets confused if cancel is not stock:
+    add_button( Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL );
     add_button( _( "Edit" ), RESPONSE_EDIT );
+    add_button( _( "Read" ), RESPONSE_READ );
 
     init_filters();
     add_filter( filter_any );
