@@ -1,6 +1,6 @@
 /***********************************************************************************
 
-	Copyright (C) 2007-2011 Ahmet Öztürk (aoz_2@yahoo.com)
+	Copyright (C) 2007-2014 Ahmet Öztürk (aoz_2@yahoo.com)
 
     This file is part of Lifeograph.
 
@@ -38,13 +38,12 @@ class DialogPassword : public DialogEvent
 {
     public:
         enum OperationType
-        // Build blocks: cur=1, new=2, check=4, set=8
         {
             // blocks:
-            OT_CHECK=1,
-            OT_SET=2,
-            OT_CURRENT=4,
-            OT_NEW=8,
+            OT_CHECK = 1,
+            OT_SET = 2,
+            OT_CURRENT = 4,
+            OT_NEW = 8,
             // composites:
             OT_AUTHENTICATE = 5,
             OT_OPEN = 6,
@@ -52,9 +51,8 @@ class DialogPassword : public DialogEvent
             OT_CHANGE = 15,
         };
 
-                                    DialogPassword(
-                                            BaseObjectType*,
-                                            const Glib::RefPtr< Gtk::Builder >& );
+                                    DialogPassword( BaseObjectType*,
+                                                    const Glib::RefPtr< Gtk::Builder >& );
 
         static int                  launch( OperationType, Diary*, bool = false );
 
@@ -63,23 +61,23 @@ class DialogPassword : public DialogEvent
         void                        authenticate();
         void                        check_match();
 
-        Gtk::Button                 *m_button_go;
-        EntryClear                  *m_entry_current;
-        Gtk::Label                  *m_label_msg;
-        Gtk::Label                  *m_label_path;
+        Gtk::Button*                m_button_go;
+        EntryClear*                 m_entry_current;
+        Gtk::Label*                 m_label_msg;
+        Gtk::Label*                 m_label_path;
 
-        Gtk::Grid                   *m_grid_new;
-        Gtk::Grid                   *m_grid_authenticate;
-        Gtk::Button                 *m_button_authenticate;
-        EntryClear                  *m_entry_new;
-        EntryClear                  *m_entry_confirm;
-        Gtk::Image                  *m_image_new;
-        Gtk::Image                  *m_image_confirm;
+        Gtk::Grid*                  m_grid_new;
+        Gtk::Grid*                  m_grid_authenticate;
+        Gtk::Button*                m_button_authenticate;
+        EntryClear*                 m_entry_new;
+        EntryClear*                 m_entry_confirm;
+        Gtk::Image*                 m_image_new;
+        Gtk::Image*                 m_image_confirm;
 
-        Diary                       *m_ptr2diary;
+        Diary*                      m_ptr2diary;
         OperationType               m_ot;
 
-        static DialogPassword       *ptr;
+        static DialogPassword*      ptr;
 
         static const int            SLEEP_DURATION = 2;
 };
