@@ -37,6 +37,10 @@
 #include "helpers.hpp"
 #include "lifeograph.hpp"
 
+#ifdef LIFEO_WINDOZE
+#include <unistd.h>
+#include "strings.hpp"
+#endif
 
 using namespace LIFEO;
 
@@ -52,7 +56,7 @@ ElementShower< Diary >* Diary::shower( NULL );
 
 // PARSING HELPERS
 Date
-get_db_line_date( const Glib::ustring& line )
+get_db_line_date( const Ustring& line )
 {
     Date date( 0 );
 
@@ -66,10 +70,10 @@ get_db_line_date( const Glib::ustring& line )
     return( date );
 }
 
-Glib::ustring
-get_db_line_name( const Glib::ustring& line )
+Ustring
+get_db_line_name( const Ustring& line )
 {
-    Glib::ustring::size_type begin( line.find( '\t' ) );
+    Ustring::size_type begin( line.find( '\t' ) );
     if( begin == std::string::npos )
         begin = 2;
     else
@@ -80,12 +84,14 @@ get_db_line_name( const Glib::ustring& line )
 
 // DIARY ===========================================================================================
 Diary::Diary()
-:   DiaryElement( NULL, DEID_DIARY ), m_path( "" ), m_passphrase( "" ),
-    m_ptr2chapter_ctg_cur( NULL ), m_orphans( NULL, "", Date::DATE_MAX ),
+:   DiaryElement( NULL, DEID_DIARY ),
+    m_current_id( DEID_FIRST ), m_force_id( DEID_UNSET ),
     m_startup_elem_id( HOME_CURRENT_ELEM ), m_last_elem_id( DEID_DIARY ),
+    m_path( "" ), m_passphrase( "" ), m_language( "" ),
+    m_ptr2chapter_ctg_cur( NULL ), m_orphans( NULL, "", Date::DATE_MAX ),
     m_option_sorting_criteria( SC_DATE ), m_read_version( 0 ),
     m_flag_read_only( false ), m_search_text( "" ),
-    m_current_id( DEID_FIRST ), m_force_id( DEID_UNSET ), m_language( "" ), m_ifstream( NULL )
+    m_ifstream( NULL )
 {
     m_filter_active = new Filter( NULL, _( "Active Filter" ) );
     m_filter_default = new Filter( NULL, "Default Filter" );
@@ -162,20 +168,40 @@ Diary::clear()
     m_option_sorting_criteria = SC_DATE;
 }
 
-const Glib::RefPtr< Gdk::Pixbuf >&
+#ifndef LIFEO_WINDOZE
+const Icon&
 Diary::get_icon() const
 {
     return Lifeograph::icons->diary_16;
 }
-const Glib::RefPtr< Gdk::Pixbuf >&
+const Icon&
 Diary::get_icon32() const
 {
     return Lifeograph::icons->diary_32;
 }
+#else
+int
+Diary::get_icon() const
+{
+    return ICON_NO_DIARY;
+}
+#endif
 
 LIFEO::Result
-Diary::set_path( const std::string& path, SetPathType type )
+Diary::set_path( const std::string& path0, SetPathType type )
 {
+    std::string path( path0 );
+
+#ifndef LIFEO_WINDOZE
+    // RESOLVE SYMBOLIC LINK
+    if( g_file_test( path0.c_str(), G_FILE_TEST_IS_SYMLINK ) )
+    {
+        GError* err = NULL;
+        path = g_file_read_link( path0.c_str(), &err );
+        print_info( "Symbolic link resolved to path = " + path );
+    }
+#endif
+
     // CHECK FILE SYSTEM PERMISSIONS
     if( access( path.c_str(), F_OK ) != 0 ) // check existence
     {
@@ -211,7 +237,7 @@ Diary::set_path( const std::string& path, SetPathType type )
     if( type != SPT_READ_ONLY )
     {
         std::string path_lock( path + LOCK_SUFFIX );
-        if( Glib::file_test( path_lock, Glib::FILE_TEST_EXISTS ) )
+        if( access( path_lock.c_str(), F_OK ) == 0 )
         {
             if( s_flag_ignore_locks )
                 print_info( "Ignored file lock" );
@@ -234,7 +260,7 @@ Diary::set_path( const std::string& path, SetPathType type )
 
     // ACCEPT PATH
     m_path = path;
-    m_name = Glib::filename_display_basename( path );
+    m_name = get_filename_base( path );
     m_flag_read_only = ( type == SPT_READ_ONLY );
 
     return LIFEO::SUCCESS;
@@ -249,7 +275,7 @@ Diary::get_path() const
 bool
 Diary::is_path_set() const
 {
-    return ( (bool) m_path.size() );
+    return( ( bool ) m_path.size() );
 }
 
 bool
@@ -285,7 +311,7 @@ Diary::compare_passphrase( const std::string& passphrase ) const
 bool
 Diary::is_passphrase_set() const
 {
-    return (bool) m_passphrase.size();
+    return( ( bool ) m_passphrase.size() );
 }
 
 void
@@ -372,7 +398,7 @@ Diary::read_plain()
 {
     if( ! m_ifstream->is_open() )
     {
-        print_error( "internal error while reading the diary file: " + m_path );
+        print_error( "Internal error while reading the diary file: " + m_path );
         clear();
         return LIFEO::COULD_NOT_START;
     }
@@ -392,6 +418,33 @@ Diary::read_encrypted()
 
     CipherBuffers buf;
 
+#ifdef LIFEO_WINDOZE
+    m_ifstream->close();
+    m_ifstream->open( m_path.c_str(),
+                      std::ifstream::in | std::ifstream::binary | std::ifstream::ate );
+
+    size_t fsize = m_ifstream->tellg();
+    m_ifstream->seekg( 0, std::ios_base::beg );
+
+    // seek... this is preposterous!
+    char ch;
+    int ch_count = 0;
+    while( m_ifstream->get( ch ) )
+    {
+        if( ch == '\n' )
+        {
+            if( ch_count )
+                break;
+            else
+                ch_count = 1;
+        }
+        else
+            ch_count = 0;
+    }
+#else
+    size_t fsize = LIFEO::get_file_size( *m_ifstream );
+#endif
+
     try
     {
         // allocate memory for salt
@@ -406,7 +459,7 @@ Diary::read_encrypted()
         LIFEO::Cipher::expand_key( m_passphrase.c_str(), buf.salt, &buf.key );
 
         // calculate bytes of data in file
-        size_t size = LIFEO::get_file_size( *m_ifstream ) - m_ifstream->tellg();
+        size_t size = fsize - m_ifstream->tellg();
         if( size <= 3 )
         {
             buf.clear();
@@ -502,20 +555,72 @@ Diary::do_standard_checks_after_parse()
     }
 }
 
+inline void
+parse_theme( Theme* ptr2theme, const std::string& line )
+{
+    switch( line[ 1 ] )
+    {
+#ifndef LIFEO_WINDOZE
+        case 'f':   // font
+            ptr2theme->font = Pango::FontDescription( line.substr( 2 ) );
+            break;
+        case 'b':   // base color
+            ptr2theme->color_base.set( line.substr( 2 ) );
+            break;
+        case 't':   // text color
+            ptr2theme->color_text.set( line.substr( 2 ) );
+            break;
+        case 'h':   // heading color
+            ptr2theme->color_heading.set( line.substr( 2 ) );
+            break;
+        case 's':   // subheading color
+            ptr2theme->color_subheading.set( line.substr( 2 ) );
+            break;
+        case 'l':   // highlight color
+            ptr2theme->color_highlight.set( line.substr( 2 ) );
+            break;
+#else
+        case 'f':   // font
+            ptr2theme->font = line.substr( 2 );
+            break;
+        case 'b':   // base color
+            ptr2theme->color_base = line.substr( 2 );
+            break;
+        case 't':   // text color
+            ptr2theme->color_text = line.substr( 2 );
+            break;
+        case 'h':   // heading color
+            ptr2theme->color_heading = line.substr( 2 );
+            break;
+        case 's':   // subheading color
+            ptr2theme->color_subheading = line.substr( 2 );
+            break;
+        case 'l':   // highlight color
+            ptr2theme->color_highlight = line.substr( 2 );
+            break;
+#endif
+    }
+}
+
 // PARSING FUNCTIONS
 inline LIFEO::Result
 Diary::parse_db_body_text( std::istream& stream )
 {
-    if( m_read_version == 1020 )
-        return parse_db_body_text_1020( stream );
-    else if( m_read_version == 1010 || m_read_version == 1011 )
-        return parse_db_body_text_1010( stream );
-    else
-        return parse_db_body_text_110( stream );
+    switch( m_read_version )
+    {
+        case 1030:
+        case 1020:
+            return parse_db_body_text_1030( stream );
+        case 1011:
+        case 1010:
+            return parse_db_body_text_1010( stream );
+        default:
+            return parse_db_body_text_110( stream );
+    }
 }
 
 LIFEO::Result
-Diary::parse_db_body_text_1020( std::istream& stream )
+Diary::parse_db_body_text_1030( std::istream& stream )
 {
     std::string         line( "" );
     Entry*              entry_new = NULL;
@@ -554,28 +659,7 @@ Diary::parse_db_body_text_1020( std::istream& stream )
                         print_error( "No tag declared for theme" );
                         break;
                     }
-                    switch( line[ 1 ] )
-                    {
-                        case 'f':   // font
-                            ptr2tag->get_own_theme()->font =
-                                    Pango::FontDescription( line.substr( 2 ) );
-                            break;
-                        case 'b':   // base color
-                            ptr2tag->get_own_theme()->color_base.set( line.substr( 2 ) );
-                            break;
-                        case 't':   // text color
-                            ptr2tag->get_own_theme()->color_text.set( line.substr( 2 ) );
-                            break;
-                        case 'h':   // heading color
-                            ptr2tag->get_own_theme()->color_heading.set( line.substr( 2 ) );
-                            break;
-                        case 's':   // subheading color
-                            ptr2tag->get_own_theme()->color_subheading.set( line.substr( 2 ) );
-                            break;
-                        case 'l':   // highlight color
-                            ptr2tag->get_own_theme()->color_highlight.set( line.substr( 2 ) );
-                            break;
-                    }
+                    parse_theme( ptr2tag->get_own_theme(), line );
                     break;
                 case 'f':   // default filter
                     switch( line[ 1 ] )
@@ -628,16 +712,16 @@ Diary::parse_db_body_text_1020( std::istream& stream )
                                 break;
                             }
                             ptr2chapter = ptr2chapter_ctg->create_chapter(
-                                    get_db_line_name( line ), get_db_line_date( line ) );
+                                    get_db_line_name( line ), get_db_line_date( line ).m_date );
                             break;
                         case 'O':   // ordinal chapter (used to be called topic)
                             ptr2chapter = m_topics->create_chapter(
-                                    get_db_line_name( line ), get_db_line_date( line ) );
+                                    get_db_line_name( line ), get_db_line_date( line ).m_date );
                             break;
                         case 'G':   // free chapter (replaced todo_group in v1020)
                         case 'S':
                             ptr2chapter = m_groups->create_chapter(
-                                    get_db_line_name( line ), get_db_line_date( line ) );
+                                    get_db_line_name( line ), get_db_line_date( line ).m_date );
                             break;
                         case 'p':   // chapter preferences
                             ptr2chapter->set_expanded( line[ 2 ] == 'e' );
@@ -703,10 +787,18 @@ Diary::parse_db_body_text_1020( std::istream& stream )
                     print_error( "No entry declared" );
                     break;
                 }
-                if( line[ 1 ] == 'r' )
-                    entry_new->m_date_created = LIFEO::convert_string( line.substr( 2 ) );
-                else    // it should be 'h'
-                    entry_new->m_date_changed = LIFEO::convert_string( line.substr( 2 ) );
+                switch( line[ 1 ] )
+                {
+                    case 'r':
+                        entry_new->m_date_created = LIFEO::convert_string( line.substr( 2 ) );
+                        break;
+                    case 'h':
+                        entry_new->m_date_edited = LIFEO::convert_string( line.substr( 2 ) );
+                        break;
+                    case 's':
+                        entry_new->m_date_status = LIFEO::convert_string( line.substr( 2 ) );
+                        break;
+                }
                 break;
             case 'T':   // tag
                 if( entry_new == NULL )
@@ -760,6 +852,9 @@ Diary::parse_db_body_text_1020( std::istream& stream )
 
     m_filter_active->set( m_filter_default );   // employ the default filter
 
+    if( m_read_version == 1020 )
+        upgrade_entries();
+
     return LIFEO::SUCCESS;
 }
 
@@ -803,28 +898,7 @@ Diary::parse_db_body_text_1010( std::istream& stream )
                         print_error( "No tag declared for theme" );
                         break;
                     }
-                    switch( line[ 1 ] )
-                    {
-                        case 'f':   // font
-                            ptr2tag->get_own_theme()->font =
-                                    Pango::FontDescription( line.substr( 2 ) );
-                            break;
-                        case 'b':   // base color
-                            ptr2tag->get_own_theme()->color_base.set( line.substr( 2 ) );
-                            break;
-                        case 't':   // text color
-                            ptr2tag->get_own_theme()->color_text.set( line.substr( 2 ) );
-                            break;
-                        case 'h':   // heading color
-                            ptr2tag->get_own_theme()->color_heading.set( line.substr( 2 ) );
-                            break;
-                        case 's':   // subheading color
-                            ptr2tag->get_own_theme()->color_subheading.set( line.substr( 2 ) );
-                            break;
-                        case 'l':   // highlight color
-                            ptr2tag->get_own_theme()->color_highlight.set( line.substr( 2 ) );
-                            break;
-                    }
+                    parse_theme( ptr2tag->get_own_theme(), line );
                     break;
                 case 'f':   // default filter
                     switch( line[ 1 ] )
@@ -863,7 +937,7 @@ Diary::parse_db_body_text_1010( std::istream& stream )
                 case 'o':   // ordinal chapter (topic)
                     ptr2chapter = m_topics->create_chapter(
                             get_db_line_name( line ),
-                            fix_pre_1020_date( get_db_line_date( line ) ) );
+                            fix_pre_1020_date( get_db_line_date( line ) ).m_date );
                     ptr2chapter->set_expanded( line[ 1 ] == 'e' );
                     break;
                 case 'd':   // to-do group
@@ -871,7 +945,7 @@ Diary::parse_db_body_text_1010( std::istream& stream )
                     {
                         ptr2chapter = m_groups->create_chapter(
                                 get_db_line_name( line ),
-                                fix_pre_1020_date( get_db_line_date( line ) ) );
+                                fix_pre_1020_date( get_db_line_date( line ) ).m_date );
                     }
                     else // options
                     {
@@ -897,7 +971,7 @@ Diary::parse_db_body_text_1010( std::istream& stream )
                     }
                     ptr2chapter = ptr2chapter_ctg->create_chapter(
                             get_db_line_name( line ),
-                            fix_pre_1020_date( get_db_line_date( line ) ) );
+                            fix_pre_1020_date( get_db_line_date( line ) ).m_date );
                     ptr2chapter->set_expanded( line[ 1 ] == 'e' );
                     break;
                 case 'O':   // options
@@ -970,7 +1044,7 @@ Diary::parse_db_body_text_1010( std::istream& stream )
                 if( line[ 1 ] == 'r' )
                     entry_new->m_date_created = LIFEO::convert_string( line.substr( 2 ) );
                 else    // it should be 'h'
-                    entry_new->m_date_changed = LIFEO::convert_string( line.substr( 2 ) );
+                    entry_new->m_date_edited = LIFEO::convert_string( line.substr( 2 ) );
                 break;
             case 'T':   // tag
                 if( entry_new == NULL )
@@ -981,7 +1055,7 @@ Diary::parse_db_body_text_1010( std::istream& stream )
                     if( iter_tag != m_tags.end() )
                     {
                         entry_new->add_tag( iter_tag->second );
-                        if( line[1] == 'T' )
+                        if( line[ 1 ] == 'T' )
                             entry_new->set_theme_tag( iter_tag->second );
                     }
                     else
@@ -1024,6 +1098,8 @@ Diary::parse_db_body_text_1010( std::istream& stream )
 
     m_filter_active->set( m_filter_default );   // employ the default filter
 
+    upgrade_entries();
+
     return LIFEO::SUCCESS;
 }
 
@@ -1069,7 +1145,7 @@ Diary::parse_db_body_text_110( std::istream& stream )
                 case 'o':   // ordinal chapter (topic)
                     ptr2chapter = m_topics->create_chapter(
                             get_db_line_name( line ),
-                            fix_pre_1020_date( get_db_line_date( line ) ) );
+                            fix_pre_1020_date( get_db_line_date( line ) ).m_date );
                     ptr2chapter->set_expanded( line[ 1 ] == 'e' );
                     break;
                 case 'c':   // chapter
@@ -1080,7 +1156,7 @@ Diary::parse_db_body_text_110( std::istream& stream )
                     }
                     ptr2chapter = ptr2chapter_ctg->create_chapter(
                             get_db_line_name( line ),
-                            fix_pre_1020_date( get_db_line_date( line ) ) );
+                            fix_pre_1020_date( get_db_line_date( line ) ).m_date );
                     ptr2chapter->set_expanded( line[ 1 ] == 'e' );
                     break;
                 case 'M':
@@ -1096,27 +1172,7 @@ Diary::parse_db_body_text_110( std::istream& stream )
                         print_error( "No theme declared" );
                         break;
                     }
-                    switch( line[ 1 ] )
-                    {
-                        case 'f':   // font
-                            ptr2theme->font = Pango::FontDescription( line.substr( 2 ) );
-                            break;
-                        case 'b':   // base color
-                            ptr2theme->color_base.set( line.substr( 2 ) );
-                            break;
-                        case 't':   // text color
-                            ptr2theme->color_text.set( line.substr( 2 ) );
-                            break;
-                        case 'h':   // heading color
-                            ptr2theme->color_heading.set( line.substr( 2 ) );
-                            break;
-                        case 's':   // subheading color
-                            ptr2theme->color_subheading.set( line.substr( 2 ) );
-                            break;
-                        case 'l':   // highlight color
-                            ptr2theme->color_highlight.set( line.substr( 2 ) );
-                            break;
-                    }
+                    parse_theme( ptr2theme, line );
                     break;
                 case 'O':   // options
                     if( line.size() < 4 )
@@ -1177,7 +1233,7 @@ Diary::parse_db_body_text_110( std::istream& stream )
                 if( line[ 1 ] == 'r' )
                     entry_new->m_date_created = LIFEO::convert_string( line.substr( 2 ) );
                 else    // it should be 'h'
-                    entry_new->m_date_changed = LIFEO::convert_string( line.substr( 2 ) );
+                    entry_new->m_date_edited = LIFEO::convert_string( line.substr( 2 ) );
                 break;
             case 'M':   // themes are converted into tags
             case 'T':   // tag
@@ -1230,9 +1286,75 @@ Diary::parse_db_body_text_110( std::istream& stream )
     if( ptr2default_theme )
         m_untagged.create_own_theme_duplicating( ptr2default_theme );
 
+    upgrade_entries();
+
     return LIFEO::SUCCESS;
 }
 
+void
+Diary::upgrade_entries()
+{
+    for( EntryIterConst iter = m_entries.begin(); iter != m_entries.end(); ++iter )
+    {
+        Entry* entry = ( *iter ).second;
+
+        entry->m_date_status = entry->m_date_created; // initialize the status date
+
+        Wchar c;
+        Wchar lf( 'n' );
+        Ustring check;
+        Ustring new_content;
+
+        for( unsigned int i = 0; i < entry->m_text.size(); i++ )
+        {
+            switch( c = entry->m_text[ i ] )
+            {
+                case '\n':
+                case '\r':
+                    new_content += '\n';
+                case 0:     // should never be the case
+                    lf = 't'; // tab
+                    break;
+                case '\t':
+                    new_content += c;
+                    lf = ( lf == 't' || lf == 'c' ) ? 'c' : 'n';
+                    break;
+                case L'☐':
+                    check = "[ ] ";
+                    new_content += c;
+                    lf = lf == 'c' ? 's' : 'n';
+                    break;
+                case L'☑':
+                    check = "[+] ";
+                    new_content += c;
+                    lf = lf == 'c' ? 's' : 'n';
+                    break;
+                case L'☒':
+                    check = "[x] ";
+                    new_content += c;
+                    lf = lf == 'c' ? 's' : 'n';
+                    break;
+                case ' ':
+                    if( lf == 's' )
+                    {
+                        new_content.erase( new_content.size() - 1, 1 );
+                        new_content += check;
+                    }
+                    else
+                        new_content += c;
+                    lf = 'n';
+                    break;
+                default:
+                    new_content += c;
+                    lf = 'n';
+                    break;
+            }
+        }
+
+        entry->m_text = new_content;
+    }
+}
+
 LIFEO::Result
 Diary::write()
 {
@@ -1243,7 +1365,7 @@ Diary::write()
         copy_file_suffix( m_path, ".", m_read_version );
 
     // BACKUP THE PREVIOUS VERSION
-    if( Glib::file_test( m_path, Glib::FILE_TEST_EXISTS ) )
+    if( access( m_path.c_str(), F_OK ) == 0 )
     {
         std::string path_old( m_path + ".~previousversion~" );
         rename( m_path.c_str(), path_old.c_str() );
@@ -1255,7 +1377,7 @@ Diary::write()
     // DAILY BACKUP SAVES
 #if LIFEOGRAPH_DEBUG_BUILD
     if( copy_file_suffix(
-            m_path, "." + Date::format_string( Date::get_today(), "%1-%2-%3" ), -1 ) )
+            m_path, "." + Date::format_string( Date::get_today(), "YMD", '-' ), -1 ) )
         print_info( "daily backup has been written successfully" );
 #endif
 
@@ -1314,7 +1436,7 @@ Diary::write_txt( const std::string& path, bool flag_filtered )
     const std::string separator_chapter = ":::::::::::::::::::::::::::::::::::::::::::::\n";
 
     // DIARY TITLE
-    file << separator_thick << Glib::filename_display_basename( path ) << '\n' << separator_thick;
+    file << separator_thick << get_filename_base( path ) << '\n' << separator_thick;
 
     // ENTRIES
     for( int i = 0; i < 4; i++ )
@@ -1390,7 +1512,8 @@ Diary::write_txt( const std::string& path, bool flag_filtered )
 LIFEO::Result
 Diary::write_plain( const std::string& path, bool flag_header_only )
 {
-    std::ofstream file( path.c_str(), std::ios::out | std::ios::trunc );
+    // NOTE: ios::binary prevents windows to use \r\n for line ends
+    std::ofstream file( path.c_str(), std::ios::binary | std::ios::out | std::ios::trunc );
     if( ! file.is_open() )
     {
         print_error( "i/o error: " + path );
@@ -1478,12 +1601,21 @@ Diary::create_db_tag_text( char type, const Tag* tag, std::stringstream& output
     {
         Theme* theme( tag->get_theme() );
 
+#ifndef LIFEO_WINDOZE
         output << type << 'f' << theme->font.to_string() << '\n';
         output << type << 'b' << convert_gdkrgba_to_string( theme->color_base ) << '\n';
         output << type << 't' << convert_gdkrgba_to_string( theme->color_text ) << '\n';
         output << type << 'h' << convert_gdkrgba_to_string( theme->color_heading ) << '\n';
         output << type << 's' << convert_gdkrgba_to_string( theme->color_subheading ) << '\n';
         output << type << 'l' << convert_gdkrgba_to_string( theme->color_highlight ) << '\n';
+#else
+        output << type << 'f' << theme->font << '\n';
+        output << type << 'b' << theme->color_base << '\n';
+        output << type << 't' << theme->color_text << '\n';
+        output << type << 'h' << theme->color_heading << '\n';
+        output << type << 's' << theme->color_subheading << '\n';
+        output << type << 'l' << theme->color_highlight << '\n';
+#endif
     }
 }
 
@@ -1634,7 +1766,8 @@ Diary::create_db_body_text( std::stringstream& output )
         output << entry->m_date.m_date << '\n';
 
         output << "Dr" << entry->m_date_created << '\n';
-        output << "Dh" << entry->m_date_changed << '\n';
+        output << "Dh" << entry->m_date_edited << '\n';
+        output << "Ds" << entry->m_date_status << '\n';
 
         // TAGS
         for( Tagset::const_iterator iter_tag = entry->m_tags.begin();
@@ -1773,7 +1906,7 @@ Diary::remove_lock()
         return false;
 
     std::string path_lock( m_path + LOCK_SUFFIX );
-    if( Glib::file_test( path_lock, Glib::FILE_TEST_EXISTS ) )
+    if( access( path_lock.c_str(), F_OK ) == 0 )
         remove( path_lock.c_str() );
     return true;
 }
@@ -1891,7 +2024,7 @@ Diary::is_last( Entry const* const entry ) const
 }
 
 Entry*
-Diary::create_entry( Date::date_t date, const Glib::ustring& content, bool flag_favorite )
+Diary::create_entry( Date::date_t date, const Ustring& content, bool flag_favorite )
 {
     // make it the last entry of its day:
     Date::reset_order_1( date );
@@ -2011,16 +2144,16 @@ Diary::make_free_entry_order( Date& date ) const
 
 // FILTERING =======================================================================================
 void
-Diary::set_search_text( const Glib::ustring& text )
+Diary::set_search_text( const Ustring& text )
 {
     m_search_text = text;
     m_filter_active->set_status_outstanding();
 }
 
 int
-Diary::replace_text( const Glib::ustring& newtext )
+Diary::replace_text( const Ustring& newtext )
 {
-    Glib::ustring::size_type iter_str;
+    Ustring::size_type iter_str;
     const int chardiff = newtext.size() - m_search_text.size();
 
     Entry* entry;
@@ -2032,8 +2165,11 @@ Diary::replace_text( const Glib::ustring& newtext )
         entry = iter_entry->second;
         if( entry->get_filtered_out() )
             continue;
-
-        Glib::ustring entrytext = entry->get_text().lowercase();
+#ifndef LIFEO_WINDOZE
+        Ustring entrytext = entry->get_text().lowercase();
+#else
+        Ustring entrytext = entry->get_text();
+#endif
         iter_str = 0;
         int count = 0;
         while( ( iter_str = entrytext.find( m_search_text, iter_str ) ) != std::string::npos )
@@ -2052,7 +2188,7 @@ Diary::replace_text( const Glib::ustring& newtext )
 
 // TAGS ============================================================================================
 Tag*
-Diary::create_tag( const Glib::ustring& name, CategoryTags* category )
+Diary::create_tag( const Ustring& name, CategoryTags* category )
 {
     PoolTags::iterator iter = m_tags.find( name );
     if( iter != m_tags.end() )
@@ -2101,8 +2237,8 @@ Diary::dismiss_tag( Tag* tag, bool flag_dismiss_associated )
 CategoryTags*
 Diary::create_tag_ctg()
 {
-    Glib::ustring name = create_unique_name_for_map( m_tag_categories,
-                                                     _( STRING::NEW_CATEGORY_NAME ) );
+    Ustring name = create_unique_name_for_map( m_tag_categories,
+                                               _( STRING::NEW_CATEGORY_NAME ) );
     CategoryTags* new_category = new CategoryTags( this, name );
     m_tag_categories.insert( PoolCategoriesTags::value_type( name, new_category ) );
 
@@ -2110,7 +2246,7 @@ Diary::create_tag_ctg()
 }
 
 CategoryTags*
-Diary::create_tag_ctg( const Glib::ustring& name )  // used while reading diary file
+Diary::create_tag_ctg( const Ustring& name )  // used while reading diary file
 {
     try
     {
@@ -2148,8 +2284,8 @@ Diary::dismiss_tag_ctg( CategoryTags* ctg, bool flag_dismiss_contained )
 CategoryChapters*
 Diary::create_chapter_ctg()
 {
-    Glib::ustring name = create_unique_name_for_map( m_chapter_categories,
-                                                     _( STRING::NEW_CATEGORY_NAME ) );
+    Ustring name = create_unique_name_for_map( m_chapter_categories,
+                                               _( STRING::NEW_CATEGORY_NAME ) );
     CategoryChapters* category = new CategoryChapters( this, name );
     m_chapter_categories.insert( PoolCategoriesChapters::value_type( name, category ) );
 
@@ -2157,7 +2293,7 @@ Diary::create_chapter_ctg()
 }
 
 CategoryChapters*
-Diary::create_chapter_ctg( const Glib::ustring& name )
+Diary::create_chapter_ctg( const Ustring& name )
 {
     // name's availability must be checked beforehand
     try
@@ -2186,7 +2322,7 @@ Diary::dismiss_chapter_ctg( CategoryChapters* category )
 }
 
 bool
-Diary::rename_chapter_ctg( CategoryChapters* category, const Glib::ustring& new_name )
+Diary::rename_chapter_ctg( CategoryChapters* category, const Ustring& new_name )
 {
     if( m_chapter_categories.count( new_name ) > 0 )
         return false;
@@ -2526,7 +2662,7 @@ Diary::import_tag( Tag* tag )
 bool
 Diary::import_entries( const Diary& diary,
                        bool flag_import_tags,
-                       const Glib::ustring &tag_all_str )
+                       const Ustring& tag_all_str )
 {
     Entry* entry_new;
     Entry* entry_ext;
@@ -2550,9 +2686,10 @@ Diary::import_entries( const Diary& diary,
         while( m_entries.find( entry_new->m_date.m_date ) != m_entries.end() )
             entry_new->m_date.m_date++;
 
-        // copy dates:
+        // copy other data:
         entry_new->m_date_created = entry_ext->m_date_created;
-        entry_new->m_date_changed = entry_ext->m_date_changed;
+        entry_new->m_date_edited = entry_ext->m_date_edited;
+        entry_new->m_date_status = entry_ext->m_date_status;
 
         // insert it into the diary:
         m_entries[ entry_new->m_date.m_date ] = entry_new;
@@ -2560,7 +2697,7 @@ Diary::import_entries( const Diary& diary,
 
         if( flag_import_tags )
         {
-            Tagset &tags = entry_ext->get_tags();
+            Tagset& tags = entry_ext->get_tags();
             Tag* tag;
 
             for( Tagset::const_iterator iter = tags.begin(); iter != tags.end(); ++iter )
@@ -2601,7 +2738,7 @@ Diary::import_chapters( const Diary& diary )
         for( CategoryChapters::iterator i_c = cc->begin(); i_c != cc->end(); ++i_c )
         {
             Chapter* chapter( i_c->second );
-            cc_new->create_chapter( chapter->get_name(), chapter->get_date() );
+            cc_new->create_chapter( chapter->get_name(), chapter->get_date().m_date );
         }
     }
 
