@@ -22,6 +22,7 @@
 
 #include "diarydata.hpp"
 #include "lifeograph.hpp"
+#include "strings.hpp"
 
 #include <cassert>
 
@@ -42,18 +43,23 @@ LIFEO::compare_listitems_by_name( DiaryElement* item_l, DiaryElement* item_r )
 }
 
 bool
-LIFEO::compare_names( const Glib::ustring& name_l, const Glib::ustring& name_r )
+LIFEO::compare_names( const Ustring& name_l, const Ustring& name_r )
 {
     return( name_l < name_r );
 }
 
 // DIARYELEMENT ====================================================================================
 // STATIC MEMBERS
+#ifndef LIFEO_WINDOZE
 ListData::Colrec*                   ListData::colrec;
+const Icon                          DiaryElement::s_pixbuf_null;
+#else
+const Icon                          DiaryElement::s_pixbuf_null = NULL;
+#endif
 bool                                DiaryElement::FLAG_ALLOCATE_GUI_FOR_DIARY = true;
-const Glib::RefPtr< Gdk::Pixbuf >   DiaryElement::s_pixbuf_null;
-const Glib::ustring DiaryElement::s_type_names[] =
-{   "", _( "Tag" ), _( "Untagged" ), _( "Tag Category" ), _( "Chapter Category" ),
+const Ustring                       DiaryElement::s_type_names[] =
+{
+    "", _( "Tag" ), _( "Untagged" ), _( "Tag Category" ), _( "Chapter Category" ),
     // TRANSLATORS: filter is a noun here
     _( "Filter" ),
     _( "Diary" ), _( "Dated Chapter" ), _( "Numbered Chapter" ),
@@ -62,24 +68,28 @@ const Glib::ustring DiaryElement::s_type_names[] =
 
 DiaryElement::DiaryElement()
 :   NamedElement( "" ), m_list_data( NULL ), m_ptr2diary( NULL ), m_id( DEID_UNSET ),
-    m_status( ES::VOID )
+    m_status( ES::_VOID_ )
 {
 }
 DiaryElement::DiaryElement( Diary* const ptr2diary,
-                            const Glib::ustring& name,
+                            const Ustring& name,
                             ElemStatus status )
 :   NamedElement( name ), m_ptr2diary( ptr2diary ),
     m_id( ptr2diary ? ptr2diary->create_new_id( this ) :  DEID_UNSET ),
     m_status( status )
 {
+#ifndef LIFEO_WINDOZE
     if( FLAG_ALLOCATE_GUI_FOR_DIARY )
         m_list_data = new ListData;
+#endif
 }
 DiaryElement::DiaryElement( Diary* const ptr2diary, DEID id, ElemStatus status )
 :   NamedElement( "" ), m_ptr2diary( ptr2diary ), m_id( id ), m_status( status )
 {
+#ifndef LIFEO_WINDOZE
     if( FLAG_ALLOCATE_GUI_FOR_DIARY )
         m_list_data = new ListData;
+#endif
 }
 
 DiaryElement::~DiaryElement()
@@ -99,8 +109,8 @@ DiaryElement::set_todo_status( ElemStatus s )
 // STATIC MEMBERS
 ElementShower< Tag >* Tag::shower( NULL );
 
-Tag::Tag( Diary* const d, const Glib::ustring& name, CategoryTags* category )
-:   DiaryElementReferrer( d, name, ES::VOID ), m_ptr2category( category ), m_theme( NULL )
+Tag::Tag( Diary* const d, const Ustring& name, CategoryTags* category )
+:   DiaryElementReferrer( d, name, ES::_VOID_ ), m_ptr2category( category ), m_theme( NULL )
 {
     if( category != NULL )
         category->insert( this );
@@ -110,17 +120,24 @@ Tag::~Tag()
 {
 }
 
-const Glib::RefPtr< Gdk::Pixbuf >&
+#ifndef LIFEO_WINDOZE
+const Icon&
 Tag::get_icon() const
 {
     return( get_has_own_theme() ? Lifeograph::icons->tag_theme_16 : Lifeograph::icons->tag_16 );
 }
-
-const Glib::RefPtr< Gdk::Pixbuf >&
+const Icon&
 Tag::get_icon32() const
 {
     return( get_has_own_theme() ? Lifeograph::icons->tag_theme_32 : Lifeograph::icons->tag_32 );
 }
+#else
+int
+Tag::get_icon() const
+{
+    return( get_has_own_theme() ? ICON_NO_TAG_THEME : ICON_NO_TAG );
+}
+#endif
 
 void
 Tag::show()
@@ -132,7 +149,7 @@ Tag::show()
 }
 
 void
-Tag::set_name( const Glib::ustring& name )
+Tag::set_name( const Ustring& name )
 {
     m_name = name;
 }
@@ -208,23 +225,34 @@ Untagged::Untagged()
 
 }
 
-Glib::ustring
+Ustring
 Untagged::get_list_str() const
 {
+#ifndef LIFEO_WINDOZE
     return( "<i>" + Glib::Markup::escape_text( m_name ) + "</i>" );
+#else
+    return( m_name ); // FIXME
+#endif
 }
 
-const Glib::RefPtr< Gdk::Pixbuf >&
+#ifndef LIFEO_WINDOZE
+const Icon&
 Untagged::get_icon() const
 {
     return Lifeograph::icons->untagged_16;
 }
-
-const Glib::RefPtr< Gdk::Pixbuf >&
+const Icon&
 Untagged::get_icon32() const
 {
     return Lifeograph::icons->untagged_32;
 }
+#else
+int
+Untagged::get_icon() const
+{
+    return ICON_NO_UNTAGGED;
+}
+#endif
 
 // TAGPOOL =========================================================================================
 PoolTags::~PoolTags()
@@ -245,7 +273,7 @@ PoolTags::get_tag( unsigned int tagorder )
 }
 
 Tag*
-PoolTags::get_tag( const Glib::ustring& name )
+PoolTags::get_tag( const Ustring& name )
 {
     iterator iter = find( name );
     if( iter != end() )
@@ -255,7 +283,7 @@ PoolTags::get_tag( const Glib::ustring& name )
 }
 
 bool
-PoolTags::rename( Tag* tag, const Glib::ustring& new_name )
+PoolTags::rename( Tag* tag, const Ustring& new_name )
 {
     erase( tag->m_name );
     tag->m_name = new_name;
@@ -268,28 +296,36 @@ PoolTags::clear()
     for( iterator iter = begin(); iter != end(); ++iter )
         delete iter->second;
 
-    std::map< Glib::ustring, Tag*, FuncCompareStrings >::clear();
+    std::map< Ustring, Tag*, FuncCompareStrings >::clear();
 }
 
 // CATEGORYTAGS ====================================================================================
 // STATIC MEMBERS
 ElementShower< CategoryTags >* CategoryTags::shower( NULL );
 
-CategoryTags::CategoryTags( Diary* const d, const Glib::ustring& name )
+CategoryTags::CategoryTags( Diary* const d, const Ustring& name )
 :   DiaryElementReferrer( d, name, ES::EXPANDED, compare_listitems_by_name )
 {
 }
 
-const Glib::RefPtr< Gdk::Pixbuf >&
+#ifndef LIFEO_WINDOZE
+const Icon&
 CategoryTags::get_icon() const
 {
     return Lifeograph::icons->tag_category_16;
 }
-const Glib::RefPtr< Gdk::Pixbuf >&
+const Icon&
 CategoryTags::get_icon32() const
 {
     return Lifeograph::icons->tag_category_32;
 }
+#else
+int
+CategoryTags::get_icon() const
+{
+    return ICON_NO_TAG_CTG;
+}
+#endif
 
 void
 CategoryTags::show()
@@ -302,7 +338,7 @@ CategoryTags::show()
 
 // POOL OF DEFINED TAG CATEGORIES
 PoolCategoriesTags::PoolCategoriesTags()
-:   std::map< Glib::ustring, CategoryTags*, FuncCompareStrings >( compare_names )
+:   std::map< Ustring, CategoryTags*, FuncCompareStrings >( compare_names )
 {
 }
 
@@ -322,11 +358,11 @@ PoolCategoriesTags::clear()
         delete iter->second;
     }
 
-    std::map< Glib::ustring, CategoryTags*, FuncCompareStrings >::clear();
+    std::map< Ustring, CategoryTags*, FuncCompareStrings >::clear();
 }
 
 bool
-PoolCategoriesTags::rename_category( CategoryTags* category, const Glib::ustring& new_name )
+PoolCategoriesTags::rename_category( CategoryTags* category, const Ustring& new_name )
 {
     erase( category->m_name );
     category->m_name = new_name;
@@ -377,13 +413,14 @@ Tagset::get_tag( unsigned int tagorder ) const
 // STATIC MEMBERS
 ElementShower< Chapter >* Chapter::shower( NULL );
 
-Chapter::Chapter( Diary* const d, const Glib::ustring& name, Date::date_t date )
+Chapter::Chapter( Diary* const d, const Ustring& name, Date::date_t date )
 :   DiaryElementReferrer( d, name, ES::CHAPTER_DEFAULT ), m_date_begin( date ), m_time_span( 0 )
 {
     update_type();
 }
 
-const Glib::RefPtr< Gdk::Pixbuf >&
+#ifndef LIFEO_WINDOZE
+const Icon&
 Chapter::get_icon() const
 {
     switch( m_status & ES::FILTER_TODO )
@@ -401,7 +438,7 @@ Chapter::get_icon() const
                     Lifeograph::icons->chapter_16 : Lifeograph::icons->month_16 );
     }
 }
-const Glib::RefPtr< Gdk::Pixbuf >&
+const Icon&
 Chapter::get_icon32() const
 {
     switch( m_status & ES::FILTER_TODO )
@@ -420,15 +457,41 @@ Chapter::get_icon32() const
     }
 
 }
+#else
+int
+Chapter::get_icon() const
+{
+    switch( m_status & ES::FILTER_TODO )
+    {
+        case ES::TODO:
+            return ICON_NO_TODO;
+        case ES::PROGRESSED:
+            return ICON_NO_PROGRESSED;
+        case ES::DONE:
+            return ICON_NO_DONE;
+        case ES::CANCELED:
+            return ICON_NO_CANCELED;
+        default:
+            return( m_date_begin.is_ordinal() ?
+                    ICON_NO_CHAPTER_O : ICON_NO_CHAPTER_D );
+    }
+}
+#endif
 
-Glib::ustring
+Ustring
 Chapter::get_list_str() const
 {
     if( m_date_begin.is_hidden() )
+#ifndef LIFEO_WINDOZE
         return Glib::ustring::compose( "<b>%1</b>", Glib::Markup::escape_text( m_name ) );
 //    else
         return Glib::ustring::compose( "<b>%1 -  %2</b>", m_date_begin.format_string(),
                     Glib::Markup::escape_text( m_name ) );
+#else // FIXME
+        return m_name;
+//    else
+        return STR::compose( m_date_begin.format_string(), " -  ", m_name );
+#endif
 }
 
 void
@@ -442,12 +505,12 @@ Chapter::show()
 }
 
 void
-Chapter::set_name( const Glib::ustring& name )
+Chapter::set_name( const Ustring& name )
 {
     m_name = name;
 }
 
-Glib::ustring
+Ustring
 Chapter::get_date_str() const
 {
     return m_date_begin.format_string();
@@ -490,7 +553,7 @@ Chapter::recalculate_span( const Chapter* next )
 }
 
 // CHAPTER CATEGORY ================================================================================
-CategoryChapters::CategoryChapters( Diary* const d, const Glib::ustring& name )
+CategoryChapters::CategoryChapters( Diary* const d, const Ustring& name )
 :   DiaryElement( d, name ),
     std::map< Date::date_t, Chapter*, FuncCompareDates >( compare_dates ),
     m_date_min( 0 )
@@ -517,16 +580,16 @@ CategoryChapters::get_chapter( const Date::date_t date ) const
 }
 
 Chapter*
-CategoryChapters::create_chapter( const Glib::ustring& name, const Date& date )
+CategoryChapters::create_chapter( const Ustring& name, const Date::date_t date )
 {
-    Chapter* chapter = new Chapter( m_ptr2diary, name, date.m_date );
+    Chapter* chapter = new Chapter( m_ptr2diary, name, date );
 
     add( chapter );
 
     return chapter;
 }
 Chapter*
-CategoryChapters::create_chapter_ordinal( const Glib::ustring& name )
+CategoryChapters::create_chapter_ordinal( const Ustring& name )
 {
     return create_chapter( name, get_free_order_ordinal() );
 }
@@ -535,6 +598,7 @@ bool
 CategoryChapters::set_chapter_date( Chapter* chapter, Date::date_t date )
 {
     assert( chapter->is_ordinal() == false );
+    assert( find( date ) == end() );
 
     if( chapter->m_date_begin.m_date != Date::NOT_SET )
     {
@@ -552,33 +616,6 @@ CategoryChapters::set_chapter_date( Chapter* chapter, Date::date_t date )
         }
 
         erase( chapter->m_date_begin.m_date );
-
-        if( find( date ) != end() ) // if target is taken move chapters
-        {
-            // FIXME "chapter->m_date_begin.is_ordinal() ?" conflicts with the assertion above:
-            Date::date_t d( chapter->m_date_begin.is_ordinal() ?
-                            chapter->m_date_begin.m_date : get_free_order_ordinal().m_date );
-                            // if a temporal chapter is being converted..
-                            // ..assume that it was the last
-            Date::date_t step( chapter->m_date_begin.m_date > date ?
-                                        -Date::ORDINAL_STEP : Date::ORDINAL_STEP );
-
-            for( d += step; ; d += step )
-            {
-                iter = find( d );
-                if( iter == end() )
-                    break;
-
-                Chapter *chapter_shift( iter->second );
-                erase( d );
-                chapter_shift->set_date( d - step );
-                insert( CategoryChapters::value_type( chapter_shift->m_date_begin.m_date,
-                                                      chapter_shift ) );
-
-                if( d == date )
-                    break;
-            }
-        }
     }
 
     chapter->set_date( date );
@@ -618,17 +655,17 @@ CategoryChapters::clear()
     std::map< Date::date_t, Chapter*, FuncCompareDates >::clear();
 }
 
-Date
+Date::date_t
 CategoryChapters::get_free_order_ordinal() const
 {
     assert( m_date_min );   // only for ordinal chapter categories
 
     if( empty() )
-        return Date( m_date_min );
+        return m_date_min;
 
     Date d( begin()->first );
     d.forward_ordinal_order();
-    return d;
+    return d.m_date;
 
 }
 
@@ -644,23 +681,30 @@ PoolCategoriesChapters::clear()
     for( PoolCategoriesChapters::iterator iter = begin(); iter != end(); ++iter )
         delete( iter->second );
 
-    std::map< Glib::ustring, CategoryChapters*, FuncCompareStrings >::clear();
+    std::map< Ustring, CategoryChapters*, FuncCompareStrings >::clear();
 }
 
 // THEMES ==========================================================================================
 // STATIC MEMBERS
-const Gdk::RGBA Theme::s_color_match1( "#33FF33" );
-const Gdk::RGBA Theme::s_color_match2( "#009900" );
-const Gdk::RGBA Theme::s_color_link1( "#3333FF" );
-const Gdk::RGBA Theme::s_color_link2( "#000099" );
-const Gdk::RGBA Theme::s_color_broken1( "#FF3333" );
-const Gdk::RGBA Theme::s_color_broken2( "#990000" );
+const Color Theme::s_color_match1( "#33FF33" );
+const Color Theme::s_color_match2( "#009900" );
+const Color Theme::s_color_link1( "#3333FF" );
+const Color Theme::s_color_link2( "#000099" );
+const Color Theme::s_color_broken1( "#FF3333" );
+const Color Theme::s_color_broken2( "#990000" );
+
+const Color Theme::s_color_todo( "#FF0000" );
+const Color Theme::s_color_progressed( "#FF8811" );
+const Color Theme::s_color_done( "#66BB00" );
+const Color Theme::s_color_done1( "#77CC11" );
+const Color Theme::s_color_done2( "#409000" );
+const Color Theme::s_color_canceled( "#AA8855" );
 
 Theme::Theme()
 {
 }
 
-Theme::Theme( const Glib::ustring& str_font,
+Theme::Theme( const Ustring& str_font,
               const std::string& str_base,
               const std::string& str_text,
               const std::string& str_heading,
@@ -682,7 +726,7 @@ Theme::Theme( const Theme* theme )
 {
 }
 
-ThemeSystem::ThemeSystem( const Glib::ustring& f,
+ThemeSystem::ThemeSystem( const Ustring& f,
                           const std::string& cb,
                           const std::string& ct,
                           const std::string& ch,
@@ -700,6 +744,7 @@ ThemeSystem::get()
 
     if( ! s_flag_initialized )
     {
+#ifndef LIFEO_WINDOZE
         // this may not be the best method to detect the default font:
         Gtk::TextView *tv = new Gtk::TextView;
         tv->show();
@@ -708,6 +753,13 @@ ThemeSystem::get()
                                    "blue", "#F066FC",
                                    "#FFF955" );
         delete tv;
+#else
+        s_theme = new ThemeSystem( "sans 11",
+                                   "#FFFFFFFFFFFF", "#000000000000",
+                                   "#00000000FFFF", "#F0F06666FCFC",
+                                   "#FFFFF9F95555" );
+
+#endif
         s_flag_initialized = true;
         return s_theme;
     }
@@ -720,23 +772,24 @@ ThemeSystem::get()
 // FILTERS =========================================================================================
 ElementShower< Filter >* Filter::shower( NULL );
 
-Filter::Filter( Diary* const d, const Glib::ustring& name )
+Filter::Filter( Diary* const d, const Ustring& name )
 :   DiaryElement( d, name, ES::FILTER_RESET ), m_tag( NULL ),
     m_date_begin( 0 ), m_date_end( Date::DATE_MAX )
 {
 }
 
-const Glib::RefPtr< Gdk::Pixbuf >&
+#ifndef LIFEO_WINDOZE
+const Icon&
 Filter::get_icon() const
 {
     return Lifeograph::icons->filter_16;
 }
-
-const Glib::RefPtr< Gdk::Pixbuf >&
+const Icon&
 Filter::get_icon32() const
 {
     return Lifeograph::icons->filter_32;
 }
+#endif
 
 void
 Filter::show()
