@@ -26,9 +26,12 @@
 
 #include "helpers.hpp"	// i18n headers
 
+#ifndef LIFEO_WINDOZE
 #include <gtkmm/treemodel.h>
+#endif
 #include <set>
-
+#include <map>
+#include <vector>
 
 namespace LIFEO
 {
@@ -37,7 +40,7 @@ using namespace HELPERS;
 
 typedef char SortingCriteria;
 static const SortingCriteria SC_DATE    = 'd';
-static const SortingCriteria SC_SIZE    = 's';
+static const SortingCriteria SC_SIZE_C  = 's';  // size (char count)
 static const SortingCriteria SC_CHANGE  = 'c';  // last change date
 
 typedef unsigned long DEID; // unique diary element id
@@ -51,7 +54,7 @@ static const DEID HOME_FIXED_ELEM = 3;      // element shown at startup (defines
 typedef unsigned long ElemStatus;
 namespace ES
 {
-    static const ElemStatus VOID             = 0x0;
+    static const ElemStatus _VOID_           = 0x0;
     static const ElemStatus EXPANDED         = 0x40;
 
     static const ElemStatus NOT_FAVORED      = 0x100;
@@ -101,7 +104,11 @@ class Untagged;         // forward declaration
 class Entry;            // forward declaration
 class Filter;           // forward declaration
 class Diary;            // forward declaration
+#ifndef LIFEO_WINDOZE
 class ListData;	        // forward declaration
+#else
+#include <commctrl.h>
+#endif
 
 typedef std::vector< Entry* >               EntryVector;
 typedef std::vector< Entry* >::iterator     EntryVectorIter;
@@ -116,28 +123,27 @@ class NamedElement
 {
     public:
                                 NamedElement() : m_name( "" ) {}
-                                NamedElement( const Glib::ustring &name ) : m_name( name ) {}
+                                NamedElement( const Ustring& name ) : m_name( name ) {}
         virtual                 ~NamedElement() {}  //needed because of virtual methods
 
-        Glib::ustring           get_name() const
+        Ustring                 get_name() const
         { return m_name; }
         std::string             get_name_std() const  // std::string version
         { return m_name; }
-        void                    set_name( const Glib::ustring &name )
+        void                    set_name( const Ustring& name )
         { m_name = name; }
 
     protected:
-        Glib::ustring           m_name;
+        Ustring                 m_name;
 };
 
 class DiaryElement : public NamedElement
 {
     public:
         static bool             FLAG_ALLOCATE_GUI_FOR_DIARY;
-        static const Glib::RefPtr< Gdk::Pixbuf >
-                                s_pixbuf_null;
-        static const Glib::ustring
-                                s_type_names[];
+
+        static const Icon       s_pixbuf_null;
+        static const Ustring    s_type_names[];
 
         enum Type
         {   // CAUTION: order is significant and shouldn't be changed!
@@ -149,27 +155,43 @@ class DiaryElement : public NamedElement
             ET_HEADER
         };
                                 DiaryElement(); // only for pseudo elements
-                                DiaryElement( Diary* const, const Glib::ustring&,
-                                              ElemStatus = ES::VOID );
-                                DiaryElement( Diary* const, DEID, ElemStatus = ES::VOID );
+                                DiaryElement( Diary* const, const Ustring&,
+                                              ElemStatus = ES::_VOID_ );
+                                DiaryElement( Diary* const, DEID, ElemStatus = ES::_VOID_ );
         virtual                 ~DiaryElement();
 
         virtual Type            get_type() const = 0;
-        Glib::ustring           get_type_name()
+        Ustring                 get_type_name()
         { return s_type_names[ get_type() ]; }
         virtual int             get_size() const = 0;
-        virtual const Glib::RefPtr< Gdk::Pixbuf >&
-                                get_icon() const
+#ifndef LIFEO_WINDOZE
+        virtual const Icon&     get_icon() const
         { return( s_pixbuf_null ); }
-        virtual const Glib::RefPtr< Gdk::Pixbuf >&
-                                get_icon32() const
+        virtual const Icon&     get_icon32() const
         { return( s_pixbuf_null ); }
+
+#else
+#define ICON_NO_DIARY          0
+#define ICON_NO_ENTRY          1
+#define ICON_NO_TODO           2
+#define ICON_NO_PROGRESSED     3
+#define ICON_NO_DONE           4
+#define ICON_NO_CANCELED       5
+#define ICON_NO_CHAPTER_D      6
+#define ICON_NO_CHAPTER_O      7
+#define ICON_NO_TAG            8
+#define ICON_NO_TAG_THEME      9
+#define ICON_NO_UNTAGGED       10
+#define ICON_NO_TAG_CTG        11
+        virtual int             get_icon() const { return 0; }
+#endif
+
         virtual Date            get_date() const
         { return Date( Date::NOT_APPLICABLE ); }
         Date::date_t            get_date_t() const
         { return get_date().m_date; }
 
-        virtual Glib::ustring   get_list_str() const
+        virtual Ustring         get_list_str() const
         { return ""; }
 
         DEID                    get_id() const
@@ -201,7 +223,11 @@ class DiaryElement : public NamedElement
         virtual bool            is_favored() const
         { return false; }
 
+#ifndef LIFEO_WINDOZE
         ListData*               m_list_data;
+#else
+        HTREEITEM               m_list_data;
+#endif
 
     protected:
         Diary* const            m_ptr2diary;
@@ -210,6 +236,7 @@ class DiaryElement : public NamedElement
         ElemStatus              m_status;
 };
 
+#ifndef LIFEO_WINDOZE
 class ListData
 {
     public:
@@ -234,25 +261,28 @@ class ListData
 
         Gtk::TreePath           treepath;
 };
+#endif
 
 bool compare_listitems( DiaryElement*, DiaryElement* );
 bool compare_listitems_by_name( DiaryElement*, DiaryElement* );
-bool compare_names( const Glib::ustring&, const Glib::ustring& );
+bool compare_names( const Ustring&, const Ustring& );
 
-typedef bool( *FuncCompareStrings )( const Glib::ustring&, const Glib::ustring& ) ;
+typedef bool( *FuncCompareStrings )( const Ustring&, const Ustring& ) ;
 typedef bool( *FuncCompareDiaryElem )( DiaryElement*, DiaryElement* ) ;
 
 template< class T >
-Glib::ustring
-create_unique_name_for_map( const std::map< Glib::ustring, T*, FuncCompareStrings > &map,
-                            const Glib::ustring &name0 )
+Ustring
+create_unique_name_for_map( const std::map< Ustring, T*, FuncCompareStrings > &map,
+                            const Ustring &name0 )
 {
-    Glib::ustring name = name0;
-    for( int i = 1;
-         map.find( name ) != map.end();
-         i++ )
+    Ustring name = name0;
+    for( int i = 1; map.find( name ) != map.end(); i++ )
     {
+#ifndef LIFEO_WINDOZE
         name = Glib::ustring::compose( "%1 %2", name0, i );
+#else
+        name = STR::compose( name0, " ", i );
+#endif
     }
 
     return name;
@@ -263,35 +293,41 @@ create_unique_name_for_map( const std::map< Glib::ustring, T*, FuncCompareString
 class ElementShowerProto
 {
     public:
+#ifndef LIFEO_WINDOZE
         ElementShowerProto() : m_grid_popover( NULL ) {}
+#endif
         virtual             ~ElementShowerProto() {}
 
         virtual DiaryElement*   get_element() = 0;
 
+#ifndef LIFEO_WINDOZE
         Gtk::Widget*            get_widget()
         { return m_vbox; }
         virtual Gtk::Widget*    get_popover()
         { return m_grid_popover; }
         virtual Gtk::Widget*    get_extra_tools()
         { return NULL; }
+#endif
 
-        virtual Glib::ustring   get_title_str() const
+        virtual Ustring         get_title_str() const
         { return ""; }
-        virtual Glib::ustring   get_info_str() const
+        virtual Ustring         get_info_str() const
         { return ""; }
 
         virtual bool            is_title_editable() const
         { return false; }
-        virtual Glib::ustring   get_title_edit_str() const
+        virtual Ustring         get_title_edit_str() const
         { return get_title_str(); }
-        virtual bool            check_title_applicable( const Glib::ustring& ) const
+        virtual bool            check_title_applicable( const Ustring& ) const
         { return false; }
-        virtual bool            apply_title( const Glib::ustring& )
+        virtual bool            apply_title( const Ustring& )
         { return false; }
 
     protected:
+#ifndef LIFEO_WINDOZE
         Gtk::Box*               m_vbox;
         Gtk::Grid*              m_grid_popover;
+#endif
 };
 
 template< class T >
@@ -321,7 +357,7 @@ class DiaryElementReferrer : public DiaryElement, public std::set< T*, FuncCompa
         DiaryElementReferrer( Diary* const d )
         :   DiaryElement( d, "" ),
             std::set< T*, FuncCompareDiaryElem >( compare_listitems ) {}
-        DiaryElementReferrer( Diary* const d, const Glib::ustring& name, ElemStatus es,
+        DiaryElementReferrer( Diary* const d, const Ustring& name, ElemStatus es,
                                FuncCompareDiaryElem f = compare_listitems )
         :   DiaryElement( d, name, es ),
             std::set< T*, FuncCompareDiaryElem >( f ) {}
@@ -335,7 +371,7 @@ class Theme
 {
     public:
                                     Theme();
-                                    Theme( const Glib::ustring&,
+                                    Theme( const Ustring&,
                                            const std::string&,
                                            const std::string&,
                                            const std::string&,
@@ -348,21 +384,31 @@ class Theme
 
         virtual bool                is_system() const
         { return false; }
-
+#ifndef LIFEO_WINDOZE
         Pango::FontDescription      font;
-        Gdk::RGBA                   color_base;
-        Gdk::RGBA                   color_text;
-        Gdk::RGBA                   color_heading;
-        Gdk::RGBA                   color_subheading;
-        Gdk::RGBA                   color_highlight;
+#else
+        std::string                 font;
+#endif
+        Color                       color_base;
+        Color                       color_text;
+        Color                       color_heading;
+        Color                       color_subheading;
+        Color                       color_highlight;
 
         // CONSTANT COLORS
-        static const Gdk::RGBA      s_color_match1;
-        static const Gdk::RGBA      s_color_match2;
-        static const Gdk::RGBA      s_color_link1;
-        static const Gdk::RGBA      s_color_link2;
-        static const Gdk::RGBA      s_color_broken1;
-        static const Gdk::RGBA      s_color_broken2;
+        static const Color          s_color_match1;
+        static const Color          s_color_match2;
+        static const Color          s_color_link1;
+        static const Color          s_color_link2;
+        static const Color          s_color_broken1;
+        static const Color          s_color_broken2;
+
+        static const Color          s_color_todo;
+        static const Color          s_color_progressed;
+        static const Color          s_color_done;
+        static const Color          s_color_done1;
+        static const Color          s_color_done2;
+        static const Color          s_color_canceled;
 };
 
 class ThemeSystem : public Theme
@@ -373,7 +419,7 @@ class ThemeSystem : public Theme
         { return true; }
 
     protected:
-                                    ThemeSystem( const Glib::ustring&,
+                                    ThemeSystem( const Ustring&,
                                                  const std::string&,
                                                  const std::string&,
                                                  const std::string&,
@@ -390,19 +436,25 @@ class CategoryTags : public DiaryElementReferrer< Tag >
     public:
         static ElementShower< CategoryTags >* shower;
 
-                                CategoryTags( Diary* const, const Glib::ustring& );
+                                CategoryTags( Diary* const, const Ustring& );
 
         void                    show();
 
         Type                    get_type() const
         { return ET_TAG_CTG; }
-        const Glib::RefPtr< Gdk::Pixbuf >&
-                                get_icon() const;
-        const Glib::RefPtr< Gdk::Pixbuf >&
-                                get_icon32() const;
 
-        Glib::ustring           get_list_str() const
+#ifndef LIFEO_WINDOZE
+        const Icon&             get_icon() const;
+        const Icon&             get_icon32() const;
+#else
+        int                     get_icon() const;
+#endif
+        Ustring                 get_list_str() const
+#ifndef LIFEO_WINDOZE
         { return Glib::ustring::compose( "<b>%1</b>", Glib::Markup::escape_text( m_name ) ); }
+#else
+        { return m_name; }
+#endif
 
         bool                    get_expanded() const
         { return( m_status & ES::EXPANDED ); }
@@ -417,13 +469,13 @@ class CategoryTags : public DiaryElementReferrer< Tag >
 };
 
 // POOL OF DEFINED TAG CATEGORIES
-class PoolCategoriesTags : public std::map< Glib::ustring, CategoryTags*, FuncCompareStrings >
+class PoolCategoriesTags : public std::map< Ustring, CategoryTags*, FuncCompareStrings >
 {
     public:
                                 PoolCategoriesTags();
                                 ~PoolCategoriesTags();
 
-        bool                    rename_category( CategoryTags*, const Glib::ustring& );
+        bool                    rename_category( CategoryTags*, const Ustring& );
         void                    clear();
 };
 
@@ -436,7 +488,7 @@ class Tag : public DiaryElementReferrer< Entry >
                                 Tag( Diary* const d )
                                 :   DiaryElementReferrer( d ),
                                     m_ptr2category( NULL ), m_theme( NULL ) {}
-        explicit                Tag( Diary* const, const Glib::ustring&, CategoryTags* );
+        explicit                Tag( Diary* const, const Ustring&, CategoryTags* );
         virtual                 ~Tag();
 
         void                    show();
@@ -452,18 +504,25 @@ class Tag : public DiaryElementReferrer< Entry >
         Theme*                  create_own_theme_duplicating( const Theme* );
         void                    reset_theme();
 
-        void                    set_name( const Glib::ustring& );
+        void                    set_name( const Ustring& );
 
         //Date                  get_date() const; // if earliest entry's date is needed
         virtual Type            get_type() const
         { return ET_TAG; }
-        virtual const Glib::RefPtr< Gdk::Pixbuf >&
-                                get_icon() const;
-        virtual const Glib::RefPtr< Gdk::Pixbuf >&
-                                get_icon32() const;
 
-        virtual Glib::ustring   get_list_str() const
+#ifndef LIFEO_WINDOZE
+        virtual const Icon&     get_icon() const;
+        virtual const Icon&     get_icon32() const;
+#else
+        virtual int             get_icon() const;
+#endif
+
+        virtual Ustring         get_list_str() const
+#ifndef LIFEO_WINDOZE
         { return Glib::Markup::escape_text( m_name ); }
+#else
+        { return m_name; }
+#endif
 
     protected:
         CategoryTags*           m_ptr2category;
@@ -480,12 +539,14 @@ class Untagged : public Tag
 
         Type                    get_type() const
         { return ET_UNTAGGED; }
-        const Glib::RefPtr< Gdk::Pixbuf >&
-                                get_icon() const;
-        const Glib::RefPtr< Gdk::Pixbuf >&
-                                get_icon32() const;
+#ifndef LIFEO_WINDOZE
+        const Icon&             get_icon() const;
+        const Icon&             get_icon32() const;
+#else
+        int                     get_icon() const;
+#endif
 
-        Glib::ustring           get_list_str() const;
+        Ustring                 get_list_str() const;
 
         void                    reset()
         {
@@ -495,17 +556,17 @@ class Untagged : public Tag
 };
 
 // POOL OF DEFINED TAGS
-class PoolTags : public std::map< Glib::ustring, Tag*, FuncCompareStrings >
+class PoolTags : public std::map< Ustring, Tag*, FuncCompareStrings >
 {
     public:
                                 PoolTags()
-        :   std::map< Glib::ustring, Tag*, FuncCompareStrings >( compare_names ) {}
+        :   std::map< Ustring, Tag*, FuncCompareStrings >( compare_names ) {}
                                 ~PoolTags();
 
         bool                    handle_tag_changed( );
-        bool                    rename( Tag*, const Glib::ustring& );
+        bool                    rename( Tag*, const Ustring& );
         Tag*                    get_tag( unsigned int );
-        Tag*                    get_tag( const Glib::ustring& );
+        Tag*                    get_tag( const Ustring& );
         void                    clear();
 };
 
@@ -533,29 +594,33 @@ class Chapter : public DiaryElementReferrer< Entry >
     public:
         static ElementShower< Chapter >* shower;
 
-                                Chapter( Diary* const, const Glib::ustring&, Date::date_t );
+                                Chapter( Diary* const, const Ustring&, Date::date_t );
         // this class should have a virtual dtor for some reason because
         // if it does not, its derived classes cannot be deleted
         virtual                 ~Chapter() {}
 
         void                    show();
 
-        void                    set_name( const Glib::ustring& );
+        void                    set_name( const Ustring& );
 
-        Glib::ustring           get_date_str() const;
+        Ustring                 get_date_str() const;
 
         void                    set_date( Date::date_t date )
         { m_date_begin.m_date = date; update_type(); }
 
         Type                    get_type() const
         { return m_type; }
-        const Glib::RefPtr< Gdk::Pixbuf >&
-                                get_icon() const;
-        const Glib::RefPtr< Gdk::Pixbuf >&
-                                get_icon32() const;
+
+#ifndef LIFEO_WINDOZE
+        const Icon&             get_icon() const;
+        const Icon&             get_icon32() const;
+#else
+        int                     get_icon() const;
+#endif
+
         Date                    get_date() const;
 
-        Glib::ustring           get_list_str() const;
+        Ustring                 get_list_str() const;
 
         Date                    get_free_order() const;
 
@@ -588,7 +653,7 @@ class CategoryChapters :
         public DiaryElement, public std::map< Date::date_t, Chapter*, FuncCompareDates >
 {
     public:
-        explicit                CategoryChapters( Diary* const, const Glib::ustring& );
+        explicit                CategoryChapters( Diary* const, const Ustring& );
         // for topics and groups which do not have names:
         explicit                CategoryChapters( Diary* const, Date::date_t );
         virtual                 ~CategoryChapters();
@@ -602,26 +667,26 @@ class CategoryChapters :
 
         Chapter*                get_chapter( const Date::date_t ) const;
 
-        Chapter*                create_chapter( const Glib::ustring&, const Date& );
-        Chapter*                create_chapter_ordinal( const Glib::ustring& );
+        Chapter*                create_chapter( const Ustring&, const Date::date_t );
+        Chapter*                create_chapter_ordinal( const Ustring& );
         bool                    set_chapter_date( Chapter*, Date::date_t );
 
-        bool                    add( Chapter* );
-
         void                    clear();
 
-        Date                    get_free_order_ordinal() const;
+        Date::date_t            get_free_order_ordinal() const;
 
     protected:
         const Date::date_t      m_date_min;
+
+        bool                    add( Chapter* );
 };
 
 class PoolCategoriesChapters :
-        public std::map< Glib::ustring, CategoryChapters*, FuncCompareStrings >
+        public std::map< Ustring, CategoryChapters*, FuncCompareStrings >
 {
     public:
                                     PoolCategoriesChapters()
-        :   std::map< Glib::ustring, CategoryChapters*, FuncCompareStrings >(
+        :   std::map< Ustring, CategoryChapters*, FuncCompareStrings >(
                 compare_names ) {}
                                     ~PoolCategoriesChapters();
         void                        clear();
@@ -633,7 +698,26 @@ class Filter : public DiaryElement
     public:
         static ElementShower< Filter >* shower;
 
-                                    Filter( Diary* const, const Glib::ustring& );
+                                    Filter( Diary* const, const Ustring& );
+
+        bool                        operator==( const Filter& f )
+        {
+            if( m_status != f.m_status )
+                return false;
+            if( m_date_begin != f.m_date_begin )
+                return false;
+
+            if( m_date_end != f.m_date_end )
+                return false;
+
+            if( m_tag != f.m_tag )
+                return false;
+
+            if( m_entries != f.m_entries )
+                return false;
+
+            return true;
+        }
 
         void                        show();
 
@@ -641,13 +725,17 @@ class Filter : public DiaryElement
         { return ET_FILTER; }
         int                         get_size() const
         { return 0; }   // redundant
-        const Glib::RefPtr< Gdk::Pixbuf >&
-                                    get_icon() const;
-        const Glib::RefPtr< Gdk::Pixbuf >&
-                                    get_icon32() const;
+#ifndef LIFEO_WINDOZE
+        const Icon&                 get_icon() const;
+        const Icon&                 get_icon32() const;
+#endif
 
-        Glib::ustring               get_list_str() const
+        Ustring                     get_list_str() const
+#ifndef LIFEO_WINDOZE
         { return Glib::Markup::escape_text( m_name ); }
+#else
+        { return m_name; }
+#endif
 
         void                        reset();
         void                        set( const Filter* );
