@@ -23,6 +23,7 @@
 #include "entry.hpp"
 #include "diary.hpp"
 #include "lifeograph.hpp"
+#include "strings.hpp"
 
 
 using namespace LIFEO;
@@ -31,12 +32,12 @@ using namespace LIFEO;
 // STATIC MEMBERS
 ElementShower< Entry >* Entry::shower( NULL );
 
-Entry::Entry( Diary* const d, const Date::date_t date, const Glib::ustring& text,
+Entry::Entry( Diary* const d, const Date::date_t date, const Ustring& text,
               bool favored )
 :   DiaryElement( d, "", favored ? ES::ENTRY_DEFAULT_FAV : ES::ENTRY_DEFAULT ), m_date( date ),
-    m_date_created( time( NULL ) ), m_date_changed( m_date_created ),
-    m_text( text ), m_ptr2theme_tag( NULL ),
-    m_option_lang( LANG_INHERIT_DIARY )
+    m_date_created( time( NULL ) ),
+    m_date_edited( m_date_created ), m_date_status( m_date_created ),
+    m_text( text ), m_ptr2theme_tag( NULL ), m_option_lang( LANG_INHERIT_DIARY )
 {
     calculate_title( text );
 }
@@ -45,13 +46,14 @@ Entry::Entry( Diary* const d, const Date::date_t date, bool favored )
 :   DiaryElement( d, _( STRING::EMPTY_ENTRY_TITLE ),
                   favored ?  ES::ENTRY_DEFAULT_FAV : ES::ENTRY_DEFAULT ),
     m_date( date ),
-    m_date_created( time( NULL ) ), m_date_changed( m_date_created ),
-    m_text( "" ), m_ptr2theme_tag( NULL ),
-    m_option_lang( LANG_INHERIT_DIARY )
+    m_date_created( time( NULL ) ),
+    m_date_edited( m_date_created ), m_date_status( m_date_created ),
+    m_text( "" ), m_ptr2theme_tag( NULL ), m_option_lang( LANG_INHERIT_DIARY )
 {
 }
 
-const Glib::RefPtr< Gdk::Pixbuf >&
+#ifndef LIFEO_WINDOZE
+const Icon&
 Entry::get_icon() const
 {
     switch( get_todo_status() )
@@ -68,7 +70,7 @@ Entry::get_icon() const
             return Lifeograph::icons->entry_16;
     }
 }
-const Glib::RefPtr< Gdk::Pixbuf >&
+const Icon&
 Entry::get_icon32() const
 {
     switch( get_todo_status() )
@@ -85,26 +87,49 @@ Entry::get_icon32() const
             return Lifeograph::icons->entry_32;
     }
 }
+#else
+int
+Entry::get_icon() const
+{
+    switch( get_todo_status() )
+    {
+        case ES::TODO:
+            return 2;
+        case ES::PROGRESSED:
+            return 3;
+        case ES::DONE:
+            return 4;
+        case ES::CANCELED:
+            return 5;
+        default:    // 0
+            return 1;
+    }
+}
+#endif
 
-Glib::ustring
+Ustring
 Entry::get_list_str() const
 {
-    static const Glib::ustring tpl[] = { "%2", "%1 -  %2", "<s>%2</s>", "<s>%1 -  %2</s>" };
+#ifndef LIFEO_WINDOZE
+    static const Ustring tpl[] = { "%2", "%1 -  %2", "<s>%2</s>", "<s>%1 -  %2</s>" };
 
     int i( m_date.is_hidden() ? 0 : 1 );
     if( m_status & ES::CANCELED ) i += 2;
 
-    Glib::ustring tpl2 = is_trashed() ?
+    Ustring tpl2 = is_trashed() ?
             Glib::ustring::compose( "<span color=\"%1\">%2</span>",
                                     Lifeograph::s_color_insensitive, tpl[ i ] ) :
             tpl[ i ];
 
     return Glib::ustring::compose( tpl2, m_date.format_string(),
                                    Glib::Markup::escape_text( m_name ) );
+#else
+    return( m_date.is_hidden() ? m_name : STR::compose( m_date.format_string(), " - ", m_name ) );
+#endif
 }
 
 void
-Entry::calculate_title( const Glib::ustring& text )
+Entry::calculate_title( const Ustring& text )
 {
     if( text.size() < 1 )
     {
@@ -118,16 +143,22 @@ Entry::calculate_title( const Glib::ustring& text )
         m_name = text.substr( 0, l_pos );
 }
 
-Glib::ustring
+Ustring
 Entry::get_date_created_str() const
 {
     return Date::format_string_dt( m_date_created );
 }
 
-Glib::ustring
-Entry::get_date_changed_str() const
+Ustring
+Entry::get_date_edited_str() const
 {
-    return Date::format_string_dt( m_date_changed );
+    return Date::format_string_dt( m_date_edited );
+}
+
+Ustring
+Entry::get_date_status_str() const
+{
+    return Date::format_string_dt( m_date_status );
 }
 
 std::string
@@ -331,8 +362,13 @@ Entry::get_filtered_out()
         }
 
         if( m_ptr2diary->is_search_active() )
+#ifndef LIFEO_WINDOZE
             flag_filteredout = ( m_text.lowercase().find( m_ptr2diary->get_search_text() )
                     == std::string::npos );
+#else
+            flag_filteredout = ( m_text.find( m_ptr2diary->get_search_text() )
+                    == std::string::npos );
+#endif
 
         break;
     }
