@@ -29,21 +29,29 @@
 
 #include <iomanip>
 
+#ifdef LIFEO_WINDOZE
+#include <sstream>
+#include <cmath>
+#include <unistd.h>
+#include <sys/stat.h>
+#endif
+
 #include "helpers.hpp"
 
 
 namespace HELPERS
 {
 
-Error::Error( const Glib::ustring& error_message )
+Error::Error( const Ustring& error_message )
 {
     print_error( error_message );
 }
 
 // DATE ============================================================================================
-std::string Date::s_date_format_template = "%1.%2.%3";
+std::string Date::s_date_format_order = "YMD";
+char        Date::s_date_format_separator = '.';
 
-Date::Date( const Glib::ustring& str_date )
+Date::Date( const std::string& str_date )
 :   m_date( 0 )
 {
     if( parse_string( &m_date, str_date ) != OK )
@@ -62,6 +70,7 @@ Date::Date( const Glib::ustring& str_date )
 //    timeinfo->tm_sec = 0;
 //}
 
+#ifndef LIFEO_WINDOZE
 Glib::Date::Month
 Date::get_month_glib() const
 {
@@ -95,9 +104,10 @@ Date::get_month_glib() const
             return Glib::Date::BAD_MONTH;
     }
 }
+#endif
 
 Result
-Date::parse_string( Date::date_t* date, const Glib::ustring& str_date )
+Date::parse_string( Date::date_t* date, const Ustring& str_date )
 {
     char c_cur;
     unsigned int num[ 4 ] = { 0, 0, 0, 0 };  // fourth int is for trailing spaces
@@ -148,7 +158,7 @@ Date::parse_string( Date::date_t* date, const Glib::ustring& str_date )
         {
             if( num[ 0 ] <= 12 && num[ 1 ] <= 12 ) // both DMY and MDY possible
             {
-                if( s_date_format_template[ 1 ] == '2' )
+                if( s_date_format_order[ 0 ] == 'M' )
                 {
                     month = num[ 0 ];
                     day = num[ 1 ];
@@ -203,59 +213,65 @@ Date::parse_string( Date::date_t* date, const Glib::ustring& str_date )
     return OK;
 }
 
-Glib::ustring
-Date::format_string( const date_t d, const std::string& format )
+Ustring
+Date::format_string( const date_t d, const std::string& format, const char separator )
 {
+    std::stringstream result;
+
     if( d & ORDINAL_FLAG )
     {
-        return Glib::ustring::compose( get_order( d ) ? "%1.%2" : "%1",
-                get_ordinal_order( d ) + 1, get_order( d ) );
+        result << ( get_ordinal_order( d ) + 1 );
+        if( get_order( d ) )
+            result << "." << get_order( d );
     }
     else
     {
-        return Glib::ustring::compose( format,
-                Glib::ustring::format( std::setfill( L'0' ), std::setw( 2 ), get_year( d ) ),
-                Glib::ustring::format( std::setfill( L'0' ), std::setw( 2 ), get_month( d ) ),
-                Glib::ustring::format( std::setfill( L'0' ), std::setw( 2 ), get_day( d ) ) );
+        result << std::setfill( '0' ) << std::setw( 2 ) << get_YMD( d, format[ 0 ] ) << separator
+               << std::setfill( '0' ) << std::setw( 2 ) << get_YMD( d, format[ 1 ] ) << separator
+               << std::setfill( '0' ) << std::setw( 2 ) << get_YMD( d, format[ 2 ] );
     }
+    return result.str();
 }
 
-Glib::ustring
+Ustring
 Date::format_string_dt( const time_t time )
 {
     struct tm* timeinfo = localtime( &time );
-    return Glib::ustring::compose( s_date_format_template + ", %4:%5",
-            1900 + timeinfo->tm_year,
-            Glib::ustring::format( std::setfill( L'0' ), std::setw( 2 ), timeinfo->tm_mon + 1 ),
-            Glib::ustring::format( std::setfill( L'0' ), std::setw( 2 ), timeinfo->tm_mday ),
-            Glib::ustring::format( std::setfill( L'0' ), std::setw( 2 ), timeinfo->tm_hour ),
-            Glib::ustring::format( std::setfill( L'0' ), std::setw( 2 ), timeinfo->tm_min ) );
+    std::stringstream result;
+
+    result << format_string( make_date_from_ctime( timeinfo ) )
+           << ", "
+           << std::setfill( '0' ) << std::setw( 2 ) << timeinfo->tm_hour << ":"
+           << std::setfill( '0' ) << std::setw( 2 ) << timeinfo->tm_min;
+
+    return result.str();
 }
 
 // date only
-Glib::ustring
+Ustring
 Date::format_string_d( const time_t time )
 {
     struct tm* timeinfo = localtime( &time );
-    return Glib::ustring::compose( s_date_format_template,
-            1900 + timeinfo->tm_year,
-            Glib::ustring::format( std::setfill( L'0' ), std::setw( 2 ), timeinfo->tm_mon + 1 ),
-            Glib::ustring::format( std::setfill( L'0' ), std::setw( 2 ), timeinfo->tm_mday ) );
+    return format_string( make_date_from_ctime( timeinfo ) );
 }
 
-Glib::ustring
+std::string
 Date::get_year_str() const
 {
-    return Glib::ustring::compose( "%1", get_year() );
+    std::stringstream result;
+    result << get_year();
+    return result.str();
 }
 
-Glib::ustring
+#ifndef LIFEO_WINDOZE
+Ustring
 Date::get_month_str() const
 {
     return Glib::Date( 20, get_month_glib(), 2000 ).format_string( "%b" );
 }
+#endif
 
-Glib::ustring
+Ustring
 Date::get_weekday_str() const
 {
     // from wikipedia: http://en.wikipedia.org/wiki/Calculating_the_day_of_the_week
@@ -277,7 +293,7 @@ Date::get_weekday_str() const
     ti.tm_wday = ( d % 7 );
     char buf[ 32 ];
     strftime( buf, 32, "%A", &ti );
-    return Glib::ustring( buf );
+    return Ustring( buf );
 }
 
 unsigned int
@@ -362,10 +378,14 @@ Date::forward_day()
 unsigned int
 Date::calculate_days_between( const Date& date2 ) const
 {
+#ifndef LIFEO_WINDOZE
     // TODO: create own implementation
     Glib::Date gdate_begin( get_glib() );
     Glib::Date gdate_end( date2.get_glib() );
     return( gdate_begin.days_between( gdate_end ) );
+#else
+    return 0; // STUB
+#endif
 }
 
 unsigned int
@@ -385,18 +405,165 @@ Date::calculate_months_between( Date::date_t date1, Date::date_t date2 )
 
 // CONSOLE MESSAGES ================================================================================
 void
-print_error( const Glib::ustring& description )
+print_error( const Ustring& description )
 {
     std::cerr << "ERROR: " << description << std::endl;
 }
 
 void
-print_info( const Glib::ustring& description )
+print_info( const Ustring& description )
 {
     std::cout << "INFO: " << description << std::endl;
 }
 
-// STRING PROCESSING
+// COLOR OPERATIONS ================================================================================
+#ifndef LIFEO_WINDOZE
+Gdk::RGBA
+contrast2( const Gdk::RGBA& bg, const Gdk::RGBA& c1, const Gdk::RGBA& c2 )
+{
+    double dist1 = ( fabs( bg.get_red() - c1.get_red() ) +
+                     fabs( bg.get_green() - c1.get_green() ) +
+                     fabs( bg.get_blue() - c1.get_blue() ) );
+
+    double dist2 = ( fabs( bg.get_red() - c2.get_red() ) +
+                     fabs( bg.get_green() - c2.get_green() ) +
+                     fabs( bg.get_blue() - c2.get_blue() ) );
+
+    if( dist1 > dist2 )
+        return c1;
+    else
+        return c2;
+}
+
+Gdk::RGBA
+midtone( const Gdk::RGBA& c1, const Gdk::RGBA& c2 )
+{
+    Gdk::RGBA midtone;
+    midtone.set_red_u( ( c1.get_red_u() + c2.get_red_u() ) / 2.0 );
+    midtone.set_green_u( ( c1.get_green_u() + c2.get_green_u() ) / 2.0 );
+    midtone.set_blue_u( ( c1.get_blue_u() + c2.get_blue_u() ) / 2.0 );
+    midtone.set_alpha( 1.0 );
+    return midtone;
+}
+
+Gdk::RGBA
+midtone( const Gdk::RGBA& c1, const Gdk::RGBA& c2, float ratio )
+{
+    Gdk::RGBA midtone;
+    midtone.set_red_u( ( c1.get_red_u() * ratio ) + ( c2.get_red_u() * ( 1.0 - ratio ) ) );
+    midtone.set_green_u( ( c1.get_green_u() * ratio ) + ( c2.get_green_u() * ( 1.0 - ratio ) ) );
+    midtone.set_blue_u( ( c1.get_blue_u() * ratio ) + ( c2.get_blue_u() * ( 1.0 - ratio ) ) );
+    midtone.set_alpha( 1.0 );
+    return midtone;
+}
+
+#else
+
+COLORREF
+contrast2( COLORREF bg, COLORREF c1, COLORREF c2 )
+{
+    double dist1 = ( fabs( GetRValue( bg ) - GetRValue( c1 ) ) +
+                     fabs( GetGValue( bg ) - GetGValue( c1 ) ) +
+                     fabs( GetBValue( bg ) - GetBValue( c1 ) ) );
+
+    double dist2 = ( fabs( GetRValue( bg ) - GetRValue( c2 ) ) +
+                     fabs( GetGValue( bg ) - GetGValue( c2 ) ) +
+                     fabs( GetBValue( bg ) - GetBValue( c2 ) ) );
+
+    if( dist1 > dist2 )
+        return c1;
+    else
+        return c2;
+}
+
+COLORREF
+midtone( COLORREF c1, COLORREF c2, float ratio )
+{
+    return RGB(
+            ( int ) ( ( GetRValue( c1 ) * ratio ) + ( GetRValue( c2 ) * ( 1.0 - ratio ) ) ),
+            ( int ) ( ( GetGValue( c1 ) * ratio ) + ( GetGValue( c2 ) * ( 1.0 - ratio ) ) ),
+            ( int ) ( ( GetBValue( c1 ) * ratio ) + ( GetBValue( c2 ) * ( 1.0 - ratio ) ) ) );
+}
+    
+#endif
+
+// FILE OPERATIONS =================================================================================
+std::ios::pos_type
+get_file_size( std::ifstream& file )
+{
+   std::ios::pos_type size;
+   const std::ios::pos_type currentPosition = file.tellg();
+
+   file.seekg( 0, std::ios_base::end );
+   size = file.tellg();
+   file.seekg( currentPosition );
+
+   return size;
+}
+
+bool
+copy_file_suffix( const std::string& source_path, const std::string& suffix1, int suffix2 )
+{
+#ifndef LIFEO_WINDOZE
+    try
+    {
+        Glib::RefPtr< Gio::File > file_src = Gio::File::create_for_path( source_path );
+
+        if( file_src )
+#endif
+        {
+            std::stringstream ss;
+            ss << source_path << suffix1;
+            if( suffix2 >= 0 )
+                ss << suffix2;
+            int index( 0 );
+
+            while( access( ss.str().c_str(), F_OK ) == 0 )
+            {
+                ss.str( std::string() );
+                ss.clear();
+                ss << source_path << suffix1;
+                if( suffix2 >= 0 )
+                    ss << suffix2;
+                ss << " (" << ++index << ")";
+            }
+
+#ifndef LIFEO_WINDOZE
+            Glib::RefPtr< Gio::File > file_dest = Gio::File::create_for_path( ss.str() );
+            file_src->copy( file_dest );
+#else
+            CopyFileA( source_path.c_str(), ss.str().c_str(), true );
+#endif
+        }
+#ifndef LIFEO_WINDOZE
+    }
+    catch( ... )
+    {
+        return false;
+    }
+#endif
+    return true;
+}
+
+bool
+is_dir( const char* path )
+{
+    struct stat s;
+
+    if( stat( path, &s ) == 0 )
+    {
+        if( s.st_mode & S_IFDIR )
+            return true;
+        else if( s.st_mode & S_IFREG ) // file
+            return false;
+        else // something else
+            return false;
+    }
+    else
+        throw Error( "Stat failed" );
+}
+
+// TEXT OPERATIONS =================================================================================
 long
 convert_string( const std::string& str )
 {
@@ -424,158 +591,7 @@ str_ends_with ( const std::string& str, const std::string& end )
     }
 }
 
-// COLOR PROCESSING
-Gdk::RGBA
-contrast2( const Gdk::RGBA& bg, const Gdk::RGBA& c1, const Gdk::RGBA& c2 )
-{
-    double dist1 = ( fabs( bg.get_red() - c1.get_red() ) +
-                     fabs( bg.get_green() - c1.get_green() ) +
-                     fabs( bg.get_blue() - c1.get_blue() ) );
-
-    double dist2 = ( fabs( bg.get_red() - c2.get_red() ) +
-                     fabs( bg.get_green() - c2.get_green() ) +
-                     fabs( bg.get_blue() - c2.get_blue() ) );
-
-    if( dist1 > dist2 )
-        return c1;
-    else
-        return c2;
-}
-
-// deprecated: this needs lots of love and it is not worth the effort
-/*Gdk::RGBA
-contrast( const Gdk::RGBA& bg, const Gdk::RGBA& fg )
-{
-    Gdk::RGBA contrast( fg );
-    int dom_index = 0;  // 1,2,3 = R,G,B
-    int existingcontrast =  abs( fg.get_red_u() - bg.get_red_u() ) +
-                            abs( fg.get_green_u() - bg.get_green_u() ) +
-                            abs( fg.get_blue_u() - bg.get_blue_u() );
-    if( existingcontrast > 60000 )
-        return contrast;
-
-    if( fg.get_red() > fg.get_green() )
-    {
-        if( fg.get_red() > fg.get_blue() )
-            dom_index = 1;
-        else
-            dom_index = 3;
-    }
-    else
-    {
-        if( fg.get_green() > fg.get_blue() )
-            dom_index = 2;
-        else
-            dom_index = 3;
-    }
-
-    switch ( dom_index )
-    {
-        case 0:
-        break;
-        case 1:
-            if( bg.get_red_u() > 32767 )
-            {
-                contrast.set_red_u( bg.get_red_u() - 32767 );// + existingcontrast );
-//              contrast.set_green( 0 );
-//              contrast.set_blue( 0 );
-            }
-            else
-            {
-                contrast.set_red_u( bg.get_red_u() + 32767 );//- existingcontrast );
-//              contrast.set_green( bg.get_green() > fg.get_green() ?
-//                                          fg.get_green()*0.5 :  );
-//              contrast.set_blue( 0 );
-            }
-        break;
-        case 2:
-            contrast.set_green_u( bg.get_green_u() > 32767 ?
-                    fg.get_green_u() - 32767 :// + existingcontrast :
-                    fg.get_green_u() + 32767 );// - existingcontrast );
-        break;
-        case 3:
-            contrast.set_blue_u( bg.get_blue_u() > 32767 ?
-                    bg.get_blue_u() - 32767 :// + existingcontrast :
-                    bg.get_blue_u() + 32767 );// - existingcontrast );
-        break;
-    }
-    return contrast;
-}*/
-
-Gdk::RGBA
-midtone( const Gdk::RGBA& c1, const Gdk::RGBA& c2 )
-{
-    Gdk::RGBA midtone;
-    midtone.set_red_u( ( c1.get_red_u() + c2.get_red_u() ) / 2.0 );
-    midtone.set_green_u( ( c1.get_green_u() + c2.get_green_u() ) / 2.0 );
-    midtone.set_blue_u( ( c1.get_blue_u() + c2.get_blue_u() ) / 2.0 );
-    midtone.set_alpha( 1.0 );
-    return midtone;
-}
-
-Gdk::RGBA
-midtone( const Gdk::RGBA& c1, const Gdk::RGBA& c2, float ratio )
-{
-    Gdk::RGBA midtone;
-    midtone.set_red_u( ( c1.get_red_u() * ratio ) + ( c2.get_red_u() * ( 1.0 - ratio ) ) );
-    midtone.set_green_u( ( c1.get_green_u() * ratio ) + ( c2.get_green_u() * ( 1.0 - ratio ) ) );
-    midtone.set_blue_u( ( c1.get_blue_u() * ratio ) + ( c2.get_blue_u() * ( 1.0 - ratio ) ) );
-    midtone.set_alpha( 1.0 );
-    return midtone;
-}
-// FILE FUNCTIONS
-std::ios::pos_type
-get_file_size( std::ifstream& file )
-{
-   std::ios::pos_type size;
-   const std::ios::pos_type currentPosition = file.tellg();
-
-   file.seekg( 0, std::ios_base::end );
-   size = file.tellg();
-   file.seekg( currentPosition );
-
-   return size;
-}
-
-// FILE I/O
-bool
-copy_file_suffix( const std::string& source_path, const std::string& suffix1, int suffix2 )
-{
-    try
-    {
-        Glib::RefPtr< Gio::File > file_src = Gio::File::create_for_path( source_path );
-        if( file_src )
-        {
-            std::stringstream ss;
-            ss << source_path << suffix1;
-            if( suffix2 >= 0 )
-                ss << suffix2;
-            int index( 0 );
-
-            while( Glib::file_test( ss.str(), Glib::FILE_TEST_EXISTS ) )
-            {
-                ss.str( std::string() );
-                ss.clear();
-                ss << source_path << suffix1;
-                if( suffix2 >= 0 )
-                    ss << suffix2;
-                ss << " (" << ++index << ")";
-            }
-
-            Glib::RefPtr< Gio::File > file_dest = Gio::File::create_for_path( ss.str() );
-
-            file_src->copy( file_dest );
-        }
-    }
-    catch( ... )
-    {
-        return false;
-    }
-
-    return true;
-}
-
-// ENVIRONMENT VARIABLES
+#ifndef LIFEO_WINDOZE
 std::string
 get_env_lang()
 {
@@ -591,6 +607,134 @@ get_env_lang()
     return s_lang_env;
 }
 
+gunichar
+char_lower( gunichar c )
+{
+    return Glib::Unicode::tolower( c );
+}
+
+bool
+is_char_alpha( gunichar c )
+{
+    return Glib::Unicode::isalpha( c );
+}
+
+#else
+wchar_t*
+convert_utf8_to_16( const Ustring& str8 )
+{
+    wchar_t* str16 = new wchar_t[ str8.size() + 1 ];
+    MultiByteToWideChar( CP_UTF8, 0, str8.c_str(), str8.size() + 1, str16, str8.size() + 1 );
+    
+    return str16;
+}
+
+char*
+convert_utf16_to_8( const wchar_t* str16 )
+{
+    char* str8;
+    int size = WideCharToMultiByte( CP_UTF8, 0, str16, -1, str8, 0, NULL, NULL );
+    str8 = new char[ size ];
+    WideCharToMultiByte( CP_UTF8, 0, str16, -1, str8, size, NULL, NULL );
+
+    return str8;
+}
+
+wchar_t
+char_lower( wchar_t c )
+{
+    return LOWORD( CharLower( ( LPWSTR ) MAKELONG( c, 0 ) ) );
+}
+
+bool
+is_char_alpha( wchar_t c )
+{
+    return IsCharAlpha( c );
+}
+
+// code taken from: http://alter.org.ua/docs/win/args/
+PCHAR*
+command_line_to_argvA( PCHAR CmdLine, int* _argc )
+{
+    PCHAR* argv;
+    PCHAR  _argv;
+    ULONG  len;
+    ULONG  argc;
+    CHAR   a;
+    ULONG  i, j;
+
+    BOOLEAN  in_QM;
+    BOOLEAN  in_TEXT;
+    BOOLEAN  in_SPACE;
+
+    len = strlen(CmdLine);
+    i = ((len+2)/2)*sizeof(PVOID) + sizeof(PVOID);
+
+    argv = (PCHAR*)GlobalAlloc(GMEM_FIXED,
+        i + (len+2)*sizeof(CHAR));
+
+    _argv = (PCHAR)(((PUCHAR)argv)+i);
+
+    argc = 0;
+    argv[argc] = _argv;
+    in_QM = FALSE;
+    in_TEXT = FALSE;
+    in_SPACE = TRUE;
+    i = 0;
+    j = 0;
+
+    while( a = CmdLine[i] ) {
+        if(in_QM) {
+            if(a == '\"') {
+                in_QM = FALSE;
+            } else {
+                _argv[j] = a;
+                j++;
+            }
+        } else {
+            switch(a) {
+            case '\"':
+                in_QM = TRUE;
+                in_TEXT = TRUE;
+                if(in_SPACE) {
+                    argv[argc] = _argv+j;
+                    argc++;
+                }
+                in_SPACE = FALSE;
+                break;
+            case ' ':
+            case '\t':
+            case '\n':
+            case '\r':
+                if(in_TEXT) {
+                    _argv[j] = '\0';
+                    j++;
+                }
+                in_TEXT = FALSE;
+                in_SPACE = TRUE;
+                break;
+            default:
+                in_TEXT = TRUE;
+                if(in_SPACE) {
+                    argv[argc] = _argv+j;
+                    argc++;
+                }
+                _argv[j] = a;
+                j++;
+                in_SPACE = FALSE;
+                break;
+            }
+        }
+        i++;
+    }
+    _argv[j] = '\0';
+    argv[argc] = NULL;
+
+    (*_argc) = argc;
+    return argv;
+}
+#endif
+
 // ENCRYPTION ======================================================================================
 bool
 Cipher::init()
@@ -805,6 +949,8 @@ Cipher::decrypt_buffer ( unsigned char* buffer,
     gcry_cipher_close( cipher );
 }
 
+#ifndef LIFEO_WINDOZE
+
 // MARKED UP MENU ITEM
 Gtk::MenuItem*
 create_menuitem_markup( const Glib::ustring& str_markup,
@@ -881,531 +1027,6 @@ EntryClear::on_key_release_event( GdkEventKey* event )
     return Gtk::Entry::on_key_release_event( event );
 }
 
-// MENUBUTTON ======================================================================================
-#if( GTKMM_MAJOR_VERSION < 3 )
-
-Glib::ustring       Menubutton::s_builder_name;
-
-Menubutton::Menubutton( const Gtk::StockID& stockid,
-                        const Glib::ustring& label,
-                        Gtk::ReliefStyle style,
-                        Gtk::IconSize iconsize,
-                        Menu2* menu )
-    :   Gtk::ToggleButton(), m_menu( menu )
-{
-    set_relief( style );
-
-    if( menu == NULL )
-        m_menu = new Menu2;
-    Gtk::Box* hbox = Gtk::manage( new Gtk::Box );
-    Gtk::Image* icon = Gtk::manage( new Gtk::Image( stockid, iconsize ) );
-    m_label = Gtk::manage( new Gtk::Label( label ) );
-    Gtk::Arrow* arrow = Gtk::manage(
-            new Gtk::Arrow( Gtk::ARROW_DOWN, Gtk::SHADOW_IN ) );
-
-    hbox->pack_start( *icon, Gtk::PACK_SHRINK );
-    hbox->pack_start( *m_label, Gtk::PACK_EXPAND_WIDGET );
-    hbox->pack_start( *arrow, Gtk::PACK_SHRINK );
-    add( *hbox );
-    m_menu->attach_to_widget( *this );
-    m_connection = m_menu->signal_deactivate().connect(
-            sigc::mem_fun( *this, &Menubutton::release ) );
-    add_events( Gdk::BUTTON_PRESS_MASK );
-}
-
-//FIXME: code duplication
-Menubutton::Menubutton( const Glib::RefPtr< Gdk::Pixbuf >* pixbuf,
-                        const Glib::ustring& label,
-                        Gtk::ReliefStyle style,
-                        Menu2* menu )
-:   Gtk::ToggleButton(), m_menu( menu )
-{
-    set_relief( style );
-    Gtk::Arrow* arrow( NULL );
-    Gtk::Image* icon( NULL );
-    Gtk::Box* hbox( NULL );
-    try
-    {
-        if( menu == NULL )
-            m_menu = new Menu2;
-        hbox = Gtk::manage( new Gtk::Box );
-        if( pixbuf )
-            icon = Gtk::manage( new Gtk::Image( *pixbuf ) );
-        m_label = Gtk::manage( new Gtk::Label( label ) );
-        arrow = Gtk::manage( new Gtk::Arrow( Gtk::ARROW_DOWN, Gtk::SHADOW_IN ) );
-    }
-    catch( ... )
-    {
-        throw Error( "Menubutton creation failed" );
-    }
-
-    if( pixbuf )
-        hbox->pack_start( *icon, Gtk::PACK_SHRINK );
-    hbox->pack_start( *m_label, Gtk::PACK_EXPAND_WIDGET );
-    hbox->pack_start( *arrow, Gtk::PACK_SHRINK );
-    add( *hbox );
-    m_menu->attach_to_widget( *this );
-    m_connection = m_menu->signal_deactivate().connect(
-            sigc::mem_fun( *this, &Menubutton::release ) );
-    add_events( Gdk::BUTTON_PRESS_MASK );
-}
-
-Menubutton::Menubutton( BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder )
-:   Gtk::ToggleButton( cobject ), m_menu( NULL )
-{
-    if( !s_builder_name.empty() )
-    {
-        try
-        {
-            builder->get_widget_derived( s_builder_name + "_menu", m_menu );
-            //builder->get_widget( s_builder_name + "_icon", m_icon );
-            //builder->get_widget( s_builder_name + "_label", m_label );
-            s_builder_name = "";
-        }
-        catch( ... )
-        {
-            throw Error( "Menubutton creation failed" );
-        }
-
-        m_menu->attach_to_widget( *this );
-        m_connection = m_menu->signal_deactivate().connect(
-                sigc::mem_fun( this, &Menubutton::release ) );
-    }
-
-    add_events( Gdk::BUTTON_PRESS_MASK );
-}
-
-Menubutton::~Menubutton()
-{
-    delete m_menu;
-}
-
-Menu2*
-Menubutton::get_menu() const
-{
-    return m_menu;
-}
-
-void
-Menubutton::set_menu( Menu2* menu )
-{
-    if( m_menu == menu )
-        return;
-
-    if( m_menu )
-    {
-        m_menu->detach();
-        m_connection.disconnect();
-    }
-
-    m_menu = menu;
-
-    set_sensitive( menu != NULL );
-
-    if( menu )
-    {
-        m_menu->attach_to_widget( *this );
-        m_connection = m_menu->signal_deactivate().connect(
-                sigc::mem_fun( this, &Menubutton::release ) );
-    }
-}
-
-bool
-Menubutton::clear_menu()
-{
-    if( m_menu->get_children().size() > 0 )
-    {
-        m_menu->detach();
-        delete m_menu;
-        m_menu = new Menu2;
-        m_menu->attach_to_widget( *this );
-        m_menu->signal_deactivate().connect( sigc::mem_fun( *this, &Menubutton::release ) );
-
-        return true;
-    }
-    else
-        return false;
-}
-
-void
-Menubutton::release()
-{
-    set_active( false );
-}
-
-void
-Menubutton::set_label( const Glib::ustring& string )
-{
-    m_label->set_label( string );
-}
-
-void
-Menubutton::get_menu_position( int& x, int& y, bool& push_in )
-{
-    get_window()->get_origin( x, y );
-    x += get_allocation().get_x();
-    y += get_allocation().get_y() + get_allocation().get_height();
-    push_in = true;
-}
-
-bool
-Menubutton::on_button_press_event( GdkEventButton* l_event )
-{
-    m_menu->popup( sigc::mem_fun(
-            *this, &Menubutton::get_menu_position), l_event->button, l_event->time);
-
-    set_active( true );
-
-    return true;
-}
-
-#endif
-
-// MENUITEMRECENT ==================================================================================
-#if( GTKMM_MAJOR_VERSION < 3 ) // to be ported to gtkmm3 if needed
-MenuitemRecent::MenuitemRecent( const std::string& path )
-:   Gtk::MenuItem(), m_icon_remove( Gtk::Stock::DELETE, Gtk::ICON_SIZE_MENU ),
-    m_path( path ), m_flag_deletepressed( false )
-{
-    Gtk::Label      *label = Gtk::manage( new Gtk::Label(
-                                            Glib::filename_display_basename( path ) ) );
-    Gtk::Box        *hbox = Gtk::manage( new Gtk::Box );
-
-    label->set_justify( Gtk::JUSTIFY_LEFT );
-    label->set_alignment( Gtk::ALIGN_START );
-    label->set_ellipsize( Pango::ELLIPSIZE_START );
-    label->set_tooltip_text( path );
-    m_icon_remove.set_tooltip_text( _( "Remove from the list" ) );
-    hbox->set_spacing( 5 );
-
-    hbox->pack_start( *label );
-    hbox->pack_start( m_icon_remove, Gtk::PACK_SHRINK );
-    this->add( *hbox );
-
-    hbox->show();
-    label->show();
-}
-
-bool
-MenuitemRecent::on_motion_notify_event( GdkEventMotion* event )
-{
-    if( !( event->state &
-            ( Gdk::BUTTON1_MASK | Gdk::BUTTON2_MASK | Gdk::BUTTON3_MASK ) ) )
-        m_icon_remove.show();
-
-    return Gtk::MenuItem::on_motion_notify_event( event );
-}
-
-bool
-MenuitemRecent::on_leave_notify_event( GdkEventCrossing* event )
-{
-    m_icon_remove.hide();
-
-    return Gtk::MenuItem::on_leave_notify_event( event );
-}
-
-bool
-MenuitemRecent::on_button_press_event( GdkEventButton* event )
-{
-    if( event->x >= m_icon_remove.get_allocation().get_x() &&
-        event->x < m_icon_remove.get_allocation().get_x() +
-                    m_icon_remove.get_allocation().get_width() )
-        m_flag_deletepressed = true;
-    else
-        m_flag_deletepressed = false;
-
-    return Gtk::MenuItem::on_button_press_event( event );
-}
-
-bool
-MenuitemRecent::on_button_release_event( GdkEventButton* event )
-{
-    if( m_flag_deletepressed )
-    {
-        if( event->x >= m_icon_remove.get_allocation().get_x() &&
-            event->x < m_icon_remove.get_allocation().get_x() +
-                        m_icon_remove.get_allocation().get_width() )
-        {
-            m_signal_removerecent.emit( m_path );
-            return true;
-        }
-    }
-
-    return Gtk::MenuItem::on_button_release_event( event );
-}
-
-// FILEBUTTONRECENT ================================================================================
-Glib::ustring   FilebuttonRecent::fallback_label = _( "Select or Create a Diary" );
-
-/*
-FilebuttonRecent::FilebuttonRecent( const Glib::RefPtr< Gdk::Pixbuf >& pixbuf,
-                                    ListPaths* list_recent,
-                                    const Glib::ustring& label_fallback )
-:   Menubutton( &pixbuf, label_fallback, Gtk::RELIEF_NORMAL ),
-    m_icon_new( Gtk::Stock::NEW, Gtk::ICON_SIZE_MENU ),
-    m_icon_browse( Gtk::Stock::OPEN, Gtk::ICON_SIZE_MENU ),
-    m_list_recent( list_recent )
-{
-    // TODO: m_hbox->set_spacing( 4 );
-
-    m_label->set_ellipsize( Pango::ELLIPSIZE_START );
-    m_label->set_alignment( Gtk::ALIGN_LEFT );
-
-    m_menu->items().push_back( Gtk::Menu_Helpers::SeparatorElem() );
-
-    m_menu->items().push_back(
-            Gtk::Menu_Helpers::ImageMenuElem( _("_Browse For a Diary..."), m_icon_browse,
-                    sigc::mem_fun( *this,
-                            &FilebuttonRecent::show_filechooser) ) );
-    m_menu->items().push_back(
-            Gtk::Menu_Helpers::ImageMenuElem( _("_Create A New Diary..."), m_icon_new,
-                    sigc::mem_fun( *this,
-                            &FilebuttonRecent::on_create_file) ) );
-
-    m_menu->show_all_children();
-
-    // ACCEPT DROPPED FILES
-    //~ std::list< Gtk::TargetEntry > list_targets;
-    //~ list_targets.push_back( Gtk::TargetEntry( "STRING" ) );
-    //~ list_targets.push_back( Gtk::TargetEntry( "text/plain" ) );
-    //~ this->drag_dest_set( list_targets );
-    // TODO: i could not figure out how this is supposed to work and replicated
-    // almost blindly bmpx' approach.
-    drag_dest_set( Gtk::DEST_DEFAULT_ALL, ( Gdk::ACTION_COPY | Gdk::ACTION_MOVE ) );
-    drag_dest_add_uri_targets();
-}*/
-
-FilebuttonRecent::FilebuttonRecent( BaseObjectType* cobj, const Glib::RefPtr<Gtk::Builder>& bui )
-:   Menubutton( cobj, bui ),
-    m_icon_new( Gtk::Stock::NEW, Gtk::ICON_SIZE_MENU ),
-    m_icon_browse( Gtk::Stock::OPEN, Gtk::ICON_SIZE_MENU ),
-    m_list_recent( NULL )
-{
-    m_label->set_ellipsize( Pango::ELLIPSIZE_START );
-    m_label->set_alignment( Gtk::ALIGN_START );
-    m_label->set_text( fallback_label );
-
-    m_menu->items().push_back( Gtk::Menu_Helpers::SeparatorElem() );
-
-    m_menu->items().push_back(
-            Gtk::Menu_Helpers::ImageMenuElem( _("_Browse For a Diary..."), m_icon_browse,
-                    sigc::mem_fun( *this,
-                            &FilebuttonRecent::show_filechooser) ) );
-    m_menu->items().push_back(
-            Gtk::Menu_Helpers::ImageMenuElem( _("_Create A New Diary..."), m_icon_new,
-                    sigc::mem_fun( *this,
-                            &FilebuttonRecent::on_create_file) ) );
-
-    m_menu->show_all_children();
-
-    // ACCEPT DROPPED FILES
-    drag_dest_set( Gtk::DEST_DEFAULT_ALL, ( Gdk::ACTION_COPY | Gdk::ACTION_MOVE ) );
-    drag_dest_add_uri_targets();
-}
-
-void
-FilebuttonRecent::set( ListPaths* list_recent )
-{
-    m_list_recent = list_recent;
-}
-
-std::string
-FilebuttonRecent::get_filename() const
-{
-    return( * m_list_recent->begin() );
-}
-
-void
-FilebuttonRecent::set_filename( const std::string& path )
-{
-    if( ! m_list_recent->empty() )
-        if( path == * m_list_recent->begin() )
-            return;
-
-    m_label->set_label( Glib::filename_display_basename( path ) );
-    set_tooltip_text( path );
-    add_recent( path );
-    m_signal_selectionchanged.emit();
-}
-
-void
-FilebuttonRecent::update_filenames()
-{
-    if( ! m_list_recent->empty() )
-    {
-        for( ListPaths::reverse_iterator iter = m_list_recent->rbegin();
-             iter != m_list_recent->rend(); ++iter )
-        {
-            MenuitemRecent* menuitem = Gtk::manage( new MenuitemRecent( *iter ) );
-
-            menuitem->signal_activate().connect(
-                    sigc::bind( sigc::mem_fun( this, &FilebuttonRecent::set_filename ), *iter ) );
-            menuitem->signal_removerecent().connect(
-                    sigc::mem_fun( this, &FilebuttonRecent::remove_recent ) );
-
-            m_menu->items().push_front( Gtk::Menu_Helpers::Element( *menuitem ) );
-
-            menuitem->show();
-        }
-
-        m_label->set_label( Glib::filename_display_basename( * m_list_recent->begin() ) );
-        set_tooltip_text( * m_list_recent->begin() );
-    }
-}
-
-bool
-FilebuttonRecent::add_recent( const std::string& path )
-{
-    // do not add a file twice:
-    Gtk::Menu_Helpers::MenuList::iterator iter_menu = m_menu->items().begin();
-    ListPaths::iterator iter_recent = m_list_recent->begin();
-    for( ; iter_recent != m_list_recent->end(); ++iter_recent )
-    {
-        if( ( *iter_recent ) == path )
-        {
-            m_menu->items().erase( iter_menu );
-            m_list_recent->erase( iter_recent );
-            break;
-        }
-        else
-            ++iter_menu;
-    }
-
-    MenuitemRecent* menuitem = Gtk::manage( new MenuitemRecent( path ) );
-
-    menuitem->signal_activate().connect(
-            sigc::bind( sigc::mem_fun( *this, &FilebuttonRecent::set_filename ),
-                        path ) );
-    menuitem->signal_removerecent().connect(
-            sigc::mem_fun( *this, &FilebuttonRecent::remove_recent ) );
-
-    m_menu->items().push_front( Gtk::Menu_Helpers::Element( *menuitem ) );
-
-    menuitem->show();
-
-    m_list_recent->push_front( path );
-
-    if( m_list_recent->size() > MAX_RECENT_FILE_COUNT )
-    {
-        m_menu->items().erase( --iter_menu );
-        m_list_recent->erase( --iter_recent );
-    }
-
-    return true;    // reserved
-}
-
-void
-FilebuttonRecent::remove_recent( const std::string& path )
-{
-    Gtk::Menu_Helpers::MenuList::iterator   iter_menu = m_menu->items().begin();
-    std::list< std::string >::iterator      iter_recent = m_list_recent->begin();
-    bool flag_update = false;
-    for( ; iter_recent != m_list_recent->end(); ++iter_recent )
-    {
-        if( ( *iter_recent ) == path )
-        {
-            if( iter_recent == m_list_recent->begin() )
-                flag_update = true;
-            m_menu->items().erase( iter_menu );
-            m_list_recent->erase( iter_recent );
-            break;
-        }
-        else
-            ++iter_menu;
-    }
-    // update current path if first item is deleted
-    if( flag_update )
-    {
-        if( m_list_recent->empty() )
-        {
-            m_label->set_label( fallback_label );
-            set_tooltip_text( "" );
-        }
-        else
-        {
-            m_label->set_label( Glib::filename_display_basename( m_list_recent->front() ) );
-            set_tooltip_text( m_list_recent->front() );
-        }
-        m_signal_selectionchanged.emit();
-    }
-}
-
-void
-FilebuttonRecent::show_filechooser()
-{
-    m_filechooserdialog = new Gtk::FileChooserDialog(
-            _( "Select a Diary" ), Gtk::FILE_CHOOSER_ACTION_OPEN );
-
-    if( m_list_recent->size() > 0 )
-        m_filechooserdialog->set_filename( * m_list_recent->begin() );
-    else
-        m_filechooserdialog->set_current_folder( Glib::get_home_dir() );
-
-    m_filechooserdialog->add_button( Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL );
-    m_filechooserdialog->add_button( Gtk::Stock::OPEN, Gtk::RESPONSE_ACCEPT );
-    FilefilterAny       filter_any;
-    FilefilterDiary     filter_diary;
-    m_filechooserdialog->add_filter( filter_any );
-    m_filechooserdialog->add_filter( filter_diary );
-    m_filechooserdialog->set_filter( filter_diary );
-    if( m_filechooserdialog->run() == Gtk::RESPONSE_ACCEPT )
-    {
-        set_filename( m_filechooserdialog->get_filename() );
-    }
-
-    delete m_filechooserdialog;
-    m_filechooserdialog= NULL;
-}
-
-void
-FilebuttonRecent::on_create_file()
-{
-    m_signal_createfile.emit();
-}
-
-void
-FilebuttonRecent::on_drag_data_received( const Glib::RefPtr<Gdk::DragContext>& context,
-                                         int, int,
-                                         const Gtk::SelectionData& seldata,
-                                         guint info,
-                                         guint time )
-{
-    if( seldata.get_length() < 0 )
-        return;
-
-    Glib::ustring uri = seldata.get_data_as_string();
-    std::string filename = uri.substr( 0, uri.find('\n') - 1 );
-    filename = Glib::filename_from_uri( filename );
-
-    if( Glib::file_test( filename, Glib::FILE_TEST_IS_DIR ) )
-        return;
-
-    set_filename( filename );
-    PRINT_DEBUG( Glib::ustring::compose( "dropped: %1", filename ) );
-
-    context->drag_finish( true, false, time );
-}
-
-void
-FilebuttonRecent::on_size_allocate( Gtk::Allocation& allocation )
-{
-    Menubutton::on_size_allocate( allocation );
-    m_menu->set_size_request( allocation.get_width(), -1 );
-}
-
-SignalVoid
-FilebuttonRecent::signal_selection_changed()
-{
-    return m_signal_selectionchanged;
-}
-
-SignalVoid
-FilebuttonRecent::signal_create_file()
-{
-    return m_signal_createfile;
-}
-
-#endif
 // DIALOGEVENT =====================================================================================
 // the rest of the DialogEvent needs to be defined within the user application
 void
@@ -1468,4 +1089,6 @@ bool is_treepath_more( const Gtk::TreePath& p, const Gtk::TreePath& pe )
     return false; // less or equal
 }
 
+#endif
+
 } // end of name space
