@@ -30,20 +30,67 @@
 
 #include <iostream>
 #include <fstream>
+#include <sstream>
 #include <set>
 
 #include <gcrypt.h>
 
+#ifndef LIFEO_WINDOZE
 #include <gtkmm.h>
+#else
+#include <shlwapi.h>
+#endif
 
+#ifndef LIFEO_WINDOZE
+typedef Glib::ustring Ustring;
+typedef Glib::ustring Wstring;
+typedef gunichar Wchar;
+#define W(s) s
+typedef Glib::RefPtr< Gdk::Pixbuf > Icon;
+typedef Gdk::RGBA Color;
+#else
+// values are temporary
+typedef std::string Ustring;
+typedef std::wstring Wstring;
+typedef wchar_t Wchar;
+#define W(s) L##s
+typedef void* Icon;
+typedef std::string Color;
+#endif
 
 namespace HELPERS
 {
 
+#ifdef LIFEO_WINDOZE
+class STR
+{
+    private:
+        static void print_internal( std::stringstream& ) {}
+
+
+        template< typename Arg1, typename... Args >
+        static void print_internal( std::stringstream& str, Arg1 arg1, Args... args )
+        {
+            str << arg1;
+            print_internal( str, args... );
+        }
+
+    public:
+        template< typename... Args >
+        static Ustring compose( Args... args )
+        {
+            std::stringstream str;
+            print_internal( str, args... );
+
+            return str.str();
+        }
+};
+#endif
+
 class Error
 {
     public:
-                        Error( const Glib::ustring& );
+                        Error( const Ustring& );
 };
 
 enum Result
@@ -121,7 +168,8 @@ class Date
         static const unsigned long  TOPIC_MIN           = VISIBLE_FLAG|ORDINAL_FLAG;
         static const unsigned long  GROUP_MIN           = ORDINAL_FLAG;
 
-        static std::string          s_date_format_template;
+        static std::string          s_date_format_order;
+        static char                 s_date_format_separator;
 
         typedef unsigned long date_t;
 
@@ -150,7 +198,7 @@ class Date
                                     Date( unsigned int y, unsigned int m, unsigned int d,
                                           unsigned int o = 0 )
             :   m_date( ( y << 19 ) | ( m << 15 ) | ( d << 10 ) | o ) {}
-        explicit                    Date( const Glib::ustring& );
+        explicit                    Date( const std::string& );
         // TODO: later: explicit                    Date( time_t );
         // ORDINAL C'TOR
                                     Date( unsigned int o1, unsigned int o2 )
@@ -180,11 +228,25 @@ class Date
         { return ( ( m_date & YEAR_FILTER ) >> 19 ); }
         static unsigned int         get_year( const date_t d )
         { return ( ( d & YEAR_FILTER ) >> 19 ); }
+        
+        static int get_YMD( long d, char c )
+        {
+            switch( c )
+            {
+                case 'Y':
+                    return get_year( d );
+                case 'M':
+                    return get_month( d );
+                case 'D':
+                default: // no error checking for now
+                    return get_day( d );
+            }
+        }
 
-        Glib::ustring               get_year_str() const;
-        Glib::ustring               get_month_str() const;
-        Glib::ustring               get_day_str() const;
-        Glib::ustring               get_weekday_str() const;
+        std::string                 get_year_str() const;
+        Ustring                     get_month_str() const;
+        //std::string                 get_day_str() const;
+        Ustring                     get_weekday_str() const;
 
         unsigned int                get_days_in_month() const;
 
@@ -206,7 +268,9 @@ class Date
         static unsigned int         get_month( const date_t d )
         { return( ( d & MONTH_FILTER ) >> 15 ); }
 
+#ifndef LIFEO_WINDOZE
         Glib::Date::Month           get_month_glib() const;
+#endif
 
         unsigned int                get_day() const
         { return( ( m_date & DAY_FILTER ) >> 10 ); }
@@ -227,8 +291,10 @@ class Date
             return ORDINAL_FLAG;
         }
 
+#ifndef LIFEO_WINDOZE
         Glib::Date                  get_glib() const
         { return Glib::Date( get_day(), get_month_glib(), get_year() ); }
+#endif
         time_t                      get_ctime() const
         { return get_ctime( m_date ); }
         static time_t               get_ctime( const date_t );
@@ -264,14 +330,15 @@ class Date
         static void                 reset_order_1( date_t& date )
         { date &= ORDER_FILTER_INV; date |= 0x1; }
 
-        static Result               parse_string( Date::date_t*, const Glib::ustring& );
-        Glib::ustring               format_string() const
-        { return format_string( m_date, s_date_format_template ); }
-        static Glib::ustring        format_string( const date_t date )
-        { return format_string( date, s_date_format_template ); }
-        static Glib::ustring        format_string( const date_t, const std::string& );
-        static Glib::ustring        format_string_dt( const time_t );
-        static Glib::ustring        format_string_d( const time_t );
+        static Result               parse_string( Date::date_t*, const Ustring& );
+
+        Ustring                     format_string() const
+        { return format_string( m_date, s_date_format_order, s_date_format_separator ); }
+        static Ustring              format_string( const date_t date )
+        { return format_string( date, s_date_format_order, s_date_format_separator ); }
+        static Ustring              format_string( const date_t, const std::string&, const char );
+        static Ustring              format_string_dt( const time_t );
+        static Ustring              format_string_d( const time_t );
 
         bool                        is_valid() const
         {
@@ -314,6 +381,15 @@ class Date
         { return( ( y << 19 ) | ( m << 15 ) | ( d << 10 ) | o ); }
         static date_t               make_date( unsigned int c, unsigned int o = 0 )
         { return( TOPIC_MIN | ( ( c - 1 ) * ORDINAL_STEP ) | o ); }
+        static date_t               make_date_from_ctime( const tm* timeinfo )
+        {
+            return make_date( timeinfo->tm_year + 1900, timeinfo->tm_mon + 1, timeinfo->tm_mday );
+        }
+        static date_t               make_date_from_ctime( const time_t t )
+        {
+            struct tm* timeinfo = localtime( &t );
+            return make_date( timeinfo->tm_year + 1900, timeinfo->tm_mon + 1, timeinfo->tm_mday );
+        }
 
         unsigned int                calculate_days_between( const Date& ) const;
         unsigned int                calculate_months_between( Date::date_t ) const;
@@ -340,27 +416,27 @@ compare_dates( const Date::date_t& date_l, const Date::date_t& date_r )
 
 typedef bool( *FuncCompareDates )( const Date::date_t&, const Date::date_t& ) ;
 
-// GLOBAL FUNCTIONS ================================================================================
-void                print_error( const Glib::ustring& );
-void                print_info( const Glib::ustring& );
+// CONSOLE MESSAGES ================================================================================
+void                print_error( const Ustring& );
+void                print_info( const Ustring& );
 
 #if LIFEOGRAPH_DEBUG_BUILD
 #define PRINT_DEBUG( msg )  std::cout << "DEBUG: " << msg << std::endl
 #define PRINT_DEBUG2( a1, a2 )  std::cout << "DEBUG: " << a1 << a2 << std::endl
 #define PRINT_DEBUG3( a1, a2, a3 )  std::cout << "DEBUG: " << a1 << a2 << a3 << std::endl
 #define PRINT_DEBUG4( a1, a2, a3, a4 )  std::cout << "DEBUG: " << a1 << a2 << a3 << a4 << std::endl
+#define PRINT_DEBUG5( a1, a2, a3, a4, a5 )  std::cout << "DEBUG: " << a1 << a2 << a3 << a4 << a5 << std::endl
 #else
 #define PRINT_DEBUG( msg )  ;
 #define PRINT_DEBUG2( a1, a2 )  ;
 #define PRINT_DEBUG3( a1, a2, a3 )  ;
 #define PRINT_DEBUG4( a1, a2, a3, a4 )  ;
+#define PRINT_DEBUG5( a1, a2, a3, a4, a5 )  ;
 #endif
 
-long                convert_string( const std::string& );
-bool                str_ends_with ( const std::string&, const std::string& );
-
+// COLOR OPERATIONS ================================================================================
+#ifndef LIFEO_WINDOZE
 Gdk::RGBA           contrast2( const Gdk::RGBA&, const Gdk::RGBA&, const Gdk::RGBA& );
-//Gdk::RGBA           contrast( const Gdk::RGBA&, const Gdk::RGBA& ); DEPRECATED
 Gdk::RGBA           midtone( const Gdk::RGBA&, const Gdk::RGBA& );
 Gdk::RGBA           midtone( const Gdk::RGBA&, const Gdk::RGBA&, float );
 
@@ -387,18 +463,99 @@ convert_gdkrgba_to_string( const Gdk::RGBA& gdkcolor )
             int( gdkcolor.get_blue() * 0xFFFF ) );
     return buffer;
 }
+
+#else
+
+inline int
+parse_color_sub( const std::string& color, int begin, int end )
+{
+    int ret_val = 0;
+
+    for( int i = begin; i <= end; i++ )
+    {
+        char c = color[ i ];
+        if( c >= '0' && c <= '9' )
+        {
+            ret_val *= 16;
+            ret_val += ( c - '0' );
+        }
+        else if( c >= 'a' && c <= 'f' )
+        {
+            ret_val *= 16;
+            ret_val += ( c - 'a' + 10 );
+        }
+        else if( c >= 'A' && c <= 'F' )
+        {
+            ret_val *= 16;
+            ret_val += ( c - 'A' + 10 );
+        }
+    }
+
+    return ret_val;
+}
+
+inline COLORREF
+parse_color( const std::string& color )
+{
+    if( color.size() == 13 ) // #RRRRGGGGBBBB
+        return RGB( parse_color_sub( color, 1, 2 ),
+                    parse_color_sub( color, 5, 6 ),
+                    parse_color_sub( color, 9, 10 ) );
+    else // #RRGGBB
+        return RGB( parse_color_sub( color, 1, 2 ),
+                    parse_color_sub( color, 3, 4 ),
+                    parse_color_sub( color, 5, 6 ) );
+}
+
+COLORREF
+contrast2( COLORREF, COLORREF, COLORREF );
+
+COLORREF
+midtone( COLORREF, COLORREF, float );
+
+#endif
+
+// FILE OPERATIONS =================================================================================
 std::ios::pos_type  get_file_size( std::ifstream& );
 
 bool                copy_file_suffix( const std::string&, const std::string&, int );
 
+bool                is_dir( const char* );
+
+inline std::string
+get_filename_base( const std::string& path )
+{
+#ifndef LIFEO_WINDOZE
+    return Glib::filename_display_basename( path );
+#else
+    char* stripped_path = new char[ path.size() + 1 ];
+    strcpy( stripped_path, path.c_str() );
+    PathStripPathA( stripped_path );
+    return std::string( stripped_path );
+#endif
+}
+
+typedef std::set< std::string > ListPaths;
+
+// TEXT OPERATIONS =================================================================================
+long                convert_string( const std::string& );
+bool                str_ends_with( const std::string&, const std::string& );
+
+#ifndef LIFEO_WINDOZE
+gunichar            char_lower( gunichar );
+bool                is_char_alpha( gunichar );
+
 std::string         get_env_lang();
 
-Gtk::MenuItem*      create_menuitem_markup( const Glib::ustring&,
-                                            const Glib::SignalProxy0< void >::SlotType& );
+#else
+wchar_t*            convert_utf8_to_16( const Ustring& );
+char*               convert_utf16_to_8( const wchar_t* );
 
-// COMMON SIGNALS ==================================================================================
-typedef sigc::signal< void >        SignalVoid;
-typedef std::set< std::string >     ListPaths;
+wchar_t             char_lower( wchar_t );
+bool                is_char_alpha( wchar_t );
+
+PCHAR*              command_line_to_argvA( PCHAR, int* );
+#endif
 
 // ENCRYPTION ======================================================================================
 class Cipher
@@ -454,6 +611,7 @@ struct CipherBuffers
     }
 };
 
+#ifndef LIFEO_WINDOZE
 // ENTRY WIDGET WITH SELF-HANDLED CLEAR ICON =======================================================
 class EntryClear : public Gtk::Entry
 {
@@ -468,137 +626,6 @@ class EntryClear : public Gtk::Entry
         bool                m_pressed;
 };
 
-// MENU 2 ==========================================================================================
-#if( GTKMM_MAJOR_VERSION < 3 )
-
-class Menu2 : public Gtk::Menu
-{
-    public:
-        Menu2() { }
-        Menu2( BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& )
-        :   Gtk::Menu( cobject ) { }
-
-    protected:
-
-    private:
-
-    friend class Menubutton;
-};
-
-class Menubutton : public Gtk::ToggleButton
-{
-    public:
-                            Menubutton( const Gtk::StockID&,
-                                        const Glib::ustring&,
-                                        Gtk::ReliefStyle = Gtk::RELIEF_NONE,
-                                        Gtk::IconSize = Gtk::ICON_SIZE_BUTTON,
-                                        Menu2* = NULL );
-                            Menubutton( const Glib::RefPtr< Gdk::Pixbuf >*,
-                                        const Glib::ustring&,
-                                        Gtk::ReliefStyle = Gtk::RELIEF_NONE,
-                                        Menu2* = NULL );
-                            Menubutton( BaseObjectType*,
-                                        const Glib::RefPtr< Gtk::Builder >& );
-        virtual             ~Menubutton();
-
-        Menu2*              get_menu() const;
-        void                set_menu( Menu2* );
-        bool                clear_menu();
-        void                release();
-
-        void                set_label( const Glib::ustring& );
-        void                get_menu_position( int&, int&, bool& );
-
-        static Glib::ustring
-                            s_builder_name;
-
-    protected:
-        bool                on_button_press_event( GdkEventButton* );
-
-        Menu2*              m_menu;
-        Gtk::Label*         m_label;
-        sigc::connection    m_connection;
-
-    private:
-};
-
-class MenuitemRecent : public Gtk::MenuItem
-{
-    public:
-        typedef sigc::signal< void, const std::string& >
-                                    Signal_void_string;
-
-                                    MenuitemRecent( const std::string& );
-
-        Signal_void_string          signal_removerecent()
-        { return m_signal_removerecent; }
-
-    protected:
-        virtual bool                on_motion_notify_event( GdkEventMotion* );
-        virtual bool                on_leave_notify_event( GdkEventCrossing* );
-        virtual bool                on_button_release_event( GdkEventButton* );
-        virtual bool                on_button_press_event( GdkEventButton* );
-
-        Gtk::Image                  m_icon_remove;
-        std::string                 m_path;
-        bool                        m_flag_deletepressed;
-
-        Signal_void_string          m_signal_removerecent;
-};
-
-class FilebuttonRecent : public Menubutton
-{
-    public:
-        const unsigned int  MAX_RECENT_FILE_COUNT( 8 );
-
-        typedef std::list< std::string > ListPaths;
-//                                    FilebuttonRecent( const Glib::RefPtr< Gdk::Pixbuf >&,
-//                                                      ListPaths*, const Glib::ustring& );
-                                    FilebuttonRecent( BaseObjectType*,
-                                                      const Glib::RefPtr< Gtk::Builder >& );
-
-        void                        set( ListPaths* );
-
-        ListPaths*                  get_recentlist()
-        {
-            return m_list_recent;
-        }
-        std::string                 get_filename() const;
-        std::string                 get_filename_recent( int ) const;
-        void                        set_filename( const std::string& );
-        void                        update_filenames();
-
-        bool                        add_recent( const std::string& );
-        void                        remove_recent( const std::string& );
-
-        void                        show_filechooser();
-
-        SignalVoid                  signal_selection_changed();
-        SignalVoid                  signal_create_file();
-
-        bool                        handle_motion_notify( GdkEventMotion* );
-
-        static Glib::ustring        fallback_label;
-
-    protected:
-        virtual void                on_create_file();
-        virtual void                on_size_allocate( Gtk::Allocation& );
-        virtual void                on_drag_data_received(
-                                            const Glib::RefPtr<Gdk::DragContext>&,
-                                            int, int,
-                                            const Gtk::SelectionData&, guint, guint );
-
-    private:
-        Gtk::FileChooserDialog*     m_filechooserdialog;
-        Gtk::Image                  m_icon_new;
-        Gtk::Image                  m_icon_browse;
-        ListPaths*                  m_list_recent;
-        SignalVoid                  m_signal_selectionchanged;
-        SignalVoid                  m_signal_createfile;
-};
-
-#endif
-
 // FILE FILTERS ====================================================================================
 //class FilefilterAny : public Gtk::FileFilter
 //{
@@ -642,6 +669,14 @@ Gtk::Frame* create_frame( const Glib::ustring&, Gtk::Widget& );
 bool is_treepath_less( const Gtk::TreePath&, const Gtk::TreePath& );
 bool is_treepath_more( const Gtk::TreePath&, const Gtk::TreePath& );
 
+// OTHER GTK HELPERS ===============================================================================
+Gtk::MenuItem*      create_menuitem_markup( const Glib::ustring&,
+                                            const Glib::SignalProxy0< void >::SlotType& );
+
+typedef sigc::signal< void >        SignalVoid;
+
+#endif // ifndef LIFEO_WINDOZE
+
 } // end of namespace HELPERS
 
 #endif
