@@ -1,6 +1,6 @@
 /***********************************************************************************
 
-    Copyright (C) 2007-2015 Ahmet Öztürk (aoz_2@yahoo.com)
+    Copyright (C) 2007-2016 Ahmet Öztürk (aoz_2@yahoo.com)
 
     This file is part of Lifeograph.
 
@@ -33,7 +33,7 @@
 using namespace LIFEO;
 
 // STATIC MEMBERS
-const char                          Lifeograph::PROGRAM_VERSION_STRING[] = "1.2.1"
+const char                          Lifeograph::PROGRAM_VERSION_STRING[] = "1.3.0"
 #if LIFEOGRAPH_DEBUG_BUILD
         "\n" BUILD_TIMESTAMP
 #endif
@@ -45,7 +45,7 @@ Icons*                              Lifeograph::icons = NULL;
 Glib::RefPtr< Gtk::Builder >        Lifeograph::builder;
 Glib::RefPtr< Gtk::ActionGroup >    Lifeograph::m_actions_read;
 Glib::RefPtr< Gtk::ActionGroup >    Lifeograph::m_actions_edit;
-int                                 Lifeograph::m_internaloperation = 0;
+int                                 Lifeograph::s_internaloperation = 0;
 SignalVoid                          Lifeograph::s_signal_logout;
 Lifeograph::LoginStatus             Lifeograph::loginstatus = Lifeograph::LOGGED_OUT;
 std::set< std::string >             Lifeograph::stock_diaries;
@@ -187,9 +187,9 @@ Lifeograph::on_command_line( const Glib::RefPtr< Gio::ApplicationCommandLine >&
         {
             if( ( i + 1 ) < argc )
             {
-                if( Glib::file_test( argv[ ++i ], Glib::FILE_TEST_EXISTS ) )
+                if( access( argv[ ++i ], F_OK ) == 0 ) // check existance
                 {
-                    if( ! Glib::file_test( argv[ i ], Glib::FILE_TEST_IS_DIR ) )
+                    if( ! is_dir( argv[ i ] ) )
                     {
                         ViewLogin::m_path_cur = argv[ i ];
                         m_flag_open_directly = true;
@@ -217,11 +217,10 @@ Lifeograph::on_command_line( const Glib::RefPtr< Gio::ApplicationCommandLine >&
             m_flag_read_only = true;
         }
         else
-        if( Glib::file_test( argv[ i ], Glib::FILE_TEST_EXISTS ) &&
-            Glib::file_test( argv[ i ], Glib::FILE_TEST_IS_DIR ) == false )
+        if( access( argv[ i ], F_OK ) == 0 && ! is_dir( argv[ i ] ) )
         {
-                ViewLogin::m_path_cur = argv[ i ];
-                m_flag_open_directly = true;
+            ViewLogin::m_path_cur = argv[ i ];
+            m_flag_open_directly = true;
         }
         else
         {
