@@ -52,22 +52,25 @@ PanelDiary::PanelDiary()
         Lifeograph::builder->get_widget( "Bx_new_elem", m_Bx_new_elem );
         Lifeograph::builder->get_widget( "B_today", button_today );
         Lifeograph::builder->get_widget( "MB_diary_add", m_MB_add );
-        Lifeograph::builder->get_widget( "MI_add_entry", m_menuitem_add_entry );
-        Lifeograph::builder->get_widget( "MI_add_topic", m_menuitem_add_topic );
-        Lifeograph::builder->get_widget( "MI_add_group", m_menuitem_add_group );
-        Lifeograph::builder->get_widget( "MI_add_chapter", m_menuitem_add_chapter );
+        Lifeograph::builder->get_widget( "MI_add_entry", m_MI_add_entry );
+        Lifeograph::builder->get_widget( "MI_add_topic", m_MI_add_topic );
+        Lifeograph::builder->get_widget( "MI_add_group", m_MI_add_group );
+        Lifeograph::builder->get_widget( "MI_add_chapter", m_MI_add_chapter );
 
         Lifeograph::builder->get_widget( "Bx_logout", m_Bx_logout );
-        Lifeograph::builder->get_widget( "B_logout", m_button_logout );
+        Lifeograph::builder->get_widget( "B_logout", m_B_logout );
         Lifeograph::builder->get_widget( "MB_logout", m_MB_logout );
         Lifeograph::builder->get_widget( "MI_logout_disable", m_MI_logout_disable_auto );
         Lifeograph::builder->get_widget( "MI_logout_wo_saving", m_MI_logout_wo_saving );
 
-        Lifeograph::builder->get_widget( "MB_tools", m_button_tools );
-        Lifeograph::builder->get_widget( "MI_sort_by_date", m_menuitem_sort_by_date );
-        Lifeograph::builder->get_widget( "MI_sort_by_size", m_menuitem_sort_by_size );
-        Lifeograph::builder->get_widget( "MI_sort_by_change", m_menuitem_sort_by_change );
+        Lifeograph::builder->get_widget( "MB_tools", m_B_tools );
+        Lifeograph::builder->get_widget( "MI_sort_by_date", m_MI_sort_by_date );
+        Lifeograph::builder->get_widget( "MI_sort_by_size", m_MI_sort_by_size );
+        Lifeograph::builder->get_widget( "MI_sort_by_change", m_MI_sort_by_change );
 
+        Lifeograph::builder->get_widget( "Bx_search", m_Bx_search );
+        Lifeograph::builder->get_widget( "B_filter", m_B_filter );
+        Lifeograph::builder->get_widget( "B_filter_revert", m_B_filter_revert );
         Lifeograph::builder->get_widget( "E_search", m_E_search );
         Lifeograph::builder->get_widget_derived( "E_replace", m_E_replace );
         Lifeograph::builder->get_widget( "B_match_prev", m_B_match_prev );
@@ -76,18 +79,35 @@ PanelDiary::PanelDiary()
         Lifeograph::builder->get_widget( "B_replace", m_B_replace );
         Lifeograph::builder->get_widget( "B_replace_all", m_B_replace_all );
 
+        // THEMABLE ICONS
+        Gtk::Image* img;
+        Lifeograph::builder->get_widget( "I_filter", img );
+        img->set( Lifeograph::icons->filter_16 );
+        Lifeograph::builder->get_widget( "I_filter_revert", img );
+        img->set( Lifeograph::icons->filter_revert_16 );
+
+
+        Lifeograph::builder->get_widget( "I_add_entry", img );
+        img->set( Lifeograph::icons->entry_16 );
+        Lifeograph::builder->get_widget( "I_add_chapter", img );
+        img->set( Lifeograph::icons->month_16 );
+        Lifeograph::builder->get_widget( "I_add_topic", img );
+        img->set( Lifeograph::icons->chapter_16 );
+        Lifeograph::builder->get_widget( "I_add_group", img );
+        img->set( Lifeograph::icons->chapter_16 );
+
         // FALLBACK ICON FOR SYSTEMS WITHOUT SYMBOLIC ICONS
         Glib::RefPtr< Gtk::IconTheme > theme = Gtk::IconTheme::get_default();
         if( ! theme->has_icon( "preferences-system-symbolic" ) &&
             theme->has_icon( "gtk-preferences" ) )
         {
             Glib::RefPtr< Gdk::Pixbuf > icon_tools = theme->load_icon( "gtk-preferences", 16 );
-            Gtk::Image *img_tools = Gtk::manage( new Gtk::Image( icon_tools ) );
-            m_button_tools->set_image( *img_tools );
+            img = Gtk::manage( new Gtk::Image( icon_tools ) );
+            m_B_tools->set_image( *img );
         }
 
         Lifeograph::builder->get_widget( "calendar_main", m_calendar );
-        Lifeograph::builder->get_widget_derived( "treeview_main", m_treeview_entries );
+        Lifeograph::builder->get_widget_derived( "treeview_main", m_TV_entries );
 
         m_PO_replace.add( *m_G_replace );
         m_PO_replace.set_relative_to( *m_E_search );
@@ -100,24 +120,21 @@ PanelDiary::PanelDiary()
     }
 
     // SIGNALS
-    m_button_logout->signal_clicked().connect(
+    m_B_logout->signal_clicked().connect(
             sigc::bind( sigc::mem_fun( AppWindow::p, &AppWindow::logout ), true ) );
 
-    m_menuitem_sort_by_date->signal_activate().connect(
-            sigc::bind(
-                    sigc::mem_fun( m_treeview_entries,
-                                   &WidgetEntryList::handle_sorting_criteria_changed ),
-                    SC_DATE ) );
-    m_menuitem_sort_by_size->signal_activate().connect(
-            sigc::bind(
-                    sigc::mem_fun( m_treeview_entries,
-                                   &WidgetEntryList::handle_sorting_criteria_changed ),
-                    SC_SIZE ) );
-    m_menuitem_sort_by_change->signal_activate().connect(
-            sigc::bind(
-                    sigc::mem_fun( m_treeview_entries,
-                                   &WidgetEntryList::handle_sorting_criteria_changed ),
-                    SC_CHANGE ) );
+    m_MI_sort_by_date->signal_activate().connect(
+            sigc::bind( sigc::mem_fun( m_TV_entries,
+                                       &WidgetEntryList::handle_sorting_criteria_changed ),
+                        SC_DATE ) );
+    m_MI_sort_by_size->signal_activate().connect(
+            sigc::bind( sigc::mem_fun( m_TV_entries,
+                                       &WidgetEntryList::handle_sorting_criteria_changed ),
+                        SC_SIZE_C ) );
+    m_MI_sort_by_change->signal_activate().connect(
+            sigc::bind( sigc::mem_fun( m_TV_entries,
+                                       &WidgetEntryList::handle_sorting_criteria_changed ),
+                        SC_CHANGE ) );
 
     m_calendar->signal_day_selected_double_click().connect(
             sigc::mem_fun( this, &PanelDiary::handle_add_entry ) );
@@ -126,27 +143,33 @@ PanelDiary::PanelDiary()
     m_calendar->signal_day_selected().connect(
             sigc::mem_fun( this, &PanelDiary::handle_calendar_dayselected ) );
 
-     m_treeview_entries->signal_row_expanded().connect(
+    m_TV_entries->signal_row_expanded().connect(
             sigc::mem_fun( this, &PanelDiary::handle_treeview_row_expanded ) );
-    m_treeview_entries->signal_row_collapsed().connect(
+    m_TV_entries->signal_row_collapsed().connect(
             sigc::mem_fun( this, &PanelDiary::handle_treeview_row_expanded ) );
 
-    m_menuitem_add_entry->signal_activate().connect(
+    m_MI_add_entry->signal_activate().connect(
             sigc::mem_fun( this, &PanelDiary::handle_add_entry ) );
-    m_menuitem_add_topic->signal_activate().connect(
+    m_MI_add_topic->signal_activate().connect(
             sigc::mem_fun( this, &PanelDiary::handle_add_topic ) );
-    m_menuitem_add_group->signal_activate().connect(
+    m_MI_add_group->signal_activate().connect(
             sigc::mem_fun( this, &PanelDiary::handle_add_group ) );
-    m_menuitem_add_chapter->signal_activate().connect(
+    m_MI_add_chapter->signal_activate().connect(
             sigc::mem_fun( this, &PanelDiary::handle_add_chapter ) );
 
+    m_B_filter->signal_clicked().connect(
+            sigc::mem_fun( Diary::d->m_filter_active, &DiaryElement::show ) );
+
+    m_B_filter_revert->signal_clicked().connect(
+            sigc::mem_fun( this, &PanelDiary::revert_filter ) );
+
     m_E_search->signal_changed().connect(
             sigc::mem_fun( this, &PanelDiary::handle_search_string_changed ) );
 
     g_signal_connect( m_E_search->gobj(), "search-changed",
                       ( GCallback ) handle_search_changed_tmp, this );
     m_E_search->signal_activate().connect(
-            sigc::mem_fun( AppWindow::p->panel_diary, &PanelDiary::go_next_match ) );
+            sigc::mem_fun( this, &PanelDiary::go_next_match ) );
 
     m_E_replace->signal_activate().connect(
             sigc::mem_fun( this, &PanelDiary::replace_match ) );
@@ -172,13 +195,13 @@ PanelDiary::PanelDiary()
             false, m_action_previous_list, "ListPrevious", _( "Previous" ),
             _( "Go to the previous entry in the list" ),
             Gtk::AccelKey( GDK_KEY_Page_Up, Gdk::CONTROL_MASK ),
-            sigc::bind( sigc::mem_fun( m_treeview_entries, &WidgetEntryList::go_up ), false ) );
+            sigc::bind( sigc::mem_fun( m_TV_entries, &WidgetEntryList::go_up ), false ) );
 
     Lifeograph::create_action(
             false, m_action_next_list, "ListNext", _( "Next" ),
             _( "Go to the next entry in the list" ),
             Gtk::AccelKey( GDK_KEY_Page_Down, Gdk::CONTROL_MASK ),
-            sigc::bind( sigc::mem_fun( m_treeview_entries, &WidgetEntryList::go_down ), false ) );
+            sigc::bind( sigc::mem_fun( m_TV_entries, &WidgetEntryList::go_down ), false ) );
 
     Lifeograph::create_action(
             false, m_action_jump2current, "Jump",
@@ -192,7 +215,7 @@ PanelDiary::PanelDiary()
             Gtk::AccelKey( GDK_KEY_l, Gdk::CONTROL_MASK ),
             sigc::mem_fun( this, &PanelDiary::show_prev_session_elem ) );
 
-    m_button_logout->add_accelerator(
+    m_B_logout->add_accelerator(
             "clicked",
             AppWindow::p->get_accel_group(),
             GDK_KEY_Escape,
@@ -243,7 +266,7 @@ PanelDiary::fill_treepaths( const Gtk::TreeModel::Children& children )
         DiaryElement* ptr = row[ ListData::colrec->ptr ];
 
         if( ptr )
-            ptr->m_list_data->treepath = m_treeview_entries->m_treestore->get_path( row );
+            ptr->m_list_data->treepath = m_TV_entries->m_treestore->get_path( row );
 
         switch( ptr->get_type() )
         {
@@ -251,7 +274,7 @@ PanelDiary::fill_treepaths( const Gtk::TreeModel::Children& children )
             case DiaryElement::ET_TOPIC:
             case DiaryElement::ET_GROUP:
                 if( dynamic_cast< Chapter* >( ptr )->get_expanded() )
-                    m_treeview_entries->expand_to_path( ptr->m_list_data->treepath );
+                    m_TV_entries->expand_to_path( ptr->m_list_data->treepath );
                 break;
             default:
                 break;
@@ -268,6 +291,7 @@ PanelDiary::add_chapter_category_to_list( const CategoryChapters* chapters )
     Gtk::TreeRow    row_entry;
     Chapter*        chapter = NULL;
     Entry*          entry = NULL;
+    bool            flag_chapter_added;
 
     for( CategoryChapters::const_iterator iter_chapter = chapters->begin();
          iter_chapter != chapters->end();
@@ -275,9 +299,15 @@ PanelDiary::add_chapter_category_to_list( const CategoryChapters* chapters )
     {
         chapter = iter_chapter->second;
 
-        // show all folders even when they are empty:
-        row_container = * m_treeview_entries->m_treestore->append( l_row_diary.children() );
-        fill_elem_row( row_container, chapter );
+        // show empty folders only when text search is not active
+        if( ! Diary::d->is_search_active() )
+        {
+            row_container = * m_TV_entries->m_treestore->append( m_row_diary.children() );
+            fill_elem_row( row_container, chapter );
+            flag_chapter_added = true;
+        }
+        else
+            flag_chapter_added = false;
 
         for( Chapter::Set::iterator iter_entry = chapter->begin();
              iter_entry != chapter->end(); ++iter_entry )
@@ -286,8 +316,14 @@ PanelDiary::add_chapter_category_to_list( const CategoryChapters* chapters )
 
             if( entry->get_filtered_out() == false )
             {
+                if( !flag_chapter_added )
+                {
+                    row_container = * m_TV_entries->m_treestore->append( m_row_diary.children() );
+                    fill_elem_row( row_container, chapter );
+                    flag_chapter_added = true;
+                }
                 m_entry_count++;
-                row_entry = * m_treeview_entries->m_treestore->append( row_container.children() );
+                row_entry = * m_TV_entries->m_treestore->append( row_container.children() );
                 fill_elem_row( row_entry, entry );
             }
         }
@@ -298,21 +334,21 @@ void
 PanelDiary::update_entry_list()
 {
     PRINT_DEBUG( "update_entry_list()" );
-    Lifeograph::m_internaloperation++;
+    Lifeograph::s_internaloperation++;
 
     AppWindow::p->m_entry_view->sync();
 
     // REMOVE MODEL AND DISBLE SORTING FOR SPEED-UP
-    m_treeview_entries->unset_model();
-    m_treeview_entries->m_treestore->set_sort_column(
+    m_TV_entries->unset_model();
+    m_TV_entries->m_treestore->set_sort_column(
             Gtk::TreeSortable::DEFAULT_UNSORTED_COLUMN_ID, Gtk::SORT_ASCENDING );
 
-    m_treeview_entries->m_treestore->clear();
+    m_TV_entries->m_treestore->clear();
     m_entry_count = 0;
 
     // DIARY ITEM
-    l_row_diary = * m_treeview_entries->m_treestore->append();
-    fill_elem_row( l_row_diary, Diary::d );
+    m_row_diary = * m_TV_entries->m_treestore->append();
+    fill_elem_row( m_row_diary, Diary::d );
 
     // CHAPTERS
     if( Diary::d->get_sorting_criteria() == SC_DATE )
@@ -329,11 +365,9 @@ PanelDiary::update_entry_list()
             if( entry->get_filtered_out() == false )
             {
                 m_entry_count++;
-                Gtk::TreeRow row = * m_treeview_entries->m_treestore->append(
-                        l_row_diary.children() );
+                Gtk::TreeRow row = * m_TV_entries->m_treestore->append( m_row_diary.children() );
                 fill_elem_row( row, entry );
             }
-
         }
     }
     else
@@ -345,8 +379,7 @@ PanelDiary::update_entry_list()
             if( entry->get_filtered_out() == false )
             {
                 m_entry_count++;
-                Gtk::TreeRow row = * m_treeview_entries->m_treestore->append(
-                        l_row_diary.children() );
+                Gtk::TreeRow row = * m_TV_entries->m_treestore->append( m_row_diary.children() );
                 fill_elem_row( row, entry );
             }
 
@@ -354,15 +387,15 @@ PanelDiary::update_entry_list()
     }
 
     // RESTORE MODEL AND SORTING (FOR SPEED-UP)
-    m_treeview_entries->m_treestore->set_sort_column(
+    m_TV_entries->m_treestore->set_sort_column(
             Gtk::TreeSortable::DEFAULT_SORT_COLUMN_ID, Gtk::SORT_ASCENDING );
-    m_treeview_entries->set_model( m_treeview_entries->m_treestore );
+    m_TV_entries->set_model( m_TV_entries->m_treestore );
 
     // set treepath values of listed elements
-    fill_treepaths( m_treeview_entries->m_treestore->children() );
+    fill_treepaths( m_TV_entries->m_treestore->children() );
 
     // always expand diary
-    m_treeview_entries->expand_element( Diary::d );
+    m_TV_entries->expand_element( Diary::d );
 
     // UPDATE CURRENT ELEM IF LAST ONE IS NOT IN THE LIST ANYMORE
     DiaryElement* elem = AppWindow::p->panel_main->get_cur_elem();
@@ -376,7 +409,7 @@ PanelDiary::update_entry_list()
             elem->show();
         }
         else if( elem->get_type() >= DiaryElement::ET_DIARY )
-            m_treeview_entries->present_element( elem );
+            m_TV_entries->present_element( elem );
     }
     else // the case at the start-up
     {
@@ -390,22 +423,22 @@ PanelDiary::update_entry_list()
 
     Diary::d->get_filter()->set_status_applied();
 
-    Lifeograph::m_internaloperation--;
+    Lifeograph::s_internaloperation--;
 }
 
 void
 PanelDiary::update_entry_list_style() // TODO: is this function really needed?
 {
-    Lifeograph::m_internaloperation++;
+    Lifeograph::s_internaloperation++;
 
     update_entry_list();
 
     if( AppWindow::p->panel_main->get_cur_elem_type() != DiaryElement::ET_ENTRY )
         Diary::d->show();
 
-    m_treeview_entries->columns_autosize();
+    m_TV_entries->columns_autosize();
 
-    Lifeograph::m_internaloperation--;
+    Lifeograph::s_internaloperation--;
 }
 
 void
@@ -415,7 +448,7 @@ PanelDiary::update_calendar()
 
     m_calendar->get_date( year, month, day );
     month++;	// fix month
-    Entry *entry;
+    Entry* entry;
     m_calendar->clear_marks();
 
     for( EntryIterConst itr_entry = Diary::d->get_entries().begin();
@@ -450,40 +483,40 @@ PanelDiary::handle_login()
     m_MI_logout_wo_saving->set_visible( ! Diary::d->is_read_only() );
     update_disable_auto_logout_MI();
 
-    static Gtk::Label *dummy_title = new Gtk::Label;
+    static Gtk::Label* dummy_title = new Gtk::Label;
     AppWindow::p->m_headerbar.pack_start( *m_Bx_new_elem );
     AppWindow::p->m_headerbar.set_custom_title( *dummy_title );
     AppWindow::p->m_headerbar.pack_start( *m_grid_elem_header );
     AppWindow::p->m_headerbar.pack_end( *m_Bx_logout );
-    AppWindow::p->m_headerbar.pack_end( *m_button_tools );
-    AppWindow::p->m_headerbar.pack_end( *m_E_search );
+    AppWindow::p->m_headerbar.pack_end( *m_B_tools );
+    AppWindow::p->m_headerbar.pack_end( *m_Bx_search );
 
     switch( Diary::d->get_sorting_criteria() )
     {
         default: // future-proofing
         case SC_DATE: // no break
-            m_menuitem_sort_by_date->set_active();
+            m_MI_sort_by_date->set_active();
             break;
-        case SC_SIZE:
-            m_menuitem_sort_by_size->set_active();
+        case SC_SIZE_C:
+            m_MI_sort_by_size->set_active();
             break;
         case SC_CHANGE:
-            m_menuitem_sort_by_change->set_active();
+            m_MI_sort_by_change->set_active();
             break;
     }
 
     // not called automatically because of m_internaloperation:
-    m_treeview_entries->reset_sorting_criteria();
+    m_TV_entries->reset_sorting_criteria();
 
     if( Diary::d->is_read_only() )
     {
-        m_treeview_entries->unset_rows_drag_source();
-        m_treeview_entries->unset_rows_drag_dest();
+        m_TV_entries->unset_rows_drag_source();
+        m_TV_entries->unset_rows_drag_dest();
     }
     else
     {
-        m_treeview_entries->enable_model_drag_source( Lifeograph::p->drag_targets_entry );
-        m_treeview_entries->enable_model_drag_dest( Lifeograph::p->drag_targets_entry,
+        m_TV_entries->enable_model_drag_source( Lifeograph::p->drag_targets_entry );
+        m_TV_entries->enable_model_drag_dest( Lifeograph::p->drag_targets_entry,
                                                     Gdk::ACTION_MOVE );
     }
 
@@ -495,7 +528,7 @@ PanelDiary::handle_login()
 void
 PanelDiary::handle_logout()
 {
-    Lifeograph::m_internaloperation++;
+    Lifeograph::s_internaloperation++;
 
     m_PO_replace.hide();
 
@@ -503,52 +536,59 @@ PanelDiary::handle_logout()
     gtk_header_bar_set_custom_title( AppWindow::p->m_headerbar.gobj(), NULL );
     AppWindow::p->m_headerbar.remove( *m_grid_elem_header );
     AppWindow::p->m_headerbar.remove( *m_Bx_logout );
-    AppWindow::p->m_headerbar.remove( *m_button_tools );
-    AppWindow::p->m_headerbar.remove( *m_E_search );
+    AppWindow::p->m_headerbar.remove( *m_B_tools );
+    AppWindow::p->m_headerbar.remove( *m_Bx_search );
 
-    m_treeview_entries->clear();
+    m_TV_entries->clear();
 
     m_E_search->set_text( "" );
     m_E_replace->set_text( "" );
 
-    Lifeograph::m_internaloperation--;
+    Lifeograph::s_internaloperation--;
 }
 
 void
 PanelDiary::show( const DiaryElement* element )
 {
     if( element->get_type() >= DiaryElement::ET_DIARY ) // if a list element
-        m_treeview_entries->present_element( element );
+        m_TV_entries->present_element( element );
     //else - selected rows on the list no longer have any relation with the current view
         //m_treeview_entries->get_selection()->unselect_all();
 
     if( element->get_type() > DiaryElement::ET_DIARY )
     {
-        select_date_in_calendar( element->get_date() );
-        m_menuitem_add_entry->set_sensitive( true );
+        m_MI_add_entry->set_sensitive( true );
 
         if( element->get_date().is_ordinal() )
         {
+            if( element->get_type() == DiaryElement::ET_ENTRY )
+            {
+                Date d( Date::make_date_from_ctime(
+                        dynamic_cast< const Entry* >( element )->get_date_created() ) );
+                select_date_in_calendar( d );
+            }
+
             Chapter* c = element->get_date().is_hidden() ?
                     Diary::d->get_groups()->get_chapter( element->get_date().get_pure() ) :
                     Diary::d->get_topics()->get_chapter( element->get_date().get_pure() );
             if( c == NULL )
-                m_menuitem_add_entry->set_sensitive( false );
+                m_MI_add_entry->set_sensitive( false );
             else
-                m_menuitem_add_entry->set_tooltip_text(
+                m_MI_add_entry->set_tooltip_text(
                         Glib::ustring::compose( _( "Create a new entry in %1" ), c->get_name() ) );
-            m_menuitem_add_chapter->set_sensitive( false );
-            m_menuitem_add_chapter->set_tooltip_text( _( "Please select a date" ) );
+            m_MI_add_chapter->set_sensitive( false );
+            m_MI_add_chapter->set_tooltip_text( _( "Please select a date" ) );
         }
         else
         {
-            m_menuitem_add_entry->set_tooltip_text(
+            select_date_in_calendar( element->get_date() );
+            m_MI_add_entry->set_tooltip_text(
                     Glib::ustring::compose( _( "Create a new entry on %1" ),
                                             element->get_date().format_string() ) );
-            m_menuitem_add_chapter->set_tooltip_text(
+            m_MI_add_chapter->set_tooltip_text(
                     Glib::ustring::compose( _( "Create a new chapter on %1" ),
                                             element->get_date().format_string() ) );
-            m_menuitem_add_chapter->set_sensitive(
+            m_MI_add_chapter->set_sensitive(
                     Diary::d->get_current_chapter_ctg()->get_chapter(
                             element->get_date().get_pure() ) == NULL );
         }
@@ -556,18 +596,18 @@ PanelDiary::show( const DiaryElement* element )
     else
     {
         m_calendar->select_day( 0 );
-        m_menuitem_add_entry->set_sensitive( false );
-        m_menuitem_add_chapter->set_sensitive( false );
+        m_MI_add_entry->set_sensitive( false );
+        m_MI_add_chapter->set_sensitive( false );
 
-        m_menuitem_add_entry->set_tooltip_text( _( "Please select a date or chapter" ) );
-        m_menuitem_add_chapter->set_tooltip_text( _( "Please select a date" ) );
+        m_MI_add_entry->set_tooltip_text( _( "Please select a date or chapter" ) );
+        m_MI_add_chapter->set_tooltip_text( _( "Please select a date" ) );
     }
 }
 
 void
 PanelDiary::show_today()
 {
-    Entry *entry_today = Diary::d->get_entry_today();
+    Entry* entry_today = Diary::d->get_entry_today();
     bool flag_add = false;
 
     if( entry_today == NULL )   // add new entry if no entry exists on selected date
@@ -594,7 +634,7 @@ PanelDiary::show_today()
 void
 PanelDiary::show_prev_session_elem()
 {
-    DiaryElement *elem( Diary::d->get_prev_session_elem() );
+    DiaryElement* elem( Diary::d->get_prev_session_elem() );
     if( elem != NULL )
         elem->show();
     else
@@ -604,18 +644,18 @@ PanelDiary::show_prev_session_elem()
 void
 PanelDiary::present_current_row()
 {
-    Gtk::TreeIter iter = m_treeview_entries->get_selection()->get_selected();
-    if( iter == m_treeview_entries->m_treestore->children().end() )
+    Gtk::TreeIter iter = m_TV_entries->get_selection()->get_selected();
+    if( iter == m_TV_entries->m_treestore->children().end() )
         return;
-    Gtk::TreePath path = m_treeview_entries->m_treestore->get_path( iter );
+    Gtk::TreePath path = m_TV_entries->m_treestore->get_path( iter );
 
-    m_treeview_entries->scroll_to_row( path );
+    m_TV_entries->scroll_to_row( path );
 }
 
 void
 PanelDiary::handle_calendar_dayselected()
 {
-    if( Lifeograph::m_internaloperation ) return;
+    if( Lifeograph::s_internaloperation ) return;
 
     guint year, month, day;
     m_calendar->get_date( year, month, day );
@@ -636,13 +676,13 @@ PanelDiary::handle_calendar_dayselected()
         entry->show();
     else
     {
-        m_menuitem_add_entry->set_sensitive( bool( day > 0 ) );
-        m_menuitem_add_chapter->set_sensitive( bool ( day > 0 &&
+        m_MI_add_entry->set_sensitive( bool( day > 0 ) );
+        m_MI_add_chapter->set_sensitive( bool ( day > 0 &&
                 Diary::d->get_current_chapter_ctg()->get_chapter( date.m_date ) == NULL ) );
 
-        m_menuitem_add_entry->set_tooltip_text(
+        m_MI_add_entry->set_tooltip_text(
                 Glib::ustring::compose( _( "Create a new entry on %1" ), date.format_string() ) );
-        m_menuitem_add_chapter->set_tooltip_text(
+        m_MI_add_chapter->set_tooltip_text(
                 Glib::ustring::compose( _( "Create a new chapter on %1" ),
                                         date.format_string() ) );
     }
@@ -651,7 +691,7 @@ PanelDiary::handle_calendar_dayselected()
 void
 PanelDiary::handle_calendar_monthchanged()
 {
-    if( Lifeograph::m_internaloperation ) return;
+    if( Lifeograph::s_internaloperation ) return;
 
     update_calendar();
 }
@@ -690,7 +730,7 @@ PanelDiary::handle_add_entry()
 void
 PanelDiary::handle_add_group()
 {
-    Chapter *c( Diary::d->get_groups()->create_chapter_ordinal( _( STRING::NEW_CHAPTER_NAME ) ) );
+    Chapter* c( Diary::d->get_groups()->create_chapter_ordinal( _( STRING::NEW_CHAPTER_NAME ) ) );
     Diary::d->update_entries_in_chapters();
     update_entry_list();
     c->show();
@@ -700,7 +740,7 @@ PanelDiary::handle_add_group()
 void
 PanelDiary::handle_add_topic()
 {
-    Chapter *c( Diary::d->get_topics()->create_chapter_ordinal( _( STRING::NEW_CHAPTER_NAME ) ) );
+    Chapter* c( Diary::d->get_topics()->create_chapter_ordinal( _( STRING::NEW_CHAPTER_NAME ) ) );
     Diary::d->update_entries_in_chapters();
     update_entry_list();
     c->show();
@@ -712,11 +752,11 @@ PanelDiary::handle_add_chapter()
 {
     guint year, month, day;
     m_calendar->get_date( year, month, day );
-    Date date( year, month + 1, day );
+    Date::date_t date = Date::make_date( year, month + 1, day );
 
-    if( day > 0 && Diary::d->get_current_chapter_ctg()->get_chapter( date.m_date ) == NULL )
+    if( day > 0 && Diary::d->get_current_chapter_ctg()->get_chapter( date ) == NULL )
     {
-        Chapter *c( Diary::d->get_current_chapter_ctg()->create_chapter(
+        Chapter* c( Diary::d->get_current_chapter_ctg()->create_chapter(
                 _( "Untitled chapter" ), date ) );
 
         Diary::d->update_entries_in_chapters();
@@ -729,7 +769,7 @@ PanelDiary::handle_add_chapter()
 void
 PanelDiary::select_date_in_calendar( const Date& date )
 {
-    ++Lifeograph::m_internaloperation;
+    ++Lifeograph::s_internaloperation;
 
     // CALENDAR
     // the current day has to be deselected first to avoid gtk's complaints
@@ -739,7 +779,7 @@ PanelDiary::select_date_in_calendar( const Date& date )
         guint year, month, day;
         m_calendar->get_date( year, month, day );
 
-        if( year != date.get_year() || month != date.get_month() + 1 )
+        if( year != date.get_year() || month != date.get_month() - 1 )
         {
             m_calendar->select_month( date.get_month() - 1, date.get_year() );
             update_calendar();
@@ -748,7 +788,7 @@ PanelDiary::select_date_in_calendar( const Date& date )
         m_calendar->select_day( date.get_day() );
     }
 
-    --Lifeograph::m_internaloperation;
+    --Lifeograph::s_internaloperation;
 }
 
 void
@@ -765,7 +805,7 @@ PanelDiary::go_prev_match()
     int i = 0;
     do
     {
-        m_treeview_entries->go_up( true );
+        m_TV_entries->go_up( true );
         // put cursor to the end:
         AppWindow::p->m_entry_view->get_buffer()->select_range(
                 AppWindow::p->m_entry_view->get_buffer()->end(),
@@ -779,7 +819,7 @@ PanelDiary::go_prev_match()
 void
 PanelDiary::go_next_match()
 {
-    if( m_entry_count < 1 )
+    if( m_entry_count < 1 || m_E_search->get_text().empty() )
         return;
 
     // TODO: move to Entry
@@ -790,16 +830,17 @@ PanelDiary::go_next_match()
     int i = 0;
     do
     {
-        m_treeview_entries->go_down( true );
+        m_TV_entries->go_down( true );
         i++;
     }
-    while( ! AppWindow::p->m_entry_view->get_buffer()->select_searchstr_next() && i < m_entry_count );
+    while( ! AppWindow::p->m_entry_view->get_buffer()->select_searchstr_next() &&
+           i < m_entry_count );
 }
 
 void
 PanelDiary::handle_entry_title_changed( DiaryElement* element )
 {
-    if( Lifeograph::m_internaloperation ) return;
+    if( Lifeograph::s_internaloperation ) return;
 
     Gtk::TreeRow row = * get_row( element->m_list_data->treepath );
     row[ ListData::colrec->info ] = element->get_list_str();
@@ -808,7 +849,7 @@ PanelDiary::handle_entry_title_changed( DiaryElement* element )
 Gtk::TreeRow
 PanelDiary::get_row( const Gtk::TreePath& path )
 {
-    return( * m_treeview_entries->m_treestore->get_iter( path ) );
+    return( * m_TV_entries->m_treestore->get_iter( path ) );
     // TODO: check validity
 }
 
@@ -827,7 +868,7 @@ PanelDiary::handle_treeview_row_expanded( const Gtk::TreeIter& iter,
         case DiaryElement::ET_GROUP:
         {
             Chapter* chapter = dynamic_cast< Chapter* >( element );
-            chapter->set_expanded( m_treeview_entries->row_expanded( path ) );
+            chapter->set_expanded( m_TV_entries->row_expanded( path ) );
         }
         break;
     default:
@@ -835,11 +876,32 @@ PanelDiary::handle_treeview_row_expanded( const Gtk::TreeIter& iter,
     }
 }
 
-// SEARCH & REPLACE
+// FILTER, SEARCH & REPLACE
+void
+PanelDiary::revert_filter()
+{
+    Diary::d->get_filter()->set( Diary::d->get_filter_default() );
+    Diary::d->get_filter()->set_status_outstanding();
+    update_calendar();
+    update_entry_list();
+    AppWindow::p->panel_extra->set_filtered_tag( Diary::d->get_filter_default()->get_tag() );
+    m_B_filter_revert->set_visible( false );
+}
+
+void
+PanelDiary::handle_filter_changed()
+{
+    m_B_filter_revert->set_visible(
+            !( *Diary::d->get_filter() == *Diary::d->get_filter_default() ) );
+
+    update_calendar();
+    update_entry_list();
+}
+
 void
 PanelDiary::handle_search_string_changed()
 {
-    if( Lifeograph::m_internaloperation ) return;
+    if( Lifeograph::s_internaloperation ) return;
     // current entry must be closed here or else it loses...
     // ...changes since it was selected:
     //AppWindow::p->m_entry_view->sync(); update_entry_list() does the syncing
@@ -847,11 +909,11 @@ PanelDiary::handle_search_string_changed()
     const std::string filterstring( m_E_search->get_text().lowercase() );
 
     Diary::d->set_search_text( filterstring );
-    AppWindow::p->panel_diary->update_entry_list();    // syncs current entry
+    update_entry_list();    // syncs current entry
 
     if( filterstring.size() > 0 )
     {
-        if( AppWindow::p->panel_diary->get_entry_count() > 0 )
+        if( m_entry_count > 0 )
         {
             AppWindow::p->m_entry_view->get_buffer()->set_search_str( filterstring );
             if( AppWindow::p->panel_main->get_cur_elem_type() == DiaryElement::ET_ENTRY )
@@ -861,7 +923,7 @@ PanelDiary::handle_search_string_changed()
         m_E_search->set_tooltip_markup(
                 Glib::ustring::compose(
                         _( "Found in <b>%1</b> of <b>%2</b> entrie(s)" ),
-                        AppWindow::p->panel_diary->get_entry_count(), Diary::d->get_size() ) );
+                        m_entry_count, Diary::d->get_size() ) );
     }
     else
     {
@@ -869,9 +931,9 @@ PanelDiary::handle_search_string_changed()
         m_E_search->set_tooltip_text( _( "Search text within entries" ) );
     }
 
-    AppWindow::p->panel_diary->update_calendar();
+    update_calendar();
 
-    if( AppWindow::p->panel_diary->get_entry_count() < 1 || filterstring.size() < 1 )
+    if( m_entry_count < 1 || filterstring.size() < 1 )
         m_PO_replace.hide();
     else
     {
@@ -887,12 +949,12 @@ void
 PanelDiary::replace_match()
 {
     if( ! AppWindow::p->m_entry_view->get_buffer()->get_has_selection() )
-        AppWindow::p->panel_diary->go_next_match();
+        go_next_match();
     if( AppWindow::p->m_entry_view->get_buffer()->get_has_selection() )
     {
         AppWindow::p->m_entry_view->get_buffer()->erase_selection();
         AppWindow::p->m_entry_view->get_buffer()->insert_at_cursor( m_E_replace->get_text() );
-        AppWindow::p->panel_diary->go_next_match();
+        go_next_match();
     }
 }
 
@@ -905,7 +967,7 @@ PanelDiary::replace_all_matches()
     // update current entry:
     if( AppWindow::p->panel_main->get_cur_elem_type() == DiaryElement::ET_ENTRY )
     {
-        Entry *entry = dynamic_cast< Entry* >( AppWindow::p->panel_main->get_cur_elem() );
+        Entry* entry = dynamic_cast< Entry* >( AppWindow::p->panel_main->get_cur_elem() );
         AppWindow::p->m_entry_view->get_buffer()->set_richtext( entry );
     }
 }
