@@ -68,8 +68,10 @@ class PanelDiary
         { return m_entry_count; }
 
         void                    do_for_each_selected_entry( sigc::slot< void, Entry* >& slot )
-        { m_treeview_entries->do_for_each_selected_entry( slot ); }
+        { m_TV_entries->do_for_each_selected_entry( slot ); }
 
+        void                    revert_filter();
+        void                    handle_filter_changed();
         void                    handle_search_string_changed(); // temporarily public
 
     protected:
@@ -84,14 +86,14 @@ class PanelDiary
         void                    handle_disable_auto_logout_toggled();
         void                    update_disable_auto_logout_MI();
 
-        WidgetEntryList*        m_treeview_entries;
+        WidgetEntryList*        m_TV_entries;
 
-        Gtk::Button*            m_button_logout;
+        Gtk::Button*            m_B_logout;
         Gtk::Calendar*          m_calendar;
 
-        Gtk::RadioMenuItem*     m_menuitem_sort_by_date;
-        Gtk::RadioMenuItem*     m_menuitem_sort_by_size;
-        Gtk::RadioMenuItem*     m_menuitem_sort_by_change;
+        Gtk::RadioMenuItem*     m_MI_sort_by_date;
+        Gtk::RadioMenuItem*     m_MI_sort_by_size;
+        Gtk::RadioMenuItem*     m_MI_sort_by_change;
 
         Gtk::Grid*              m_grid_elem_header;
         Gtk::Box*               m_Bx_new_elem;
@@ -101,14 +103,17 @@ class PanelDiary
         Gtk::MenuItem*          m_MI_logout_wo_saving;
 
         Gtk::MenuButton*        m_MB_add;
-        Gtk::ImageMenuItem*     m_menuitem_add_entry;
-        Gtk::ImageMenuItem*     m_menuitem_add_topic;
-        Gtk::ImageMenuItem*     m_menuitem_add_group;
-        Gtk::ImageMenuItem*     m_menuitem_add_chapter;
+        Gtk::ImageMenuItem*     m_MI_add_entry;
+        Gtk::ImageMenuItem*     m_MI_add_topic;
+        Gtk::ImageMenuItem*     m_MI_add_group;
+        Gtk::ImageMenuItem*     m_MI_add_chapter;
         Gtk::Separator*         m_sprt_tb1;
 
-        Gtk::MenuButton*        m_button_tools;
+        Gtk::MenuButton*        m_B_tools;
 
+        Gtk::Box*               m_Bx_search;
+        Gtk::Button*            m_B_filter;
+        Gtk::Button*            m_B_filter_revert;
         Gtk::SearchEntry*       m_E_search;
         EntryClear*             m_E_replace;
         Gtk::Button*            m_B_match_prev;
@@ -131,7 +136,7 @@ class PanelDiary
         // LISTING TMP VARIABLES
         void                    add_chapter_category_to_list( const CategoryChapters* );
         void                    fill_treepaths( const Gtk::TreeModel::Children& );
-        Gtk::TreeRow            l_row_diary;
+        Gtk::TreeRow            m_row_diary;
         int                     m_entry_count;
 
     friend class Lifeograph;
