@@ -66,8 +66,6 @@ PanelExtra::PanelExtra( BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder
         cellr_filter = Gtk::manage( new Gtk::CellRendererPixbuf );
         cellr_name = Gtk::manage( new Gtk::CellRendererText );
         column = Gtk::manage( new Gtk::TreeViewColumn( "" ) );
-
-        Lifeograph::builder->get_widget( "button_filter", m_button_filter );
     }
     catch( ... )
     {
@@ -116,9 +114,6 @@ PanelExtra::PanelExtra( BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder
             sigc::mem_fun( this, &PanelExtra::handle_treeview_row_expanded ) );
     this->signal_row_collapsed().connect(
             sigc::mem_fun( this, &PanelExtra::handle_treeview_row_expanded ) );
-
-    m_button_filter->signal_clicked().connect(
-            sigc::mem_fun( Diary::d->m_filter_active, &DiaryElement::show ) );
 }
 
 void
@@ -142,11 +137,11 @@ PanelExtra::handle_login()
 void
 PanelExtra::handle_logout()
 {
-    Lifeograph::m_internaloperation++;
+    Lifeograph::s_internaloperation++;
 
     m_treestore->clear();
 
-    Lifeograph::m_internaloperation--;
+    Lifeograph::s_internaloperation--;
 }
 
 void
@@ -206,7 +201,7 @@ PanelExtra::cell_data_func_filter( Gtk::CellRenderer* cell, const Gtk::TreeModel
 void
 PanelExtra::populate()
 {
-    Lifeograph::m_internaloperation++;
+    Lifeograph::s_internaloperation++;
 
     m_treestore->clear();
 
@@ -270,7 +265,7 @@ PanelExtra::populate()
     /*for( FilterVector::iterator iter = )
         add_elem_to_list( *iter );*/
 
-    Lifeograph::m_internaloperation--;
+    Lifeograph::s_internaloperation--;
 }
 
 inline Gtk::TreeIter
@@ -548,7 +543,7 @@ void
 PanelExtra::handle_treeview_row_expanded( const Gtk::TreeIter& iter,
                                           const Gtk::TreePath& path )
 {
-    if( Lifeograph::m_internaloperation )
+    if( Lifeograph::s_internaloperation )
         return;
 
     DiaryElement *element = ( * iter )[ m_treestore->colrec.ptr ];
@@ -581,9 +576,7 @@ PanelExtra::handle_treeview_row_activated( const Gtk::TreePath& path, Gtk::TreeV
 
         Diary::d->set_filter_tag( tag );
         set_filtered_tag( tag );
-
-        AppWindow::p->m_tag_view->update_button_filter_tag();
-        AppWindow::p->panel_diary->update_entry_list();
+        AppWindow::p->panel_diary->handle_filter_changed();
     }
 }
 
