@@ -49,6 +49,8 @@ PanelMain::PanelMain()
     Lifeograph::builder->get_widget( "I_header_overlay", m_image_overlay );
     Lifeograph::builder->get_widget( "A_header_extra_tools", m_alignment_extra_tools );
 
+    Lifeograph::builder->get_widget( "B_filter", m_B_filter ); // mainly dealt by PanelDiary
+
     for( int i = 0; i < BROWSING_HISTORY_SIZE; i++ )
         m_browsing_history[ i ] = NULL;
 
@@ -102,7 +104,7 @@ PanelMain::show( ElementShowerProto* shower )
 
     m_cur_shower = shower;
 
-    Lifeograph::m_internaloperation++;
+    Lifeograph::s_internaloperation++;
 
     // HEADER TEXTS
     m_label_elem_title->set_text( shower->get_title_str() );
@@ -124,6 +126,8 @@ PanelMain::show( ElementShowerProto* shower )
 
     set_extra_tools( shower->get_extra_tools() );
 
+    m_B_filter->set_sensitive( shower->get_element()->get_type() != DiaryElement::ET_FILTER );
+
     // CONTENT
     if( m_ptr2widget != shower->get_widget() )
     {
@@ -139,7 +143,7 @@ PanelMain::show( ElementShowerProto* shower )
 
     AppWindow::p->panel_diary->show( shower->get_element() );
 
-    Lifeograph::m_internaloperation--;
+    Lifeograph::s_internaloperation--;
 }
 
 void
