@@ -671,9 +671,9 @@ EntryParserPango::apply_check_ccl()
     const Glib::ustring esc_text(
             m_ptr2entry->get_text()->substr( pos_regular, pos_current - pos_regular ) );
     m_pango_text += Glib::Markup::escape_text( esc_text );
-    pos_regular = pos_current;
+    pos_regular = pos_current + 1;
 
-    m_pango_text += "<s>";
+    m_pango_text += " <s>";
 }
 
 void
@@ -689,6 +689,30 @@ EntryParserPango::apply_check_ccl_end()
     m_pango_text += "</s>";
 }
 
+void
+EntryParserPango::apply_check_fin()
+{
+    const Glib::ustring esc_text(
+            m_ptr2entry->get_text()->substr( pos_regular, pos_current - pos_regular ) );
+    m_pango_text += Glib::Markup::escape_text( esc_text );
+    pos_regular = pos_current + 1;
+
+    m_pango_text += " <span bgcolor='yellow'>";
+}
+
+void
+EntryParserPango::apply_check_fin_end()
+{
+    if( pos_regular < pos_current )
+    {
+        const Glib::ustring esc_text(
+                m_ptr2entry->get_text()->substr( pos_regular, pos_current - pos_regular ) );
+        m_pango_text += Glib::Markup::escape_text( esc_text );
+        pos_regular = pos_current;
+    }
+    m_pango_text += "</span>";
+}
+
 void
 EntryParserPango::apply_link()
 {
@@ -697,23 +721,23 @@ EntryParserPango::apply_link()
 
     if( m_flag_hidden_link )
     {
-        offset1 = pos_tab - m_pos_start;
+        offset1 = pos_tab - m_pos_start + 1;
         offset2 = -offset1;
     }
     else if( m_pos_start > 0 )   // first line is reserved for title
     {
         // HANDLE RELATIVE LINKS
-        if( word_last.find( "rel://" ) == 0 )
-            word_last.replace( 0, 5, "file://" + Glib::path_get_dirname( Diary::d->get_path() ) );
+        if( m_word_last.find( "rel://" ) == 0 )
+            m_word_last.replace( 0, 5, "file://" + Glib::path_get_dirname( Diary::d->get_path() ) );
 
-        if( word_last.find( "file:///" ) == 0 &&
+        if( m_word_last.find( "file:///" ) == 0 &&
             // there can be no text on the same line as the image:
             get_char_at( m_pos_start - 1 ) == '\n' && char_current == '\n' )
         {
             try
             {
-                m_pango_pixbuf =Lifeograph::get_thumbnail( Glib::filename_from_uri( word_last ),
-                                                          m_max_thumbnail_width );
+                m_pango_pixbuf = Lifeograph::get_thumbnail( Glib::filename_from_uri( m_word_last ),
+                                                            m_max_thumbnail_width );
                 m_pango_return = Printable::PT_IMAGE;
                 m_pango_begin = pos_current;
 
