@@ -122,6 +122,8 @@ class EntryParserPango : public EntryParser
         void                    apply_highlight();
         void                    apply_check_ccl();
         void                    apply_check_ccl_end();
+        void                    apply_check_fin();
+        void                    apply_check_fin_end();
         void                    apply_link();
         void                    apply_link_id() { apply_link(); }
         void                    apply_link_date() { apply_link(); }
