@@ -23,11 +23,15 @@
 #ifndef LIFEOGRAPH_STRINGS_HEADER
 #define LIFEOGRAPH_STRINGS_HEADER
 
-
+#ifndef LIFEO_WINDOZE
 #include <libintl.h>
-
+#endif
 // DEFINITIONS FOR LIBGETTEXT
+#ifndef LIFEO_WINDOZE
 #define _(String)               gettext(String)
+#else
+#define _(String)               String
+#endif
 #define gettext_noop(String)    String
 #define N_(String)              gettext_noop(String)
 // END OF LIBGETTEXT DEFINITIONS
