@@ -37,7 +37,7 @@ Undoable::Undoable( const Glib::ustring& name, UndoableType type )
 // static undo manager
 UndoManager *UndoManager::m = NULL;
 
-UndoManager::UndoManager( void )
+UndoManager::UndoManager()
     :   m_freezed( false )
 {
 
@@ -62,7 +62,7 @@ UndoManager::add_action( Undoable *action )
 }
 
 void
-UndoManager::clear( void )
+UndoManager::clear()
 {
     int i;
     for(  i = m_stack_undo.size()-1; i>= 0; i-- )
@@ -76,7 +76,7 @@ UndoManager::clear( void )
 }
 
 void
-UndoManager::undo( void )
+UndoManager::undo()
 {
     if(  ! m_stack_undo.empty() )
     {
@@ -89,7 +89,7 @@ UndoManager::undo( void )
 }
 
 void
-UndoManager::redo( void )
+UndoManager::redo()
 {
     if(  ! m_stack_redo.empty() )
     {
