@@ -47,17 +47,17 @@ class Undoable {
                                     Undoable( const Glib::ustring&, UndoableType );
         virtual                     ~Undoable() {}
 
-        glong                       get_time_sec( void ) const
+        glong                       get_time_sec() const
         {
             return m_time.tv_sec;
         }
 
-        Glib::TimeVal               get_time( void ) const
+        Glib::TimeVal               get_time() const
         {
             return m_time;
         }
 
-        UndoableType                get_type( void ) const
+        UndoableType                get_type() const
         {
             return m_type;
         }
@@ -65,8 +65,8 @@ class Undoable {
     protected:
         virtual bool                can_merge( const Undoable* ) const = 0;
         virtual void                merge( Undoable* ) = 0;
-        virtual void                undo( void ) = 0;
-        virtual void                redo( void ) = 0;
+        virtual void                undo() = 0;
+        virtual void                redo() = 0;
 
         Glib::ustring               m_name;
         Glib::TimeVal               m_time;
@@ -80,34 +80,34 @@ class Undoable {
 // UNDO MANAGER
 class UndoManager {
     public:
-                                    UndoManager( void );
+                                    UndoManager();
 
         void                        add_action( Undoable* );
-        void                        clear( void );
+        void                        clear();
 
-        bool                        can_undo( void )
+        bool                        can_undo()
         {
             return(  m_stack_undo.size() > 0 );
         }
 
-        bool                        can_redo( void )
+        bool                        can_redo()
         {
             return(  m_stack_redo.size() > 0 );
         }
 
-        bool                        is_freezed( void )
+        bool                        is_freezed()
         {
             return m_freezed;
         }
 
-        void                        undo( void );
-        void                        redo( void );
-        void                        freeze( void )
+        void                        undo();
+        void                        redo();
+        void                        freeze()
         {
             m_freezed = true;
 
         }
-        void                        thaw( void )
+        void                        thaw()
         {
             m_freezed = false;
         }
