@@ -34,8 +34,7 @@ using namespace LIFEO;
 
 
 EntryView::EntryView()
-:   m_tag_operation_cur( TO_NONE ), m_entry_sync( NULL ),
-    m_flag_entrychanged( false )
+:   m_tag_operation_cur( TO_NONE ), m_entry_sync( NULL ), m_flag_entrychanged( false )
 {
     Entry::shower = this;
 
@@ -54,7 +53,10 @@ EntryView::EntryView()
         Lifeograph::builder->get_widget( "RB_entry_progressed", m_button_progressed );
         Lifeograph::builder->get_widget( "RB_entry_done", m_button_done );
         Lifeograph::builder->get_widget( "RB_entry_canceled", m_button_canceled );
-        Lifeograph::builder->get_widget( "L_entry_info", m_label_info );
+        Lifeograph::builder->get_widget( "L_entry_created", m_label_created );
+        Lifeograph::builder->get_widget( "L_entry_edited", m_label_edited );
+        Lifeograph::builder->get_widget( "L_entry_status", m_label_status );
+        Lifeograph::builder->get_widget( "L_entry_status_changed", m_label_status_changed );
         Lifeograph::builder->get_widget( "TB_entry_favorite", m_button_toggle_favorite );
         Lifeograph::builder->get_widget( "B_entry_print", button_print );
         Lifeograph::builder->get_widget( "B_entry_filter", button_hide );
@@ -65,24 +67,58 @@ EntryView::EntryView()
         Lifeograph::builder->get_widget( "B_entry_dismiss", m_button_dismiss );
 
 
-        Lifeograph::builder->get_widget( "hbox_entry_toolbar_text", m_hbox_editing_toolbar );
-        Lifeograph::builder->get_widget( "button_entry_bold", m_button_bold );
-        Lifeograph::builder->get_widget( "button_entry_italic", m_button_italic );
-        Lifeograph::builder->get_widget( "button_entry_strikethrough", m_button_strikethrough );
-        Lifeograph::builder->get_widget( "button_entry_highlight", m_button_highlight );
-        Lifeograph::builder->get_widget( "label_entry_highlight", m_label_highlight );
-        Lifeograph::builder->get_widget( "evntb_entry_highlight", m_eventbox_highlight );
-        Lifeograph::builder->get_widget( "button_entry_add_bullet", m_button_add_bullet );
-        Lifeograph::builder->get_widget( "button_entry_add_checkbox", m_button_add_checkbox );
-        Lifeograph::builder->get_widget( "tgglbutton_entry_comments", m_button_toggle_comments );
-        Lifeograph::builder->get_widget_derived( "textview_entry", m_textview );
+        Lifeograph::builder->get_widget( "Bx_entry_toolbar_text", m_Bx_editing_toolbar );
+        Lifeograph::builder->get_widget( "B_entry_bold", m_button_bold );
+        Lifeograph::builder->get_widget( "B_entry_italic", m_button_italic );
+        Lifeograph::builder->get_widget( "B_entry_strikethrough", m_button_strikethrough );
+        Lifeograph::builder->get_widget( "B_entry_highlight", m_button_highlight );
+        Lifeograph::builder->get_widget( "L_entry_highlight", m_label_highlight );
+        Lifeograph::builder->get_widget( "EB_entry_highlight", m_eventbox_highlight );
+        Lifeograph::builder->get_widget( "MB_entry_list_item", m_MB_list_item );
+        Lifeograph::builder->get_widget( "MI_entry_list_item_none", m_MI_list_none );
+        Lifeograph::builder->get_widget( "MI_entry_list_item_bullet", m_MI_list_bullet );
+        Lifeograph::builder->get_widget( "MI_entry_list_item_todo", m_MI_list_todo );
+        Lifeograph::builder->get_widget( "MI_entry_list_item_progressed", m_MI_list_progressed );
+        Lifeograph::builder->get_widget( "MI_entry_list_item_done", m_MI_list_done );
+        Lifeograph::builder->get_widget( "MI_entry_list_item_canceled", m_MI_list_canceled );
+        Lifeograph::builder->get_widget( "TB_entry_comments", m_TB_comments );
+        Lifeograph::builder->get_widget_derived( "TV_entry", m_textview );
 
         Lifeograph::builder->get_widget( "Bx_entry_tag_edit", m_box_tag_edit );
         Lifeograph::builder->get_widget( "Bx_entry_tag_linked", m_Bx_tag_linked );
         Lifeograph::builder->get_widget_derived( "E_tag_filter", m_tag_widget );
         Lifeograph::builder->get_widget( "B_entry_tag", m_button_tag_operation );
         Lifeograph::builder->get_widget( "B_entry_tag_theme", m_button_set_theme );
-        Lifeograph::builder->get_widget_derived( "drawingarea_entry_tags", m_widgettaglist );
+        Lifeograph::builder->get_widget_derived( "DA_entry_tags", m_widgettaglist );
+
+        // THEMABLE ICONS
+        Gtk::Image* img;
+        Lifeograph::builder->get_widget( "I_entry_not_todo", img );
+        img->set( Lifeograph::icons->entry_32 );
+        Lifeograph::builder->get_widget( "I_entry_todo", img );
+        img->set( Lifeograph::icons->todo_open_32 );
+        Lifeograph::builder->get_widget( "I_entry_progressed", img );
+        img->set( Lifeograph::icons->todo_progressed_32 );
+        Lifeograph::builder->get_widget( "I_entry_done", img );
+        img->set( Lifeograph::icons->todo_done_32 );
+        Lifeograph::builder->get_widget( "I_entry_canceled", img );
+        img->set( Lifeograph::icons->todo_canceled_32 );
+
+        Lifeograph::builder->get_widget( "I_entry_list_item_todo", img );
+        img->set( Lifeograph::icons->todo_open_16 );
+        Lifeograph::builder->get_widget( "I_entry_list_item_progressed", img );
+        img->set( Lifeograph::icons->todo_progressed_16 );
+        Lifeograph::builder->get_widget( "I_entry_list_item_done", img );
+        img->set( Lifeograph::icons->todo_done_16 );
+        Lifeograph::builder->get_widget( "I_entry_list_item_canceled", img );
+        img->set( Lifeograph::icons->todo_canceled_16 );
+
+        Lifeograph::builder->get_widget( "I_entry_favorite", img );
+        img->set( Lifeograph::icons->favorite_16 );
+
+        Lifeograph::builder->get_widget( "I_header_overlay", img );
+        img->set( Lifeograph::icons->favorite_16 );
+
     }
     catch( ... )
     {
@@ -127,10 +163,18 @@ EntryView::EntryView()
     button_hide_after->signal_clicked().connect(
             sigc::mem_fun( this, &EntryView::hide_after ) );
 
-    m_button_add_bullet->signal_clicked().connect(
-            sigc::mem_fun( m_textview->m_buffer, &TextbufferDiary::add_bullet ) );
-    m_button_add_checkbox->signal_clicked().connect(
-            sigc::mem_fun( m_textview->m_buffer, &TextbufferDiary::add_checkbox ) );
+    m_MI_list_bullet->signal_activate().connect( sigc::bind(
+            sigc::mem_fun( m_textview->m_buffer, &TextbufferDiary::set_list_item_mark ), '*' ) );
+    m_MI_list_none->signal_activate().connect( sigc::bind(
+            sigc::mem_fun( m_textview->m_buffer, &TextbufferDiary::set_list_item_mark ), 0 ) );
+    m_MI_list_todo->signal_activate().connect( sigc::bind(
+            sigc::mem_fun( m_textview->m_buffer, &TextbufferDiary::set_list_item_mark ), ' ' ) );
+    m_MI_list_progressed->signal_activate().connect( sigc::bind(
+            sigc::mem_fun( m_textview->m_buffer, &TextbufferDiary::set_list_item_mark ), '~' ) );
+    m_MI_list_done->signal_activate().connect( sigc::bind(
+            sigc::mem_fun( m_textview->m_buffer, &TextbufferDiary::set_list_item_mark ), '+' ) );
+    m_MI_list_canceled->signal_activate().connect( sigc::bind(
+            sigc::mem_fun( m_textview->m_buffer, &TextbufferDiary::set_list_item_mark ), 'x' ) );
 
     m_textview->signal_drag_data_received().connect(
             sigc::mem_fun( this, &EntryView::handle_drag_data_received ) );
@@ -183,7 +227,7 @@ EntryView::EntryView()
             false, m_action_toggle_comments, "ToggleComments", "", "",
             Gtk::AccelKey( GDK_KEY_c, Gdk::MOD1_MASK ),
             sigc::mem_fun( this, &EntryView::toggle_comments ),
-            m_button_toggle_comments );
+            m_TB_comments );
 
     Lifeograph::create_action(
             true, m_action_indent, "Indent", "", "",
@@ -223,7 +267,7 @@ EntryView::sync()
 {
     if( m_flag_entrychanged )
     {
-        m_entry_sync->set_date_changed( time( NULL ) );
+        m_entry_sync->set_date_edited( time( NULL ) );
         m_entry_sync->set_text( m_textview->m_buffer->get_text() );
         m_flag_entrychanged = false;
         PRINT_DEBUG( "entry synced" );
@@ -269,14 +313,14 @@ EntryView::handle_login()
     m_button_trash->set_visible( editable );
     m_button_restore->set_visible( editable );
     m_button_dismiss->set_visible( editable );
-    m_hbox_editing_toolbar->set_visible( Lifeograph::settings.show_formatting_toolbar &&
+    m_Bx_editing_toolbar->set_visible( Lifeograph::settings.show_formatting_toolbar &&
                                          editable );
 }
 
 void
 EntryView::handle_textview_changed()
 {
-    if( Lifeograph::m_internaloperation ) return;
+    if( Lifeograph::s_internaloperation ) return;
 
     m_flag_entrychanged = true;
 
@@ -336,7 +380,7 @@ EntryView::handle_drag_data_received(
 void
 EntryView::toggle_favoredness()
 {
-    if( Lifeograph::m_internaloperation )
+    if( Lifeograph::s_internaloperation )
         return;
 
     m_ptr2elem->toggle_favored();
@@ -348,14 +392,18 @@ EntryView::toggle_favoredness()
 void
 EntryView::set_todo_status( ElemStatus status )
 {
-    if( Lifeograph::m_internaloperation )
+    if( Lifeograph::s_internaloperation )
         return;
 
     m_ptr2elem->set_todo_status( status );
+    m_ptr2elem->set_date_status( time( NULL ) );
+
     AppWindow::p->panel_main->set_icon( m_ptr2elem->get_icon32() );
     Gtk::TreeRow row = AppWindow::p->get_element_row( m_ptr2elem );
     row[ ListData::colrec->icon ] = m_ptr2elem->get_icon();
     row[ ListData::colrec->info ] = m_ptr2elem->get_list_str();
+
+    update_status_date();
 }
 
 void
@@ -370,7 +418,7 @@ EntryView::print()
     try
     {
         AppWindow::p->freeze_auto_logout();
-        print->set_hide_comments( m_button_toggle_comments->get_active() );
+        print->set_hide_comments( m_TB_comments->get_active() );
         print->run( Gtk::PRINT_OPERATION_ACTION_PRINT_DIALOG, *AppWindow::p );
         AppWindow::p->unfreeze_auto_logout();
     }
@@ -431,12 +479,12 @@ EntryView::trash_entry()
     }
     Diary::d->get_filter()->set_status_outstanding();
 
-    Lifeograph::m_internaloperation++;
+    Lifeograph::s_internaloperation++;
 
     AppWindow::p->panel_diary->update_calendar();
     AppWindow::p->panel_diary->update_entry_list();
 
-    Lifeograph::m_internaloperation--;
+    Lifeograph::s_internaloperation--;
 }
 
 void
@@ -449,12 +497,12 @@ EntryView::restore_entry()
     m_ptr2elem->set_trashed( false );
     Diary::d->get_filter()->set_status_outstanding();
 
-    Lifeograph::m_internaloperation++;
+    Lifeograph::s_internaloperation++;
 
     AppWindow::p->panel_diary->update_calendar();
     AppWindow::p->panel_diary->update_entry_list();
 
-    Lifeograph::m_internaloperation--;
+    Lifeograph::s_internaloperation--;
 }
 
 void
@@ -472,12 +520,12 @@ EntryView::dismiss_entry()
     AppWindow::p->panel_main->remove_element_from_history( m_ptr2elem );
     Diary::d->dismiss_entry( m_ptr2elem );
 
-    Lifeograph::m_internaloperation++;
+    Lifeograph::s_internaloperation++;
 
     AppWindow::p->panel_diary->update_calendar();
     AppWindow::p->panel_diary->update_entry_list();
 
-    Lifeograph::m_internaloperation--;
+    Lifeograph::s_internaloperation--;
 }
 
 void
@@ -643,11 +691,13 @@ EntryView::show( Entry& entry )
     m_ptr2elem = &entry; // must be first thing
 
     m_box_tag_edit->set_visible( false );
+
     AppWindow::p->panel_main->show( this );
+    m_label_created->set_text( m_ptr2elem->get_date_created_str() );
+    m_label_edited->set_text( m_ptr2elem->get_date_edited_str() );
+    update_status_date();
 
-    m_label_info->set_markup( get_extended_info_str() );
-
-    Lifeograph::m_internaloperation++;
+    Lifeograph::s_internaloperation++;
 
     if( ! Diary::d->is_read_only() )
     {
@@ -656,7 +706,7 @@ EntryView::show( Entry& entry )
         m_button_restore->set_visible( entry.is_trashed() );
         m_button_dismiss->set_visible( entry.is_trashed() );
 
-        switch( entry.get_todo_status() )
+        switch( m_ptr2elem->get_todo_status() )
         {
             case ES::NOT_TODO:
                 m_button_not_todo->set_active();
@@ -681,8 +731,10 @@ EntryView::show( Entry& entry )
 
     // BODY
     m_textview->set_richtext( &entry );
+    // unfortunately, word count is only ready after parse which occurs in set_richtext:
+    AppWindow::p->panel_main->refresh_extra_info();
 
-    Lifeograph::m_internaloperation--;
+    Lifeograph::s_internaloperation--;
 
     m_widgettaglist->set_entry( &entry );
     m_tag_widget->populate();
@@ -702,7 +754,7 @@ EntryView::prepare_for_hiding( Entry& entry )
 void
 EntryView::update_formatting_toolbar()
 {
-    m_hbox_editing_toolbar->set_visible( Lifeograph::settings.show_formatting_toolbar &&
+    m_Bx_editing_toolbar->set_visible( Lifeograph::settings.show_formatting_toolbar &&
                                          Diary::d->is_read_only() == false );
 }
 
@@ -720,3 +772,31 @@ EntryView::update_highlight_button()
     m_eventbox_highlight->override_background_color(
             theme->color_highlight, Gtk::STATE_FLAG_ACTIVE );
 }
+
+void
+EntryView::update_status_date()
+{
+    ElemStatus es = m_ptr2elem->get_todo_status();
+
+    m_label_status->set_visible( es != ES::NOT_TODO );
+    m_label_status_changed->set_visible( es != ES::NOT_TODO );
+
+    if( es != ES::NOT_TODO )
+        m_label_status_changed->set_text( m_ptr2elem->get_date_status_str() );
+
+    switch( es )
+    {
+        case ES::TODO:
+            m_label_status->set_text( _( "Opened" ) );
+            break;
+        case ES::PROGRESSED:
+            m_label_status->set_text( _( "Started" ) );
+            break;
+        case ES::DONE:
+            m_label_status->set_text( _( "Completed" ) );
+            break;
+        case ES::CANCELED:
+            m_label_status->set_text( _( "Canceled" ) );
+            break;
+    }
+}
