@@ -571,7 +571,7 @@ ViewLogin::handle_diary_selection_changed()
 {
     m_password_attempt_no = 0;
 
-    if( Lifeograph::m_internaloperation )
+    if( Lifeograph::s_internaloperation )
         return;
 
     bool flag_selection( m_treesel_diaries->count_selected_rows() > 0 );
