@@ -50,11 +50,12 @@ class ViewLogin
                 Gtk::TreeModelColumn< std::string >                     path;
                 Gtk::TreeModelColumn< time_t >                          date_sort;
         };
-        static Colrec               *colrec;
+        static Colrec*              colrec;
 
                                     ViewLogin();
 
         void                        handle_start();
+        void                        handle_login();
         void                        handle_logout();
 
         void                        populate_diaries();
@@ -100,19 +101,24 @@ class ViewLogin
                                                          const Gtk::SelectionData&,
                                                          guint, guint );
 
-        Gtk::TreeView               *m_treeview_diaries;
+        void                        initialize();
+
+        Gtk::TreeView*              m_treeview_diaries;
         Glib::RefPtr< Gtk::ListStore >
                                     m_treestore_diaries;
         Glib::RefPtr< Gtk::TreeSelection >
                                     m_treesel_diaries;
 
-        Gtk::Grid                   *m_grid_login;
-        Gtk::InfoBar                *m_infobar;
-        Gtk::Label                  *m_label_info;
-        Gtk::Button                 *m_button_info;
-        Gtk::Button                 *m_button_edit_diary;
-        Gtk::Button                 *m_button_read_diary;
-        Gtk::Button                 *m_button_remove_diary;
+        Gtk::Popover*               m_popover_add;
+        Gtk::Grid*                  m_grid_login;
+        Gtk::InfoBar*               m_infobar;
+        Gtk::Label*                 m_label_info;
+        Gtk::Button*                m_button_info;
+        Gtk::ButtonBox*             m_buttonbox_open;
+        Gtk::MenuButton*            m_button_add;
+        Gtk::Button*                m_button_edit_diary;
+        Gtk::Button*                m_button_read_diary;
+        Gtk::Button*                m_button_remove_diary;
 
         std::string                 m_path_removed;
         bool                        m_flag_info_is_visible;
