@@ -44,14 +44,14 @@ TagView::TagView()
     {
         Lifeograph::builder->get_widget( "Bx_tag", m_vbox );
         Lifeograph::builder->get_widget( "G_tag_popover", m_grid_popover );
+        Lifeograph::builder->get_widget( "B_tag_toggle_filtering", m_B_filtering );
         Lifeograph::builder->get_widget( "B_tag_dismiss", m_button_dismiss );
-        Lifeograph::builder->get_widget( "frame_tag_edit", m_frame_edit );
-        Lifeograph::builder->get_widget( "TB_tag_filter", m_togglebutton_filter );
-        Lifeograph::builder->get_widget( "combobox_tag_category", m_combobox_category );
-        Lifeograph::builder->get_widget_derived( "drawingarea_tag_chart", m_widgetchart );
-        Lifeograph::builder->get_widget( "textview_tag_theme", m_textview_theme );
-        Lifeograph::builder->get_widget( "menubutton_tag_themes", m_button_themes );
-        Lifeograph::builder->get_widget( "button_tag_theme_reset", m_button_theme_reset );
+        Lifeograph::builder->get_widget( "F_tag_edit", m_frame_edit );
+        Lifeograph::builder->get_widget( "CB_tag_category", m_combobox_category );
+        Lifeograph::builder->get_widget_derived( "DA_tag_chart", m_widgetchart );
+        Lifeograph::builder->get_widget( "TV_tag_theme", m_textview_theme );
+        Lifeograph::builder->get_widget( "MB_tag_themes", m_button_themes );
+        Lifeograph::builder->get_widget( "B_tag_theme_reset", m_button_theme_reset );
 
         m_liststore_categories = Gtk::ListStore::create( colrec_category );
     }
@@ -68,8 +68,6 @@ TagView::TagView()
             sigc::mem_fun( this, &TagView::is_row_separator ) );
 
     // SIGNALS
-    m_togglebutton_filter->signal_toggled().connect(
-            sigc::mem_fun( this, &TagView::handle_filter_toggled ) );
     m_button_dismiss->signal_clicked().connect(
             sigc::mem_fun( this, &TagView::dismiss_tag ) );
 
@@ -79,6 +77,9 @@ TagView::TagView()
     m_button_theme_reset->signal_clicked().connect(
             sigc::mem_fun( this, &TagView::reset_theme ) );
 
+    m_B_filtering->signal_clicked().connect(
+            sigc::mem_fun( this, &TagView::handle_filter_toggled ) );
+
     // THEME TEXT TAGS
     Glib::RefPtr< Gtk::TextBuffer::TagTable > tag_table =
             m_textview_theme->get_buffer()->get_tag_table();
@@ -166,20 +167,20 @@ TagView::handle_login()
 void
 TagView::handle_filter_toggled()
 {
-    if( Lifeograph::m_internaloperation )
+    if( Lifeograph::s_internaloperation )
         return;
 
-    const Tag *tag( m_togglebutton_filter->get_active() ? m_ptr2elem : NULL );
+    const Tag* tag( m_ptr2elem == Diary::d->get_filter_tag() ? NULL : m_ptr2elem );
+
     Diary::d->set_filter_tag( tag );
-    update_button_filter_tag();
     AppWindow::p->panel_extra->set_filtered_tag( tag );
-    AppWindow::p->panel_diary->update_entry_list();
+    AppWindow::p->panel_diary->handle_filter_changed();
 }
 
 void
 TagView::handle_category_changed()
 {
-    if( Lifeograph::m_internaloperation )
+    if( Lifeograph::s_internaloperation )
         return;
 
     Gtk::TreeIter iter = m_combobox_category->get_active();
@@ -246,14 +247,6 @@ TagView::update_combobox_categories()
     row[ colrec_category.type ] = TCT_NEW;
 }
 
-void
-TagView::update_button_filter_tag()
-{
-    Lifeograph::m_internaloperation++;
-    m_togglebutton_filter->set_active( Diary::d->get_filter_tag() == m_ptr2elem );
-    Lifeograph::m_internaloperation--;
-}
-
 void
 TagView::update_theme_view()
 {
@@ -333,7 +326,9 @@ TagView::update_theme_view()
 
     add_tagged_theme_text(
             Glib::ustring::format(
-                    ".\t", _( "Click on the parts to edit" ), "." ), m_tag_region );
+                    ".\t",
+                    _( "Click on the parts to edit. Non-editable parts adapt automatically." ) ),
+            m_tag_region );
 }
 
 void
@@ -400,11 +395,9 @@ TagView::show( Tag& tag )
 
     AppWindow::p->panel_main->show( this );
 
-    Lifeograph::m_internaloperation++;
+    Lifeograph::s_internaloperation++;
 
     // BODY
-    update_button_filter_tag();
-
     for( Gtk::TreeIter iter = m_liststore_categories->children().begin();
          iter != m_liststore_categories->children().end();
          ++iter )
@@ -413,7 +406,7 @@ TagView::show( Tag& tag )
             m_combobox_category->set_active( iter );
     }
 
-    Lifeograph::m_internaloperation--;
+    Lifeograph::s_internaloperation--;
 
     m_frame_edit->set_visible( tag.get_type() == DiaryElement::ET_TAG );
 
@@ -691,6 +684,8 @@ ChapterView::ChapterView()
         Lifeograph::builder->get_widget( "RB_chapter_canceled", m_button_canceled );
         Lifeograph::builder->get_widget( "B_chapter_dismiss", m_button_dismiss );
 
+        Lifeograph::builder->get_widget_derived( "DA_chapter_chart", m_widgetchart );
+
 //		Lifeograph::builder->get_widget( "label_chapter_period", m_label_period );
 //		Lifeograph::builder->get_widget( "hbox_chapter_period", m_hbox_period );
         Lifeograph::builder->get_widget( "entry_chapter_begins", m_entry_begins );
@@ -700,6 +695,17 @@ ChapterView::ChapterView()
         Lifeograph::builder->get_widget( "frame_chapter_edit", m_frame_edit );
         Lifeograph::builder->get_widget( "frame_chapter_actions", m_frame_actions );
         Lifeograph::builder->get_widget( "button_chapter_new_entry", m_button_new_entry );
+
+        // THEMABLE ICONS
+        Gtk::Image* img;
+        Lifeograph::builder->get_widget( "I_chapter_todo", img );
+        img->set( Lifeograph::icons->todo_open_32 );
+        Lifeograph::builder->get_widget( "I_chapter_progressed", img );
+        img->set( Lifeograph::icons->todo_progressed_32 );
+        Lifeograph::builder->get_widget( "I_chapter_done", img );
+        img->set( Lifeograph::icons->todo_done_32 );
+        Lifeograph::builder->get_widget( "I_chapter_canceled", img );
+        img->set( Lifeograph::icons->todo_canceled_32 );
     }
     catch( ... )
     {
@@ -802,7 +808,7 @@ ChapterView::update_labels()
 {
     if( ! m_ptr2elem->m_date_begin.is_ordinal() )
     {
-        Lifeograph::m_internaloperation++;
+        Lifeograph::s_internaloperation++;
 
         m_entry_begins->set_text( m_ptr2elem->m_date_begin.format_string() );
 
@@ -816,7 +822,7 @@ ChapterView::update_labels()
             m_label_ends->set_text( iter->second->m_date_begin.format_string() );
         }
 
-        Lifeograph::m_internaloperation--;
+        Lifeograph::s_internaloperation--;
     }
 }
 
@@ -878,6 +884,20 @@ ChapterView::show( Chapter& chapter )
             m_button_canceled->set_active();
             break;
     }
+
+    // CHART DATA
+    ChartPoints* points( new ChartPoints );
+    for( Chapter::iterator iter = chapter.begin(); iter != chapter.end(); ++iter )
+    {
+        Entry* entry( *iter );
+        Date date( entry->get_date() );
+        if( date.is_ordinal() )
+            date.m_date = Date::make_date_from_ctime( entry->get_date_created() );
+        points->increase( date.get_yearmonth() );
+
+    }
+    points->finish();
+    m_widgetchart->set_points( points );
 }
 
 Gtk::Widget*
@@ -889,7 +909,7 @@ ChapterView::get_popover()
 void
 ChapterView::set_todo_status( ElemStatus status )
 {
-    if( Lifeograph::m_internaloperation )
+    if( Lifeograph::s_internaloperation )
         return;
 
     m_ptr2elem->set_todo_status( status );
@@ -909,93 +929,110 @@ FilterView::FilterView()
     try
     {
         Lifeograph::builder->get_widget( "Bx_filter", m_vbox );
-        Lifeograph::builder->get_widget( "TB_filter_not_todo", m_tglbtn_todo_not );
-        Lifeograph::builder->get_widget( "TB_filter_todo", m_tglbtn_todo_open );
-        Lifeograph::builder->get_widget( "TB_filter_progressed", m_tglbtn_todo_progressed );
-        Lifeograph::builder->get_widget( "TB_filter_done", m_tglbtn_todo_done );
-        Lifeograph::builder->get_widget( "TB_filter_canceled", m_tglbtn_todo_canceled );
-        Lifeograph::builder->get_widget( "TB_filter_not_favored", m_tglbtn_not_favored );
-        Lifeograph::builder->get_widget( "TB_filter_favored", m_tglbtn_favored );
-        Lifeograph::builder->get_widget( "TB_filter_not_trashed", m_tglbtn_not_trashed );
-        Lifeograph::builder->get_widget( "TB_filter_trashed", m_tglbtn_trashed );
+        Lifeograph::builder->get_widget( "TB_filter_not_todo", m_TB_todo_not );
+        Lifeograph::builder->get_widget( "TB_filter_todo", m_TB_todo_open );
+        Lifeograph::builder->get_widget( "TB_filter_progressed", m_TB_todo_progressed );
+        Lifeograph::builder->get_widget( "TB_filter_done", m_TB_todo_done );
+        Lifeograph::builder->get_widget( "TB_filter_canceled", m_TB_todo_canceled );
+        Lifeograph::builder->get_widget( "TB_filter_not_favored", m_TB_not_favored );
+        Lifeograph::builder->get_widget( "TB_filter_favored", m_TB_favored );
+        Lifeograph::builder->get_widget( "TB_filter_not_trashed", m_TB_not_trashed );
+        Lifeograph::builder->get_widget( "TB_filter_trashed", m_TB_trashed );
 
-        Lifeograph::builder->get_widget( "L_filter_tag", m_label_tag );
-        Lifeograph::builder->get_widget( "B_filter_clear_tag", m_button_clear_tag );
+        Lifeograph::builder->get_widget( "L_filter_tag", m_L_tag );
+        Lifeograph::builder->get_widget( "B_filter_clear_tag", m_B_clear_tag );
 
-        Lifeograph::builder->get_widget_derived( "E_filter_date_start", m_entry_date_begin );
-        Lifeograph::builder->get_widget_derived( "E_filter_date_end", m_entry_date_end );
+        Lifeograph::builder->get_widget_derived( "E_filter_date_start", m_E_date_begin );
+        Lifeograph::builder->get_widget_derived( "E_filter_date_end", m_E_date_end );
 
-        Lifeograph::builder->get_widget( "TV_filter_entries", m_treeview_entries );
-        Lifeograph::builder->get_widget( "B_filter_remove_entry", m_button_remove_entry );
-        Lifeograph::builder->get_widget( "B_filter_rm_all_entries", m_button_rm_all_entries );
+        Lifeograph::builder->get_widget( "TV_filter_entries", m_TV_entries );
+        Lifeograph::builder->get_widget( "B_filter_remove_entry", m_B_remove_entry );
+        Lifeograph::builder->get_widget( "B_filter_rm_all_entries", m_B_rm_all_entries );
 
         Lifeograph::builder->get_widget( "G_filter_popover", m_grid_popover );
-        Lifeograph::builder->get_widget( "B_filter_revert", m_button_revert_to_default );
-        Lifeograph::builder->get_widget( "B_filter_make_default", m_button_make_default );
+        Lifeograph::builder->get_widget( "B_filter_make_default", m_B_make_default );
+        Lifeograph::builder->get_widget( "B_filter_revert", m_B_revert );
 
-        m_liststore_entries = Gtk::ListStore::create( *colrec_entries );
+        m_LS_entries = Gtk::ListStore::create( *colrec_entries );
+
+        // THEMABLE ICONS
+        Gtk::Image* img;
+        Lifeograph::builder->get_widget( "I_filter_not_todo", img );
+        img->set( Lifeograph::icons->entry_16 );
+        Lifeograph::builder->get_widget( "I_filter_todo", img );
+        img->set( Lifeograph::icons->todo_open_16 );
+        Lifeograph::builder->get_widget( "I_filter_progressed", img );
+        img->set( Lifeograph::icons->todo_progressed_16 );
+        Lifeograph::builder->get_widget( "I_filter_done", img );
+        img->set( Lifeograph::icons->todo_done_16 );
+        Lifeograph::builder->get_widget( "I_filter_canceled", img );
+        img->set( Lifeograph::icons->todo_canceled_16 );
     }
     catch( ... )
     {
         throw LIFEO::Error( "Failed to create the filter view" );
     }
 
-    m_button_revert_to_default->signal_clicked().connect(
-            sigc::mem_fun( this, &FilterView::revert_to_default ) );
-    m_button_make_default->signal_clicked().connect(
+    m_B_make_default->signal_clicked().connect(
             sigc::mem_fun( this, &FilterView::make_default ) );
 
-    m_tglbtn_todo_not->signal_toggled().connect(
+    // revert filter clicks are also handled here in addition to PanelDiary, the main handler
+    m_B_revert->signal_clicked().connect(
+                sigc::mem_fun( this, &FilterView::update ) );
+
+    m_TB_todo_not->signal_toggled().connect(
             sigc::mem_fun( this, &FilterView::handle_todo_changed ) );
-    m_tglbtn_todo_open->signal_toggled().connect(
+    m_TB_todo_open->signal_toggled().connect(
             sigc::mem_fun( this, &FilterView::handle_todo_changed ) );
-    m_tglbtn_todo_progressed->signal_toggled().connect(
+    m_TB_todo_progressed->signal_toggled().connect(
             sigc::mem_fun( this, &FilterView::handle_todo_changed ) );
-    m_tglbtn_todo_done->signal_toggled().connect(
+    m_TB_todo_done->signal_toggled().connect(
             sigc::mem_fun( this, &FilterView::handle_todo_changed ) );
-    m_tglbtn_todo_canceled->signal_toggled().connect(
+    m_TB_todo_canceled->signal_toggled().connect(
             sigc::mem_fun( this, &FilterView::handle_todo_changed ) );
 
-    m_tglbtn_trashed->signal_toggled().connect(
+    m_TB_trashed->signal_toggled().connect(
             sigc::mem_fun( this, &FilterView::handle_trash_changed ) );
-    m_tglbtn_not_trashed->signal_toggled().connect(
+    m_TB_not_trashed->signal_toggled().connect(
             sigc::mem_fun( this, &FilterView::handle_trash_changed ) );
 
-    m_tglbtn_favored->signal_toggled().connect(
+    m_TB_favored->signal_toggled().connect(
             sigc::mem_fun( this, &FilterView::handle_favored_changed ) );
-    m_tglbtn_not_favored->signal_toggled().connect(
+    m_TB_not_favored->signal_toggled().connect(
             sigc::mem_fun( this, &FilterView::handle_favored_changed ) );
 
-    m_label_tag->drag_dest_set( Lifeograph::p->drag_targets_tag );
-    m_label_tag->signal_drag_drop().connect(
+    m_L_tag->drag_dest_set( Lifeograph::p->drag_targets_tag );
+    m_L_tag->signal_drag_drop().connect(
             sigc::mem_fun( this, &FilterView::handle_tag_dropped ) );
-    m_button_clear_tag->signal_clicked().connect(
+    m_B_clear_tag->signal_clicked().connect(
             sigc::mem_fun( this, &FilterView::clear_tag ) );
 
-    m_entry_date_begin->signal_changed().connect(
+    m_E_date_begin->signal_changed().connect(
             sigc::mem_fun( this, &FilterView::handle_date_begin_changed ) );
-    m_entry_date_end->signal_changed().connect(
+    m_E_date_end->signal_changed().connect(
             sigc::mem_fun( this, &FilterView::handle_date_end_changed ) );
 
-    m_treeview_entries->set_model( m_liststore_entries );
-    m_treeview_entries->append_column(
+    m_TV_entries->set_model( m_LS_entries );
+    m_TV_entries->append_column(
             * Gtk::manage( new Gtk::TreeView::Column( "", colrec_entries->name ) ) );
-    m_treeview_entries->drag_dest_set( Lifeograph::p->drag_targets_entry );
-    m_treeview_entries->signal_drag_drop().connect(
+    m_TV_entries->drag_dest_set( Lifeograph::p->drag_targets_entry );
+    m_TV_entries->signal_drag_drop().connect(
             sigc::mem_fun( this, &FilterView::handle_entry_dropped ) );
-    m_treeview_entries->get_selection()->signal_changed().connect(
+    m_TV_entries->get_selection()->signal_changed().connect(
             sigc::mem_fun( this, &FilterView::handle_entry_selection_changed ) );
 
-    m_button_remove_entry->signal_clicked().connect(
+    m_B_remove_entry->signal_clicked().connect(
             sigc::mem_fun( this, &FilterView::remove_selected_entries ) );
-    m_button_rm_all_entries->signal_clicked().connect(
+    m_B_rm_all_entries->signal_clicked().connect(
             sigc::mem_fun( this, &FilterView::remove_all_entries ) );
 }
 
 void
 FilterView::handle_login()
 {
-    m_button_make_default->set_visible( ! Diary::d->is_read_only() );
+    m_B_make_default->set_visible( ! Diary::d->is_read_only() );
+    m_ptr2elem = Diary::d->get_filter();
+    // the above line prevents segfaults when filter is reverted before being shown
 }
 
 void
@@ -1028,42 +1065,42 @@ FilterView::update()
 {
     ElemStatus fs( m_ptr2elem->get_status() );
 
-    Lifeograph::m_internaloperation++;
+    Lifeograph::s_internaloperation++;
 
     // STATUS
-    m_tglbtn_favored->set_active( fs & ES::SHOW_FAVORED );
-    m_tglbtn_not_favored->set_active( fs & ES::SHOW_NOT_FAVORED );
-    m_tglbtn_trashed->set_active( fs & ES::SHOW_TRASHED );
-    m_tglbtn_not_trashed->set_active( fs & ES::SHOW_NOT_TRASHED );
-    m_tglbtn_todo_not->set_active( fs & ES::SHOW_NOT_TODO );
-    m_tglbtn_todo_open->set_active( fs & ES::SHOW_TODO );
-    m_tglbtn_todo_progressed->set_active( fs & ES::SHOW_PROGRESSED );
-    m_tglbtn_todo_done->set_active( fs & ES::SHOW_DONE );
-    m_tglbtn_todo_canceled->set_active( fs & ES::SHOW_CANCELED );
+    m_TB_favored->set_active( fs & ES::SHOW_FAVORED );
+    m_TB_not_favored->set_active( fs & ES::SHOW_NOT_FAVORED );
+    m_TB_trashed->set_active( fs & ES::SHOW_TRASHED );
+    m_TB_not_trashed->set_active( fs & ES::SHOW_NOT_TRASHED );
+    m_TB_todo_not->set_active( fs & ES::SHOW_NOT_TODO );
+    m_TB_todo_open->set_active( fs & ES::SHOW_TODO );
+    m_TB_todo_progressed->set_active( fs & ES::SHOW_PROGRESSED );
+    m_TB_todo_done->set_active( fs & ES::SHOW_DONE );
+    m_TB_todo_canceled->set_active( fs & ES::SHOW_CANCELED );
 
     // TAG
     if( m_ptr2elem->get_tag() )
-        m_label_tag->set_text( m_ptr2elem->get_tag()->get_name() );
+        m_L_tag->set_text( m_ptr2elem->get_tag()->get_name() );
     else
-        m_label_tag->set_text( _( STRING::DROP_TAG_TO_FILTER ) );
+        m_L_tag->set_text( _( STRING::DROP_TAG_TO_FILTER ) );
 
-    m_button_clear_tag->set_visible( m_ptr2elem->get_tag() );
+    m_B_clear_tag->set_visible( m_ptr2elem->get_tag() );
 
     // DATE INTERVAL
     if( m_ptr2elem->get_date_begin() > 0 )
-        m_entry_date_begin->set_text( Date::format_string( m_ptr2elem->get_date_begin() ) );
+        m_E_date_begin->set_text( Date::format_string( m_ptr2elem->get_date_begin() ) );
     else
-        m_entry_date_begin->set_text( "" );
+        m_E_date_begin->set_text( "" );
 
     if( m_ptr2elem->get_date_end() != Date::DATE_MAX )
-        m_entry_date_end->set_text( Date::format_string( m_ptr2elem->get_date_end() ) );
+        m_E_date_end->set_text( Date::format_string( m_ptr2elem->get_date_end() ) );
     else
-        m_entry_date_end->set_text( "" );
+        m_E_date_end->set_text( "" );
 
     // INDIVIDUAL ENTRIES
     update_entries();
 
-    Lifeograph::m_internaloperation--;
+    Lifeograph::s_internaloperation--;
 }
 
 Glib::ustring
@@ -1072,34 +1109,23 @@ FilterView::get_info_str() const
     return _( "Determines the entries to be shown in the list" );
 }
 
-void
-FilterView::revert_to_default()
-{
-    AppWindow::p->panel_main->hide_popover();
-
-    m_ptr2elem->set( Diary::d->get_filter_default() );
-    m_ptr2elem->set_status_outstanding();
-    update();
-    AppWindow::p->panel_diary->update_calendar();
-    AppWindow::p->panel_diary->update_entry_list();
-}
-
 void
 FilterView::make_default()
 {
     AppWindow::p->panel_main->hide_popover();
 
     Diary::d->get_filter_default()->set( m_ptr2elem );
+    m_B_revert->set_visible( false );
 }
 
 void
 FilterView::handle_trash_changed()
 {
-    if( Lifeograph::m_internaloperation )
+    if( Lifeograph::s_internaloperation )
         return;
 
-    bool trashed( m_tglbtn_trashed->get_active() );
-    bool not_trashed( m_tglbtn_not_trashed->get_active() );
+    bool trashed( m_TB_trashed->get_active() );
+    bool not_trashed( m_TB_not_trashed->get_active() );
 
     if( !( trashed || not_trashed ) )
     {
@@ -1108,24 +1134,24 @@ FilterView::handle_trash_changed()
         if( m_ptr2elem->get_status() & ES::SHOW_NOT_TRASHED )
             trashed = true;
 
-        Lifeograph::m_internaloperation++;
-        m_tglbtn_not_trashed->set_active( not_trashed );
-        m_tglbtn_trashed->set_active( trashed );
-        Lifeograph::m_internaloperation--;
+        Lifeograph::s_internaloperation++;
+        m_TB_not_trashed->set_active( not_trashed );
+        m_TB_trashed->set_active( trashed );
+        Lifeograph::s_internaloperation--;
     }
 
     m_ptr2elem->set_trash( trashed, not_trashed );
-    AppWindow::p->panel_diary->update_entry_list();
+    AppWindow::p->panel_diary->handle_filter_changed();
 }
 
 void
 FilterView::handle_favored_changed()
 {
-    if( Lifeograph::m_internaloperation )
+    if( Lifeograph::s_internaloperation )
         return;
 
-    bool favored( m_tglbtn_favored->get_active() );
-    bool not_favored( m_tglbtn_not_favored->get_active() );
+    bool favored( m_TB_favored->get_active() );
+    bool not_favored( m_TB_not_favored->get_active() );
 
     if( !( favored || not_favored ) )
     {
@@ -1134,39 +1160,39 @@ FilterView::handle_favored_changed()
         if( m_ptr2elem->get_status() & ES::SHOW_NOT_FAVORED )
             favored = true;
 
-        Lifeograph::m_internaloperation++;
-        m_tglbtn_favored->set_active( favored );
-        m_tglbtn_not_favored->set_active( not_favored );
-        Lifeograph::m_internaloperation--;
+        Lifeograph::s_internaloperation++;
+        m_TB_favored->set_active( favored );
+        m_TB_not_favored->set_active( not_favored );
+        Lifeograph::s_internaloperation--;
     }
 
     m_ptr2elem->set_favorites( favored, not_favored );
-    AppWindow::p->panel_diary->update_entry_list();
+    AppWindow::p->panel_diary->handle_filter_changed();
 }
 
 void
 FilterView::handle_todo_changed()
 {
-    if( Lifeograph::m_internaloperation )
+    if( Lifeograph::s_internaloperation )
         return;
 
-    m_ptr2elem->set_todo( m_tglbtn_todo_not->get_active(),
-                          m_tglbtn_todo_open->get_active(),
-                          m_tglbtn_todo_progressed->get_active(),
-                          m_tglbtn_todo_done->get_active(),
-                          m_tglbtn_todo_canceled->get_active() );
+    m_ptr2elem->set_todo( m_TB_todo_not->get_active(),
+                          m_TB_todo_open->get_active(),
+                          m_TB_todo_progressed->get_active(),
+                          m_TB_todo_done->get_active(),
+                          m_TB_todo_canceled->get_active() );
 
-    AppWindow::p->panel_diary->update_entry_list();
+    AppWindow::p->panel_diary->handle_filter_changed();
 }
 
 void
 FilterView::clear_tag()
 {
-    m_label_tag->set_text( _( STRING::DROP_TAG_TO_FILTER ) );
-    m_button_clear_tag->hide();
+    m_L_tag->set_text( _( STRING::DROP_TAG_TO_FILTER ) );
+    m_B_clear_tag->hide();
     m_ptr2elem->set_tag( NULL );
     AppWindow::p->panel_extra->set_filtered_tag( NULL );
-    AppWindow::p->panel_diary->update_entry_list();
+    AppWindow::p->panel_diary->handle_filter_changed();
 }
 
 bool
@@ -1183,11 +1209,11 @@ FilterView::handle_tag_dropped( const Glib::RefPtr< Gdk::DragContext >& context,
             case DiaryElement::ET_UNTAGGED:
             {
                 const Tag *tag( dynamic_cast< Tag* >( Lifeograph::s_elem_dragged ) );
-                m_label_tag->set_text( Lifeograph::s_elem_dragged->get_name() );
-                m_button_clear_tag->show();
+                m_L_tag->set_text( Lifeograph::s_elem_dragged->get_name() );
+                m_B_clear_tag->show();
                 m_ptr2elem->set_tag( tag );
                 AppWindow::p->panel_extra->set_filtered_tag( tag );
-                AppWindow::p->panel_diary->update_entry_list();
+                AppWindow::p->panel_diary->handle_filter_changed();
             }
                 break;
             default:
@@ -1204,88 +1230,85 @@ FilterView::handle_tag_dropped( const Glib::RefPtr< Gdk::DragContext >& context,
 void
 FilterView::handle_date_begin_changed()
 {
-    if( Lifeograph::m_internaloperation )
+    if( Lifeograph::s_internaloperation )
         return;
 
-    m_entry_date_begin->unset_color();
+    m_E_date_begin->unset_color();
 
-    if( m_entry_date_begin->get_text_length() == 0 )
+    if( m_E_date_begin->get_text_length() == 0 )
     {
         Diary::d->set_filter_date_begin( 0 );
     }
     else
     {
-        Date date( m_entry_date_begin->get_text() );
+        Date date( m_E_date_begin->get_text() );
 
         if( date.is_set() )
             Diary::d->set_filter_date_begin( date.m_date );
         else
-            m_entry_date_begin->override_color( Gdk::RGBA( "Red" ) );
+            m_E_date_begin->override_color( Gdk::RGBA( "Red" ) );
     }
 
-    AppWindow::p->panel_diary->update_calendar();
-    AppWindow::p->panel_diary->update_entry_list();
+    AppWindow::p->panel_diary->handle_filter_changed();
 }
 
 void
 FilterView::handle_date_end_changed()
 {
-    if( Lifeograph::m_internaloperation )
+    if( Lifeograph::s_internaloperation )
         return;
 
-    m_entry_date_end->unset_color();
+    m_E_date_end->unset_color();
 
-    if( m_entry_date_end->get_text_length() == 0 )
+    if( m_E_date_end->get_text_length() == 0 )
     {
         Diary::d->set_filter_date_end( Date::DATE_MAX );
     }
     else
     {
-        Date date( m_entry_date_end->get_text() );
+        Date date( m_E_date_end->get_text() );
 
         if( date.is_set() )
             Diary::d->set_filter_date_end( date.m_date );
         else
-            m_entry_date_end->override_color( Gdk::RGBA( "Red" ) );
+            m_E_date_end->override_color( Gdk::RGBA( "Red" ) );
     }
 
-    AppWindow::p->panel_diary->update_calendar();
-    AppWindow::p->panel_diary->update_entry_list();
+    AppWindow::p->panel_diary->handle_filter_changed();
 }
 
 void
 FilterView::update_entries()
 {
-    m_liststore_entries->clear();
+    m_LS_entries->clear();
     const EntrySet* es( m_ptr2elem->get_entries() );
     for( EntrySetIter iter = es->begin(); iter != es->end(); ++iter )
     {
-        Gtk::TreeModel::Row row( *( m_liststore_entries->append() ) );
+        Gtk::TreeModel::Row row( *( m_LS_entries->append() ) );
         row[ colrec_entries->name ] = ( *iter )->get_name();
         row[ colrec_entries->ptr ] = *iter;
     }
 
-    m_button_rm_all_entries->set_sensitive( ! m_liststore_entries->children().empty( ) );
+    m_B_rm_all_entries->set_sensitive( ! m_LS_entries->children().empty( ) );
 }
 
 void
 FilterView::remove_selected_entries()
 {
     std::vector< Gtk::TreePath > paths(
-            m_treeview_entries->get_selection()->get_selected_rows() );
+            m_TV_entries->get_selection()->get_selected_rows() );
 
     for( std::vector< Gtk::TreePath >::iterator iter = paths.begin();
          iter != paths.end();
          ++iter )
     {
-        Gtk::TreeModel::Row row( * m_liststore_entries->get_iter( *iter ) );
+        Gtk::TreeModel::Row row( * m_LS_entries->get_iter( *iter ) );
         Entry* entry( row[ colrec_entries->ptr ] );
         m_ptr2elem->remove_entry( entry );
     }
 
     update_entries();
-    AppWindow::p->panel_diary->update_calendar();
-    AppWindow::p->panel_diary->update_entry_list();
+    AppWindow::p->panel_diary->handle_filter_changed();
 }
 
 void
@@ -1293,8 +1316,7 @@ FilterView::remove_all_entries()
 {
     m_ptr2elem->clear_entries();
     update_entries();
-    AppWindow::p->panel_diary->update_calendar();
-    AppWindow::p->panel_diary->update_entry_list();
+    AppWindow::p->panel_diary->handle_filter_changed();
 }
 
 bool
@@ -1312,8 +1334,7 @@ FilterView::handle_entry_dropped( const Glib::RefPtr< Gdk::DragContext >& contex
                 Entry* entry( dynamic_cast< Entry* >( Lifeograph::s_elem_dragged ) );
                 m_ptr2elem->add_entry( entry );
                 update_entries();
-                AppWindow::p->panel_diary->update_calendar();
-                AppWindow::p->panel_diary->update_entry_list();
+                AppWindow::p->panel_diary->handle_filter_changed();
                 break;
             }
             case DiaryElement::ET_MULTIPLE_ENTRIES:
@@ -1321,8 +1342,7 @@ FilterView::handle_entry_dropped( const Glib::RefPtr< Gdk::DragContext >& contex
                 sigc::slot< void, Entry* > s = sigc::mem_fun( *m_ptr2elem, &Filter::add_entry );
                 AppWindow::p->panel_diary->do_for_each_selected_entry( s );
                 update_entries();
-                AppWindow::p->panel_diary->update_calendar();
-                AppWindow::p->panel_diary->update_entry_list();
+                AppWindow::p->panel_diary->handle_filter_changed();
                 break;
             }
             default:
@@ -1339,8 +1359,8 @@ FilterView::handle_entry_dropped( const Glib::RefPtr< Gdk::DragContext >& contex
 void
 FilterView::handle_entry_selection_changed()
 {
-    m_button_remove_entry->set_sensitive(
-            m_treeview_entries->get_selection()->count_selected_rows() > 0 );
+    m_B_remove_entry->set_sensitive(
+            m_TV_entries->get_selection()->count_selected_rows() > 0 );
 }
 
 // DIARY ===========================================================================================
@@ -1443,7 +1463,7 @@ DiaryView::~DiaryView()
 void
 DiaryView::handle_login()
 {
-    Lifeograph::m_internaloperation++;
+    Lifeograph::s_internaloperation++;
 
     // SPELL CHECKING
     m_combobox_spellcheck->remove_all();
@@ -1471,7 +1491,7 @@ DiaryView::handle_login()
     else
         m_combobox_startup_type->set_active( 2 );
 
-    Lifeograph::m_internaloperation--;
+    Lifeograph::s_internaloperation--;
 
     bool editable( ! Diary::d->is_read_only() );
     m_combobox_startup_type->set_sensitive( editable );
@@ -1577,7 +1597,7 @@ DiaryView::start_dialog_export()
 void
 DiaryView::handle_language_changed()
 {
-    if( Lifeograph::m_internaloperation )
+    if( Lifeograph::s_internaloperation )
         return;
     std::string lang( m_combobox_spellcheck->get_active_text() );
     Diary::d->set_lang( lang == _( STRING::OFF ) ? "" : lang );
@@ -1586,7 +1606,7 @@ DiaryView::handle_language_changed()
 void
 DiaryView::handle_startup_type_changed()
 {
-    if( ! Lifeograph::m_internaloperation )
+    if( ! Lifeograph::s_internaloperation )
     {
         Gtk::TreeRow row( * m_combobox_startup_type->get_active() );
         Diary::d->m_startup_elem_id = row[ colrec_startup_type.type ];
@@ -1720,7 +1740,7 @@ DiaryView::update_combobox_chapter_ctg()
 void
 DiaryView::handle_cur_chapter_ctg_changed()
 {
-    if( Lifeograph::m_internaloperation ) return;
+    if( Lifeograph::s_internaloperation ) return;
 
     Gtk::TreeIter iter = m_combobox_chapter_ctg->get_active();
     bool flag_renamed = ! ( iter ), flag_existing_ctg( false );
