@@ -55,14 +55,11 @@ class TagView : public ElementShower< Tag >
         }
 
         Gtk::Widget*            get_popover();
-        Gtk::Widget*            get_extra_tools()
-        { return m_togglebutton_filter; }
 
         void                    handle_login();
         void                    show( Tag& tag );
 
         void                    update_combobox_categories();
-        void                    update_button_filter_tag();
 
         enum TagComboType { TCT_NONE, TCT_CATEGORY, TCT_NEW, TCT_SEPARATOR };
 
@@ -97,7 +94,6 @@ class TagView : public ElementShower< Tag >
         void                    dismiss_tag();
 
         Gtk::Frame*             m_frame_edit;
-        Gtk::ToggleButton*      m_togglebutton_filter;
         Gtk::Button*            m_button_dismiss;
         Gtk::ComboBox*          m_combobox_category;
         WidgetChart*            m_widgetchart;
@@ -105,6 +101,7 @@ class TagView : public ElementShower< Tag >
         Gtk::Menu*              m_menu_themes;
         Gtk::MenuButton*        m_button_themes;
         Gtk::Button*            m_button_theme_reset;
+        Gtk::Button*            m_B_filtering;
 
         class ColrecCategory : public Gtk::TreeModel::ColumnRecord
         {
@@ -232,6 +229,7 @@ class ChapterView : public ElementShower< Chapter >
 
         Gtk::Frame*             m_frame_edit;
         Gtk::Frame*             m_frame_actions;
+        WidgetChart*            m_widgetchart;
 };
 
 // FILTER VIEW =====================================================================================
@@ -259,7 +257,6 @@ class FilterView : public ElementShower< Filter >
         bool                    apply_title( const Glib::ustring& )
         { return false; }
 
-        void                    revert_to_default();
         void                    make_default();
 
         void                    handle_trash_changed();
@@ -282,29 +279,29 @@ class FilterView : public ElementShower< Filter >
                                         int, int, guint );
         void                    handle_entry_selection_changed();
 
-        Gtk::ToggleButton*      m_tglbtn_todo_not;
-        Gtk::ToggleButton*      m_tglbtn_todo_open;
-        Gtk::ToggleButton*      m_tglbtn_todo_progressed;
-        Gtk::ToggleButton*      m_tglbtn_todo_done;
-        Gtk::ToggleButton*      m_tglbtn_todo_canceled;
-        Gtk::ToggleButton*      m_tglbtn_not_favored;
-        Gtk::ToggleButton*      m_tglbtn_favored;
-        Gtk::ToggleButton*      m_tglbtn_not_trashed;
-        Gtk::ToggleButton*      m_tglbtn_trashed;
+        Gtk::ToggleButton*      m_TB_todo_not;
+        Gtk::ToggleButton*      m_TB_todo_open;
+        Gtk::ToggleButton*      m_TB_todo_progressed;
+        Gtk::ToggleButton*      m_TB_todo_done;
+        Gtk::ToggleButton*      m_TB_todo_canceled;
+        Gtk::ToggleButton*      m_TB_not_favored;
+        Gtk::ToggleButton*      m_TB_favored;
+        Gtk::ToggleButton*      m_TB_not_trashed;
+        Gtk::ToggleButton*      m_TB_trashed;
 
-        Gtk::Label*             m_label_tag;
-        Gtk::Button*            m_button_clear_tag;
+        Gtk::Label*             m_L_tag;
+        Gtk::Button*            m_B_clear_tag;
 
-        EntryClear*             m_entry_date_begin;
-        EntryClear*             m_entry_date_end;
+        EntryClear*             m_E_date_begin;
+        EntryClear*             m_E_date_end;
 
-        Gtk::TreeView*          m_treeview_entries;
-        Glib::RefPtr< Gtk::ListStore >      m_liststore_entries;
-        Gtk::Button*            m_button_remove_entry;
-        Gtk::Button*            m_button_rm_all_entries;
+        Gtk::TreeView*          m_TV_entries;
+        Glib::RefPtr< Gtk::ListStore >      m_LS_entries;
+        Gtk::Button*            m_B_remove_entry;
+        Gtk::Button*            m_B_rm_all_entries;
 
-        Gtk::Button*            m_button_make_default;
-        Gtk::Button*            m_button_revert_to_default;
+        Gtk::Button*            m_B_make_default;
+        Gtk::Button*            m_B_revert;
 
         class ColrecEntries : public Gtk::TreeModel::ColumnRecord
         {
