@@ -61,17 +61,17 @@ class WidgetChart : public Gtk::DrawingArea
 {
     public:
         // CONSTANTS
-        static const float          border_curve = 30.0;
-        static const float          border_label = 10.0;
-        static const float          offset_label = 5.0;
-        static const float          label_height = 12.0;
-        static const float          bar_height = 25.0;
-        static const float          OVERVIEW_COEFFICIENT = 20;
-        static const float          COLUMN_WIDTH_MIN = 45.0;
+        static const float          border_curve;
+        static const float          border_label;
+        static const float          offset_label;
+        static const float          label_height;
+        static const float          bar_height;
+        static const float          OVERVIEW_COEFFICIENT;
+        static const float          COLUMN_WIDTH_MIN;
         // CALCULATED CONSTANTS
-        static const float          label_y = 5.0 + 12.0;   // = offset_label + label_height;
-        static const float          s_x_min = 30.0 + 10.0; // = border_curve + border_label
-        static const float          s_y_min = 30.0;   // = border_curve;
+        static const float          label_y;
+        static const float          s_x_min;
+        static const float          s_y_min;
 
                                     WidgetChart( BaseObjectType*,
                                                  const Glib::RefPtr< Gtk::Builder >& );
