@@ -83,7 +83,7 @@ WidgetEntryList::cell_data_func_icon( Gtk::CellRenderer* cell, const Gtk::TreeMo
         bool favored( elem->is_favored() );
         cell->set_property( "visible", favored );
         if( favored )
-            cell->set_property( "pixbuf", Lifeograph::icons->entry_favorite_16 );
+            cell->set_property( "pixbuf", Lifeograph::icons->favorite_16 );
     }
 }
 
@@ -219,7 +219,7 @@ WidgetEntryList::handle_sorting_criteria_changed( SortingCriteria sc )
             m_treestore->set_default_sort_func(
                     sigc::mem_fun( this, &WidgetEntryList::sort_by_date ) );
             break;
-        case SC_SIZE:
+        case SC_SIZE_C:
             m_treestore->set_default_sort_func(
                     sigc::mem_fun( this, &WidgetEntryList::sort_by_size ) );
             break;
@@ -242,7 +242,7 @@ WidgetEntryList::reset_sorting_criteria()
             m_treestore->set_default_sort_func(
                     sigc::mem_fun( this, &WidgetEntryList::sort_by_date ) );
             break;
-        case SC_SIZE:
+        case SC_SIZE_C:
             m_treestore->set_default_sort_func(
                     sigc::mem_fun( this, &WidgetEntryList::sort_by_size ) );
             break;
@@ -533,7 +533,7 @@ WidgetEntryList::on_drag_drop( const Glib::RefPtr< Gdk::DragContext >& context,
                         case DiaryElement::ET_TOPIC:
                         case DiaryElement::ET_GROUP:
                         {
-                            Chapter *chapter( dynamic_cast< Chapter* >( m_elem_drop_target ) );
+                            Chapter* chapter( dynamic_cast< Chapter* >( m_elem_drop_target ) );
                             Diary::d->set_entry_date( entry, chapter->get_free_order() );
                             AppWindow::p->panel_main->refresh_title();
                             AppWindow::p->panel_diary->update_entry_list();
@@ -556,7 +556,7 @@ WidgetEntryList::on_drag_drop( const Glib::RefPtr< Gdk::DragContext >& context,
                         m_elem_drop_target->get_type() == DiaryElement::ET_TOPIC ||
                         m_elem_drop_target->get_type() == DiaryElement::ET_GROUP )
                     {
-                        Chapter *chapter( dynamic_cast< Chapter* >( m_elem_drop_target ) );
+                        Chapter* chapter( dynamic_cast< Chapter* >( m_elem_drop_target ) );
                         sigc::slot< void, Entry* > s = sigc::bind(
                                  sigc::mem_fun( this, &WidgetEntryList::move_entry_to_chapter ),
                                  chapter );
@@ -617,7 +617,7 @@ WidgetEntryList::on_drag_drop( const Glib::RefPtr< Gdk::DragContext >& context,
 void
 WidgetEntryList::handle_selection_changed()
 {
-    if( Lifeograph::m_internaloperation || Lifeograph::s_flag_dragging )
+    if( Lifeograph::s_internaloperation || Lifeograph::s_flag_dragging )
         return;
 
     m_multiple_entries.m_entries.clear();
@@ -637,9 +637,9 @@ WidgetEntryList::handle_selection_changed()
         {
             if( num_sel > 1 )
             {
-                Lifeograph::m_internaloperation++;
+                Lifeograph::s_internaloperation++;
                 sel->unselect( path );
-                Lifeograph::m_internaloperation--;
+                Lifeograph::s_internaloperation--;
             }
         }
         else
@@ -727,9 +727,9 @@ WidgetEntryList::sort_by_change( const Gtk::TreeModel::iterator& itr1,
         return 0;
 
     time_t date1( item1->get_type() == DiaryElement::ET_ENTRY ?
-            dynamic_cast< Entry* >( item1 )->get_date_changed() : 0 );
+            dynamic_cast< Entry* >( item1 )->get_date_edited() : 0 );
     time_t date2( item2->get_type() == DiaryElement::ET_ENTRY ?
-            dynamic_cast< Entry* >( item2 )->get_date_changed() : 0 );
+            dynamic_cast< Entry* >( item2 )->get_date_edited() : 0 );
 
     if( date1 > date2 )
         return -1;
