@@ -60,30 +60,49 @@ class WidgetEntryList : public Gtk::TreeView
             int                         sort_by_change( const Gtk::TreeModel::iterator&,
                                                         const Gtk::TreeModel::iterator& );
 
-            void cell_data_func_icon( Gtk::CellRenderer* cell, const Gtk::TreeModel::iterator& iter );
+            void                        cell_data_func_icon( Gtk::CellRenderer* cell,
+                                                             const Gtk::TreeModel::iterator& iter );
+
+            void                        do_for_each_selected_entry( sigc::slot< void, Entry* >& );
 
             Glib::RefPtr< Gtk::TreeStore >
                                         m_treestore;
 
     protected:
-            DiaryElement                *m_elem_drop_target;
+            DiaryElement*               m_elem_drop_target;
 
             bool                        on_button_press_event( GdkEventButton* );
             bool                        on_button_release_event( GdkEventButton* );
             bool                        on_key_press_event( GdkEventKey* );
 
             void                        on_drag_begin( const Glib::RefPtr< Gdk::DragContext >& );
+            void                        on_drag_end( const Glib::RefPtr< Gdk::DragContext >& );
             bool                        on_drag_motion( const Glib::RefPtr< Gdk::DragContext >&,
                                                         int, int, guint );
             bool                        on_drag_drop( const Glib::RefPtr< Gdk::DragContext >&,
                                                       int x, int y, guint time );
-            //void                        on_drag_data_received(
-                                                //const Glib::RefPtr< Gdk::DragContext >&,
-                                                //int, int, const Gtk::SelectionData&,
-                                                //guint, guint );
+            void                        handle_selection_changed();
+            void                        restore_selection();
 
             bool                        make_path_deeper_last( Gtk::TreePath& );
             bool                        move_path_next( Gtk::TreePath& );
+
+            // HELPER FUNCTION
+            void                        move_entry_to_chapter( Entry*, Chapter* );
+
+            class MultipleEntries : public DiaryElement
+            {
+                public:
+                    Type                get_type() const
+                    { return ET_MULTIPLE_ENTRIES; }
+                    int                 get_size() const
+                    { return 0; }
+                    void                show() {}
+                    const Glib::RefPtr< Gdk::Pixbuf >&
+                                        get_icon32() const;
+
+                    EntryVector         m_entries;
+            } m_multiple_entries;
 };
 
 
