@@ -91,6 +91,17 @@ TagWidget::populate()
 }
 
 // TAG LIST WIDGET =================================================================================
+
+// STATIC MEMBERS
+const float          WidgetTagList::MARGIN = 18.0;
+const float          WidgetTagList::HSPACING = 10.0;
+const float          WidgetTagList::VSPACING = 14.0;
+const float          WidgetTagList::LABEL_OFFSET = 2.0;
+const float          WidgetTagList::TEXT_HEIGHT = 12.0;
+const float          WidgetTagList::ITEM_BORDER = 4.0;  // must be < MARGIN
+const float          WidgetTagList::ITEM_HEIGHT =  24.0; // ITEM_BORDER + ICON_SIZE + ITEM_BORDER
+const float          WidgetTagList::HALF_HEIGHT = 12.0; // ITEM_HEIGHT / 2
+
 WidgetTagList::WidgetTagList( BaseObjectType* cobject, const Glib::RefPtr< Gtk::Builder >& )
 :   DrawingArea( cobject ), m_ptr2entry( NULL ), m_pos_x( MARGIN ), m_pos_y( MARGIN ),
     m_hovered_tag( NULL ), m_flag_editable( true )
