@@ -256,28 +256,31 @@ class LinkCheck : public Link
                                                const Glib::RefPtr< Gtk::TextMark >&,
                                                unsigned int = 0 );
         void                        go();
+        static void                 set_check( int );
+
+        static const Glib::ustring  s_boxes;
+        static int                  s_pos_mark;
 
-        static const Glib::ustring  boxes;
         unsigned int                m_state_index;
 };
 
 class InlineImage
 {
     public:
-        InlineImage( const Glib::RefPtr< Gtk::TextMark >& );
+        InlineImage( int );
         ~InlineImage();
 
-        Glib::RefPtr< Gtk::TextMark > m_mark;
+        int                         m_offset;
 };
 
 // NEW LINE PREDICATE ==============================================================================
 class PredicateNL
 {
-  public:
-    bool operator()( gunichar ch ) const
-    {
-        return( ch == '\n' );
-    }
+    public:
+        bool operator()( gunichar ch ) const
+        {
+            return( ch == '\n' );
+        }
 };
 
 // TEXTBUFFER ======================================================================================
@@ -320,14 +323,13 @@ class TextbufferDiary : public Gtk::TextBuffer, public EntryParser
         bool                        get_comment_visibility() const
         { return m_tag_comment->property_invisible(); }
 
-        static void                 calculate_para_bounds( Gtk::TextIter&, Gtk::TextIter& );
-        bool                        calculate_multiline_selection_bounds( Gtk::TextIter&,
+        void                        calculate_para_bounds( Gtk::TextIter&, Gtk::TextIter& );
+        bool                        calculate_multi_para_bounds( Gtk::TextIter&,
                                                                           Gtk::TextIter& );
         void                        handle_indent();
         void                        handle_unindent();
 
-        void                        add_bullet();
-        void                        add_checkbox();
+        void                        set_list_item_mark( char );
         void                        add_empty_line_above();
         void                        remove_empty_line_above();
         void                        move_line_up();
@@ -352,15 +354,19 @@ class TextbufferDiary : public Gtk::TextBuffer, public EntryParser
                                                   const Gtk::TextIter&,
                                                   const Gtk::TextIter& );*/
 
+        void                        update_cursor_paragraph( const Gtk::TextIter& );
+        void                        clear_cursor_paragraph( const Gtk::TextIter& );
+
         void                        on_mark_set( const TextBuffer::iterator&,
                                                  const Glib::RefPtr< TextBuffer::Mark >& );
 
-        void                        process_space();
-        bool                        process_new_line();
+        void                        handle_space();
+        bool                        handle_new_line();
+        bool                        increment_numbered_line( Gtk::TextIter&, int );
 
         // PARSING
         void                        parse( const Gtk::TextIter&, const Gtk::TextIter& );
-        void                        reparse();
+        void                        reparse() { parse( begin(), end() ); }
 
         void                        apply_hidden_link_tags( Gtk::TextIter&,
                                             const Glib::RefPtr< Tag >& );
@@ -376,8 +382,12 @@ class TextbufferDiary : public Gtk::TextBuffer, public EntryParser
         void                        apply_link();
         void                        apply_link_date();
         void                        apply_link_id();
+        void                        apply_check( Glib::RefPtr< Gtk::TextTag >*,
+                                                 Glib::RefPtr< Gtk::TextTag >*,
+                                                 int );
         void                        apply_check_ccl();
         void                        apply_check_unf();
+        void                        apply_check_prg();
         void                        apply_check_fin();
         void                        apply_match();
         void                        apply_indent();
@@ -385,6 +395,7 @@ class TextbufferDiary : public Gtk::TextBuffer, public EntryParser
         void                        apply_markup( const Glib::RefPtr< Tag >& );
 
         gunichar                    get_char_at( int );
+        bool                        check_cursor_is_in_para();
 
         int                         get_text_width( const Pango::FontDescription&,
                                                     const Glib::ustring& );
@@ -400,10 +411,8 @@ class TextbufferDiary : public Gtk::TextBuffer, public EntryParser
         void                        replace_misspelled_word( const Glib::ustring& );
         void                        add_word_to_dictionary( const Glib::ustring& );
 
-        Glib::ustring::size_type    parser_open_tag_begin;
-        Glib::ustring::size_type    parser_open_tag_end;
-        bool                        parser_open_tag_is_link;
-        Glib::ustring::size_type    parser_offset_insert_prev;
+        Wstring::size_type          m_parser_pos_cur_para_begin;
+        Wstring::size_type          m_parser_pos_cur_para_end;
 
         static PredicateNL          s_predicate_nl;
 
@@ -414,6 +423,7 @@ class TextbufferDiary : public Gtk::TextBuffer, public EntryParser
         void                        clear_images( int, int& );
         void                        clear_images();
         bool                        update_thumbnail_width( int );
+        void                        update_offsets( int, int );
 
         // TAGS
         // TODO: move these program-wide objects out of this class as...
@@ -433,7 +443,11 @@ class TextbufferDiary : public Gtk::TextBuffer, public EntryParser
         Glib::RefPtr< Tag >         m_tag_link;
         Glib::RefPtr< Tag >         m_tag_link_broken;
         Glib::RefPtr< Tag >         m_tag_link_hidden;
-        static Glib::RefPtr< Tag >  m_tag_checkbox;
+        Glib::RefPtr< Tag >         m_tag_done;
+        Glib::RefPtr< Tag >         m_tag_checkbox_todo;
+        Glib::RefPtr< Tag >         m_tag_checkbox_progressed;
+        Glib::RefPtr< Tag >         m_tag_checkbox_done;
+        Glib::RefPtr< Tag >         m_tag_checkbox_canceled;
         Glib::RefPtr< Tag >         m_tag_image;
         Glib::RefPtr< Tag >         m_tag_misspelled;
 
@@ -444,6 +458,7 @@ class TextbufferDiary : public Gtk::TextBuffer, public EntryParser
         bool                        m_flag_settextoperation;
         int                         m_flag_ongoing_operation;   // Incremental to allow nesting
         bool                        m_flag_parsing;
+        bool                        m_flag_updating_search_text;
         Entry*                      m_ptr2entry;
         Gtk::TextView*              m_ptr2textview;
 
